(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1031462,      35606]*)
(*NotebookOutlinePosition[   1100200,      37649]*)
(*  CellTagsIndexPosition[   1092999,      37451]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Theory Exploration 
Versus
Theorem Proving\
\>", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Bruno Buchberger",
    FontSize->16],
  "\n",
  StyleBox[
  "RISC\nResearch Institute for Symbolic Computation\nA4232 Castle of \
Hagenberg, Austria",
    FontSize->12]
}], "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
Invited Talk at the Calculemus Meeting, Trento, July 11, 1999.\
\>", "SmallText",
  TextAlignment->Center,
  TextJustification->0,
  FontSize->12],

Cell[TextData[{
  StyleBox["Copyright Bruno Buchberger",
    FontWeight->"Bold"],
  ": Copying, storing in data bases etc. is granted under the condition that \
the file is kept unchanged and this copyright note is included in the copy. \
Usage of the material contained in this talk hast be cited appropriately."
}], "Text"],

Cell[TextData[{
  "\.03",
  StyleBox["Acknowledgements",
    FontWeight->"Bold"],
  ": ",
  "This research is partially supported by the Austrian Science Foundation \
(FWF-SFB-project FO-1302) and the Upper Austrian Government  (project \
``PROVE'')."
}], "Text"],

Cell[CellGroupData[{

Cell["A Rough Distinction", "Section"],

Cell[CellGroupData[{

Cell["Theorem Proving", "Subsection"],

Cell["The two essential parameters of a prover:", "Text"],

Cell[BoxData[
    RowBox[{"Knowledge\[Dash]Base", "      ", 
      OverscriptBox[
        StyleBox["\[RightTee]",
          FontSize->24], 
        StyleBox["?",
          FontSize->14]], 
      StyleBox["  ",
        FontSize->24], "Goal"}]], "Input"],

Cell["\<\
Power of theorem provers is measured by the class of goals and knowledge \
bases for which proofs can be generated (efficiently, naturally, ...).\
\>", "Text"],

Cell[TextData[{
  "Correspondingly, in ",
  StyleBox["Theorema,",
    FontSlant->"Italic"],
  " the basic call is"
}], "Text"],

Cell[BoxData[
    \(Prove[expression, \ using \[Rule] knowledge\[Dash]base, \ 
      by \[Rule] proof\[Dash]method]\)], "Input"],

Cell[TextData[{
  "Similarly, in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", we have the calls"
}], "Text"],

Cell[BoxData[
    \(Solve[expression, \ using \[Rule] knowledge\[Dash]base, \ 
      by \[Rule] solution\[Dash]method]\)], "Input"],

Cell[BoxData[
    \(Compute[expression, \ using \[Rule] knowledge\[Dash]base, \ 
      by \[Rule] evaluation\[Dash]method]\)], "Input"],

Cell[TextData[{
  "Remark: Prove, Solve, Compute intimately interact with each other, see B. \
Buchberger, ",
  StyleBox[
  "Proving, Solving, Computing: A Language Environment Based on Mathematica",
    FontSlant->"Italic"],
  ", invited talk at the  Multi-Paradigm Logic Programming Conference, \
Schloss Dagstuhl, September 1996; \
http://www.risc.uni-linz.ac.at/people/buchberg/papers/B-Buchberger-1999-Talk- \
MPLP96.zip"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory Exploration", "Subsection"],

Cell["\<\
In normal math research, teaching, and application, we do not consider \
individual theorems.\
\>", "Text"],

Cell["Rather, we explore an entire 'theory', i.e. we ", "Text"],

Cell["\<\
we proceed in proving 'layers' of more and more complex propositions\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
in each layer, we consider (try to prove or disprove) the propositions as an \
ensemble and not isolated\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
in each layer, we prove by reduction to the (immediately) preceding layer(s) \
and not by reduction to 'first principles'.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
in each layer, we apply specific proof techniques that are 'appropriate' to \
the layer considered.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]],

Cell["The thesis of this talk: ", "Text"],

Cell["\<\
Organized theory exploration instead of isolated theorem proving has a \
drastic influence on the feasibility, power, naturalness and practical \
attractiveness of automated theorem proving.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
Hence, future mathematical software systems that integrate theorem proving \
should support theory generation in various ways.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exploration Situations", "Section"],

Cell[CellGroupData[{

Cell["The Parameters of an Exploration Situation", "Subsection"],

Cell["\<\
An 'exploration situation' in mathematical research is characterized by the \
following parameters:\
\>", "Text"],

Cell[TextData[{
  "a collection ",
  StyleBox["C",
    FontColor->RGBColor[1, 0, 0]],
  " of known concepts"
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[{
  "a collection ",
  StyleBox["K",
    FontColor->RGBColor[1, 0, 0]],
  " of facts that (are thought  to) \"completely\" describe the \
interrelations among the known concepts"
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[{
  "a new concept ",
  StyleBox["N",
    FontColor->RGBColor[1, 0, 0]]
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[{
  "axioms ",
  StyleBox["A",
    FontColor->RGBColor[1, 0, 0]],
  " (definitions) that relate the new concept with the known concepts"
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[{
  "a collection ",
  StyleBox["G",
    FontColor->RGBColor[1, 0, 0]],
  " of goal propositions that (are thought to) \"completely\" explore the \
relation between the new concept and the known concepts."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
Note that, here, the notion of a \"complete\" knowledge on concepts is not a \
formal notion. In certain contexts, for example in rewriting, \"complete\" \
knowledge may well be conceived as a \"completed system\" in the technical \
sense, which entails that the truth of sentences can be decided w.r.t. to \
such a system. However, although we do not give a formal definition of \
\"completeness\", the intuitive ingredient of the notion of  \"complete \
knowledge\" is that, as with formally complete systems,  it should be \
\"relatively easy\" (i.e. by \"symbolic computing\" and not by handling \
quantifiers) to prove or disprove all other statements on the given notions \
as soon as we have \"complete knowledge\" about them. We will make this \
clearer in the examples below.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Proof Method Appropriate for an Exploration Situation", "Subsection"],

Cell["We believe that", "Text"],

Cell["\<\
the parameters K (known facts), A (axioms), and G (goals)  of an exploration \
situation determine an \"appropriate\" proof method for proving the \"routine\
\" propositions in G and \
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
\"often\", the appropriate proof method can be derived from the syntactical \
structure of K , A , and G.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
Layers of sophistication in (present and future) computer-supported theory \
exploration systems:\
\>", "Text"],

Cell[BoxData[
    RowBox[{\(For\ many\ typical\ exploration\ situations\), ",", " ", 
      RowBox[{
      "the", " ", "system", " ", "provides", " ", "an", " ", "appropriate", 
        " ", "proof", " ", "method", " ", "in", " ", "a", " ", "library", 
        " ", "of", " ", "proof", " ", "methods", " ", "which", " ", "the", 
        " ", "user", " ", "may", " ", "choose", " ", "according", " ", 
        "this", " ", "hir", " ", "analysis", " ", "of", " ", "the", " ", 
        "situation", " ", 
        RowBox[{
          RowBox[{"(", "\"\<\!\(\*
StyleBox[\\(Theorema\\),\nFontSlant->\"Italic\"]\), present Version 1\>\"", 
            ")"}], "."}]}]}]], "Input",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[BoxData[
    RowBox[{
    \(For\ any\ \ exploration\ situation\), ",", " ", 
      \(the\ system\ allows\ the\ user\ to\ formulate\), ",", " ", 
      \(in\ an\ easy\ "\<prover programming language\>"\), ",", " ", 
      \(using\ also\ basic\ proof\ methods\ from\ a\ library\), ",", " ", 
      RowBox[{
      \(his/her\), " ", "proposal", " ", "for", " ", "what", " ", "she", " ", 
        "believes", " ", "is", " ", "an", " ", "appropriate", " ", "proof", 
        " ", "method", " ", "for", " ", "the", " ", "given", " ", 
        "situation", " ", 
        RowBox[{
          RowBox[{"(", "\"\<\!\(\*
StyleBox[\\(Theorema\\),\nFontSlant->\"Italic\"]\), future Version 2\>\"", 
            ")"}], "."}]}]}]], "Input",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[BoxData[
    RowBox[{
    \(The\ system\ provides\ a\ "\<proof method composer\>"\ that\ composes
        \), ",", " ", \(for\ \((m)\) any\ exploration\ situations\), ",", 
      " ", 
      RowBox[{
      "an", " ", "appropriate", " ", "proof", " ", "method", " ", 
        "automatically", " ", "from", " ", "a", " ", "library", " ", "of", 
        " ", "basic", " ", "proof", " ", "methods", " ", 
        RowBox[{"(", "\"\<\!\(\*
StyleBox[\\(Theorema\\),\nFontSlant->\"Italic\"]\), future Version \
3)\>."}]}]}]], "Input",
  CellDingbat->"\[FilledSmallCircle]"]
}, Closed]],

Cell[CellGroupData[{

Cell["An Example of an Exploration Situation", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Theorema`\>"]\)], "Input"],

Cell[BoxData[
    \("You can specify your personal preferences in a file `Setup.m` in the \
directory (folder) \"Theorema -> User\" in your private Theorema \
directory!"\)], "Print"]
}, Closed]],

Cell[TextData[{
  StyleBox["Known concepts:",
    FontColor->RGBColor[1, 0, 0]],
  " 0 (zero), ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Placeholder]\^+\)\)]],
  " (successor function)."
}], "Text"],

Cell[TextData[{
  StyleBox["Fact(s) about known concept",
    FontColor->RGBColor[1, 0, 0]],
  "s: induction axiom(s)"
}], "Text"],

Cell[BoxData[
    \(\[ForAll] \+A\((
        \((A[0] \[And] 
              \[ForAll] \+x\((A[x]\[DoubleLongRightArrow]A[\(x\^+\)])\))
            \)\[DoubleLongRightArrow]\(\[ForAll] \+x A[x]\))\)\)], "Input"],

Cell[TextData[{
  StyleBox["New concept: ",
    FontColor->RGBColor[1, 0, 0]],
  "'+' (addition)."
}], "Text"],

Cell[TextData[StyleBox[
"Axioms (definition) that relate new concept with known concepts:",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Addition\>\"", ",", \(any[m, n]\), ",", "\n", "\t", GridBox[{
            {\(m + 0 = m\), "\"\< +0\>\""},
            {\(m + \(n\^+\) = \(\((m + n)\)\^+\)\), "\"\< +succ\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Addition"],

Cell[TextData[{
  StyleBox["Goal propositions: ",
    FontColor->RGBColor[1, 0, 0]],
  "all formulae of the form"
}], "Text"],

Cell[BoxData[
    \(\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)L = R\)], "Input"],

Cell[TextData[{
  "where L and R are terms in '0', '",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Placeholder]\^+\)\)]],
  "', and '+' and the variables ",
  Cell[BoxData[
      \(\(' x\_1'\), \[Ellipsis], \(' x\_n\)\)]],
  "'."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["An Appropriate Proof Method", "Subsection"],

Cell["\<\
A proof method that is appropriate for this proof situation (and many \
others):\
\>", "Text"],

Cell[TextData[{
  "Take all ",
  Cell[BoxData[
      \(x\_1, \[Ellipsis], x\_n\)]],
  " \"arbitrary but fixed\" and try to prove 'L=R' by rewriting both L and R \
modulo the assumed equalities (in the definition)."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["If this proof succeeds, report success (and show the proof).", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "If this proof fails, organize induction on ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  ":"
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
        The induction base is a proof situation of the same type but with one \
variable less. 
         Hence call the proof method recursively.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
        The induction step is a proof situation of the same type but with one \
variable less. 
         Hence call the proof method recursively.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "In ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", this proof method has the name '",
  "NNEqIndProver'."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["An Example of a Proof", "Subsection"],

Cell[BoxData[
    \(SetGlobals[TraceLevel -> 0]; $RecursionLimit = 1024; \)], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Addition of Zero from Left\>\"", ",", \(any[n]\), ",", "\n", "\t", 
        GridBox[{
            {\(0 + n = n\), "\"\<0+ \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Addition of Zero from Left"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Addition of Zero from Left\>\"", 
          "]"}], ",", "\n", 
        "\t", \(using \[Rule] Definition["\<Addition\>"]\), ",", "\n", 
        "    ", \(by \[Rule] NNEqIndProver\)}], "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "(If you are a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " alpha tester you can execute the above Prove-call and you obtain the \
proof generated by ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " in a notebook with name 'Untitled-...'. If you don't have ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " available but you have Mathematica 3.0 installed you can read the proof \
in the notebook Proof-Addition-0-From-Left-All-Branches.nb. If you don't have \
Mathematica available you can read the proof in the postscript file \
Proof-Addition-0-From-Left-All-Branches.nb.)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Addition of Zero from Left\>\"", 
          "]"}], ",", "\n", "\t", 
        \(using \[Rule] Definition["\<Addition\>"]\), ",", "\n", "    ", 
        \(by \[Rule] NNEqIndProver\), ",", 
        \(proof\[Dash]object \[Rule] "\<SuccessBranch\>"\)}], "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell["\<\
(You can read the proof in the notebook Proof-Addition-0-From-Left.nb  or \
...ps.)\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["An Attempt at Complete Exploration", "Subsection"],

Cell[TextData[{
  "Let's now try to prove other equalities on 0, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Placeholder]\^+\)\)]],
  ", + by the same method:"
}], "Text"],

Cell[BoxData[
    \(SetGlobals[Prover \[Rule] NNEqIndProver]\)], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Addition from Left\>\"", ",", \(any[m, n]\), ",", "\n", "\t", 
        GridBox[{
            {\(\(m\^+\) + n = \(\((m + n)\)\^+\)\), "\"\<succ+ \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Addition from Left"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Addition from Left\>\"", "]"}], 
        ",", \(using \[Rule] Definition["\<Addition\>"]\), 
        ",", \(proof\[Dash]object \[Rule] "\<SuccessBranch\>"\)}], 
      "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell["\<\
(You can read the proof in the notebook \
Proof-Addition-From-Left-All-Branches.nb or ...ps.)\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Associativity of Addition\>\"", ",", \(any[m, n, p]\), ",", "\n", 
        "\t", GridBox[{
            {\(\((m + n)\) + p = m + \((n + p)\)\), "\"\<( + )+ \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Associativity of Addition"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Associativity of Addition\>\"", 
          "]"}], ",", \(using \[Rule] Definition["\<Addition\>"]\), ",", 
        "\n", \(proof\[Dash]object \[Rule] "\<SuccessBranch\>"\)}], "]"}]], 
  "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell["\<\
(You can read the proof in the notebook Proof-Addition-Associativity.nb or \
...ps.)\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Commutativity of Addition\>\"", ",", \(any[m, n]\), ",", "\n", 
        "\t", GridBox[{
            {\(m + n = n + m\), "\"\< + \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Commutativity of Addition"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Commutativity of Addition\>\"", 
          "]"}], ",", \(using \[Rule] Definition["\<Addition\>"]\)}], "]"}]], 
  "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell["\<\
This proof fails. The failure will be analyzed below. (You can read the proof \
attempt in the notebook Proof-Addition- Commutativity.nb or ...ps.)\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Complete Exploration: Bottom-Up", "Section"],

Cell[CellGroupData[{

Cell["Observation ", "Subsection"],

Cell["\<\
A fixed prover determines, of course, for every fixed knowledge base a fixed \
set of provable formulae.\
\>", "Text",
  CellFrame->True,
  CellDingbat->"\[FilledSmallCircle]",
  Background->GrayLevel[0.849989]],

Cell["\<\
However, without changing the prover, the collection of provable formula can \
increase drastically if we add proved formulae to the knowledge base. \
Similarly, the length of proofs may decrease drastically by the same measure.\
\
\>", "Text",
  CellFrame->True,
  CellDingbat->"\[FilledSmallCircle]",
  Background->GrayLevel[0.849989]],

Cell["\<\
Also, the order in which formulae are proved (and, if proved, are added to \
the knowledge base) may drastically influence the proving power of the \
prover.\
\>", "Text",
  CellFrame->True,
  CellDingbat->"\[FilledSmallCircle]",
  Background->GrayLevel[0.849989]],

Cell["\<\
Hence, we should add a mechanism to the proof system that automatically adds \
proved formulae to the knowledge if sequences of goal propositions are given \
to a prover of the system instead of isolated goal propositions.\
\>", "Text",
  CellFrame->True,
  CellDingbat->"\[FilledSmallCircle]",
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["An Example of Adding Proved Formulae to the Knowledge Base", 
  "Subsection"],

Cell[BoxData[
    \(SetGlobals[LabelStyle \[Rule] "\<Alpha\>"]\)], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Propositions",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Equational Properties of Addition\>\"", ",", \(any[m, n, p]\), 
        ",", "\n", "\t", GridBox[{
            {\(0 + n = n\), "\"\<0+ \>\""},
            {\(\(m\^+\) + n = \(\((m + n)\)\^+\)\), "\"\<^++ \>\""},
            {\(m + n = n + m\), "\"\< + \>\""},
            {\(\((m + n)\) + p = m + \((n + p)\)\), "\"\<( + ) + \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Equational Properties of Addition"],

Cell[TextData[
"By setting the option 'ExpandKnowledge\[Rule]True' (which forces every \
proved goal to be added to the knowledge base) in the Prove-call, all above \
propositions can be proved without changing the prover."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", 
        \(Propositions["\<Equational Properties of Addition\>"], \n\t
        using \[Rule] Definition["\<Addition\>"], \n\ \ \ \ \ 
        by \[Rule] NNEqIndProver, 
        proof\[Dash]object \[Rule] "\<SuccessBranch\>", 
        ExpandKnowledge \[Rule] True\), "]"}], "  "}]], "Input"],

Cell[BoxData[
    \({\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator], 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator], 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator], 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]}\)], "Output"]
}, Closed]],

Cell["\<\
(The four proofs generated are stored in Proof-Sequence-Expanding-KB-1.nb \
through ...-4.nb and the corresponding .ps files.)\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Which and How Many Formulae should we Prove for a 'Complete' Exploration?\
\>", "Subsection"],

Cell[TextData[StyleBox["Answer: ",
  FontWeight->"Bold"]], "Text"],

Cell["\<\
All propositions (in our case, equalities) that describe all interactions of \
the new concept with the known concepts (and with itself) are interesting \
goals.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
Interactions that can be described in the form of rewrite rules are \
particular useful because they 'algorithmize' the branch of mathematics under \
exploration. (90 % of the mathematical knowledge is of this nature.)\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
Only the 'immediate' interactions need to be explored because the compound \
interactions are iterations of immediate interactions.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
This does not yet give conjectures about the 'result' of the interactions, \
however!\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example Addition: ",
    FontWeight->"Bold"],
  "immediate interactions"
}], "Text"],

Cell[BoxData[
    \(0 + 0 = \ ?\)], "Input"],

Cell[BoxData[
    \(0 + n = ?\)], "Input"],

Cell[BoxData[
    \(m + 0 = ?\)], "Input"],

Cell[BoxData[
    \(\(m\^+\) + n = ?\)], "Input"],

Cell[BoxData[
    \(m + \(n\^+\) = ?\)], "Input"],

Cell[BoxData[
    \(m + m = ?\)], "Input"],

Cell[BoxData[
    \(m + n = ?\)], "Input"],

Cell[BoxData[
    \(m + \((n + p)\) = ?\)], "Input"],

Cell[BoxData[
    \(\((m + n)\) + p = ?\)], "Input"],

Cell["All other interactions are 'compound'.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["One Syntactical Class At A Time", "Subsection"],

Cell[CellGroupData[{

Cell["A Suggestion", "Subsubsection"],

Cell["An Example:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<limit\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a, \[Epsilon], N\)\((
                  limit[f] := 
                    \(\[AE]\+a\) 
                      \(\[ForAll] 
                          \+\[Epsilon]\(\[Exists] \+N\(\(\ \[ForAll] \)\+n\) 
                            \((n \[GreaterEqual] N)
                                \)\[DoubleLongRightArrow]\((
                                \[LeftBracketingBar]f[n] - a
                                      \[RightBracketingBar] < \[Epsilon])
                                \)\)\))\)\), "\"\<l1:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],

Cell["Exploration situation: ", "Text"],

Cell[TextData[
"          known concepts: +, -, *, \[LeftBracketingBar] \
\[RightBracketingBar], <, ... on numbers,  \[CirclePlus], \[CircleMinus], ... \
on sequences,\n          known facts: 'complete' knowledge about mutual \
interaction of these operations,\n          new concept: limit\n          \
axioms: the above definition\n          goals: all interactions of limit with \
\[CirclePlus], \[CircleMinus], ..."], "Text"],

Cell["Example of a goal:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<limit\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, g\)\((
                  limit[f\[CirclePlus]g] = limit[f] + limit[g])\)\), 
              "\"\<limit[ \[CirclePlus] ] \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<limit\>\"", ",", "\n", "\t", GridBox[{
            {\(\(\[ForAll] \+\(f, g\)\)\+\(is\[Dash]convergent[f], \
is\[Dash]convergent[g]\)\((limit[f\[CirclePlus]g] = limit[f] + limit[g])\)\), 
              "\"\<limit[ \[CirclePlus] ] \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<convergence\>", \n\t
      \[ForAll] \+\(f, a, \[Epsilon], N\)\((
          is\[Dash]convergent[f] := 
            \(\[Exists] \+a\) 
              \(\[ForAll] 
                  \+\[Epsilon]\(\[Exists] \+N\(\(\ \[ForAll] \)\+n\) 
                    \((n \[GreaterEqual] N)\)\[DoubleLongRightArrow]\((
                        \[LeftBracketingBar]f[n] - a\[RightBracketingBar] < 
                          \[Epsilon])\)\)\))\)\), "]"}]], "Input",
  CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],

Cell["\<\
Suggestion: Consider one \"syntactical class\" at a time! In other words, \
apply \"structured programming\" principles!\
\>", "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Split New Notion", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<1-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a, \[Epsilon], N\)\((
                  limit[f] := \(\[AE]\+a\) limit[f, a])\)\), "\"\<l1:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "1-ary limit", "2-ary limit", "3-ary limit", "4-ary limit", "limit"}],

Cell[BoxData[
    \(General::"spell1" \( : \ \) 
      "Possible spelling error: new symbol name \"\!\(limit\)\" is similar to \
existing symbol \"\!\(Limit\)\"."\)], "Message",
  CellTags->"1-ary limit"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<2-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a\)\((
                  \((limit[f, a])\)\  := 
                    \((\ \[ForAll] \+\[Epsilon] limit[f, a, \[Epsilon]])\))
                  \)\), "\"\<l2:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"2-ary limit"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<3-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a, \[Epsilon]\)\((
                  \((limit[f, a, \[Epsilon]])\) := \ 
                    \[Exists] \+N limit[f, a, \[Epsilon], N])\)\), 
              "\"\<l3:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"2-ary limit", "3-ary limit"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<4-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a, \[Epsilon], N\)\((
                  \((limit[f, a, \[Epsilon], N])\) := 
                    \((\(\(\ \[ForAll] \)\+n\) 
                        \((n \[GreaterEqual] N)\)\[DoubleLongRightArrow]\((
                            \[LeftBracketingBar]f[n] - a
                                  \[RightBracketingBar] < \[Epsilon])\))\))
                  \)\), "\"\<l4:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Some Knowledge on Known Notions", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<sum of sequences\>\"", ",", \(any[f, g, x]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((\((f\[CirclePlus]g)\)[x])\) = \((f[x] + g[x])\)\), 
              "\"\<\[CirclePlus]:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"sum of sequences"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<distance of sum\>\"", ",", 
        \(any[x, y, a, b, \[Delta], \[Epsilon]]\), ",", "\n", "\t", GridBox[{
            {
              \(\((\[LeftBracketingBar]x - a\[RightBracketingBar] < \[Delta] 
                    \[And] \[LeftBracketingBar]y - b\[RightBracketingBar] < 
                      \[Epsilon])\)\[DoubleLongRightArrow]\((
                  \[LeftBracketingBar]\((x + y)\) - 
                        \((a + b)\)\[RightBracketingBar] < 
                    \[Delta] + \[Epsilon])\)\), 
              "\"\<\[LeftBracketingBar]++\[RightBracketingBar]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"distance of sum"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<max\>\"", ",", \(any[M, m, n]\), ",", "\n", "\t", GridBox[{
            {
              \(\((M \[GreaterEqual] max[m, n])\)\[DoubleLongRightArrow]\((
                  M \[GreaterEqual] m \[And] M \[GreaterEqual] n)\)\), 
              "\"\<max:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"max"],

Cell[BoxData[
    \(General::"spell1" \( : \ \) 
      "Possible spelling error: new symbol name \"\!\(max\)\" is similar to \
existing symbol \"\!\(Max\)\"."\)], "Message",
  CellTags->"max"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Explore Lowest Layer", "Subsubsection"],

Cell["Now we explore each of the \"layers\" separately:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<4-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(Definition["\<4-ary limit\>"]\)},
            {\(Definition["\<sum of sequences\>"]\)},
            {\(Proposition["\<distance of sum\>"]\)},
            {\(Proposition["\<max\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"4-ary limit"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<4-ary limit of sum\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a, \[Delta], M, g, b, \[Epsilon], N\)\((
                  \((limit[f, a, \[Delta], M] \[And] 
                        limit[g, b, \[Epsilon], N])\)\n\t
                    \[DoubleLongRightArrow]limit[f\[CirclePlus]g, a + b, 
                      \[Delta] + \[Epsilon], max[M, N]])\)\), "\"\<l4+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"4-ary limit of sum"],

Cell[BoxData[
    \(SetGlobals[Prover \[Rule] PredicateProver]; $RecursionLimit = 1024; 
    SetGlobals[LabelStyle \[Rule] "\<Alphanumeric\>"]; \n
    SetGlobals[SearchDepth \[Rule] 200]; SetGlobals[DebugLevel \[Rule] 0]; 
    SetGlobals[TraceLevel \[Rule] 0]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<4-ary limit of sum\>"], 
        using \[Rule] Theory["\<4-ary limit\>"], \n\t
        ProverOptions \[Rule] {BackChaining \[Rule] True}, 
        SearchDepth \[Rule] 250\), "]"}], " ", "//", "Timing"}]], "Input"],

Cell[BoxData[
    \({21.5299999999999736`\ Second, 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]}\)], "Output"]
}, Closed]],

Cell["(The proof is stored in Proof-Sum-4-ary-Limit.nb and ...ps.)", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Explore Next Layer", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<3-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(Definition["\<3-ary limit\>"]\)},
            {\(Proposition["\<4-ary limit of sum\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"3-ary limit"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<3-ary limit of sum\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a, \[Delta], g, b, \[Epsilon]\)\((
                  \((limit[f, a, \[Delta]] \[And] limit[g, b, \[Epsilon]])\)\n
                    \t\[DoubleLongRightArrow]limit[f\[CirclePlus]g, a + b, 
                      \[Delta] + \[Epsilon]])\)\), "\"\<l3+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"3-ary limit of sum"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<3-ary limit of sum\>"], 
        using \[Rule] Theory["\<3-ary limit\>"], 
        ProverOptions 
          \[Rule] {BackChaining \[Rule] True, PNDLevel \[Rule] 0}, 
        SearchDepth \[Rule] 200\), "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
    \({10.930000000000064`\ Second, 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Explore Next Layer", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<3-ary limit of sum: variant\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a, g, b, \[Epsilon]\)\((
                  \((limit[f, a, \[Epsilon]/2] \[And] 
                        limit[g, b, \[Epsilon]/2])\)\n\t
                    \[DoubleLongRightArrow]limit[f\[CirclePlus]g, a + b, 
                      \[Epsilon]])\)\), "\"\<l3+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"3-ary limit of sum: variant"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<2-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(Definition["\<2-ary limit\>"]\)},
            {\(Proposition["\<3-ary limit of sum: variant\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"2-ary limit"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<2-ary limit of sum\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\[ForAll] \+\(f, a, g, b\)\((
                  \((limit[f, a] \[And] limit[g, b])\)\n\t
                    \[DoubleLongRightArrow]limit[f\[CirclePlus]g, a + b])
                  \)\), "\"\<l2+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"2-ary limit of sum"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<2-ary limit of sum\>"], 
        using \[Rule] Theory["\<2-ary limit\>"], 
        ProverOptions \[Rule] {BackChaining \[Rule] True}, 
        SearchDepth \[Rule] 200\), "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
    \({5.88000000000010913`\ Second, 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Explore Next Layer", "Subsubsection"],

Cell[TextData[{
  "The last layer, at this stage, cannot yet be handled in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<1-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(Definition["\<1-ary limit\>"]\)},
            {\(Definition["\<convergence\>"]\)},
            {\(Proposition["\<2-ary limit of sum\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"1-ary limit", "2-ary limit"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<limit\>\"", ",", "\n", "\t", GridBox[{
            {
              \(\(\[ForAll] \+\(f, g\)\)\+\(is\[Dash]convergent[f], 
                  is\[Dash]convergent[g]\)\((
                  limit[f\[CirclePlus]g] = limit[f] + limit[g])\)\), 
              "\"\<limit[ \[CirclePlus] ] \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", 
      \(Proposition[
        "\<limit'],using\[Rule]Theory[\>" 1 - 
          ary\ limit 
            \*"\"\<],\n\t\t\t\t\t\
ProverOptions\[Rule]{BackChaining\[Rule]True},SearchDepth\[Rule]200\>]"\)}]], 
  "Input"],

Cell[BoxData[
    \({9.06999999999970896`\ Second, 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]}\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Complete Exploration: Top-Down", "Section"],

Cell[CellGroupData[{

Cell["Let's Be Unsystematic", "Subsection"],

Cell[CellGroupData[{

Cell["Start with Higher Level Conjecture as a Challenge", "Subsubsection"],

Cell["\<\
In contrast to the bottom-up approach, we now start with a \"challenge\" for \
the natural induction prover for equalities that cannot yet be handled \
because, at this stage, some intermediate knowledge is not yet proved:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Propositions",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Equational Properties of Addition\>\"", ",", \(any[m, n, p]\), 
        ",", "\n", "\t", GridBox[{
            {\(m + 0 = m\), "\"\< +0\>\""},
            {\(m + \(n\^+\) = \(\((m + n)\)\^+\)\), "\"\< + ^+\>\""},
            {\(0 + n = n\), "\"\<0+ \>\""},
            {\(\(m\^+\) + n = \(\((m + n)\)\^+\)\), "\"\<^++ \>\""},
            {\(\((m + n)\) + p = m + \((n + p)\)\), "\"\<( + ) + \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Equational Properties of Addition"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Multiplication\>\"", ",", \(any[m, n]\), ",", "\n", "\t", 
        GridBox[{
            {\(m*0 = 0\), "\"\< *0\>\""},
            {\(m*\(n\^+\) = \((m*n)\) + m\), "\"\< * ^+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Multiplication"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Commutativity of Multiplication\>\"", ",", \(any[m, n]\), ",", 
        "\n", "\t", GridBox[{
            {\(m*n = n*m\), "\"\< * \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Commutativity of Multiplication"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", 
        \(Proposition["\<Commutativity of Multiplication\>"], \n\t
        using \[Rule] {Definition["\<Multiplication\>"], 
            Propositions["\<Equational Properties of Addition\>"]}, \ \n\t
        by \[Rule] NNEqIndProver\), "]"}], "//", " ", "Timing"}]], "Input"],

Cell[BoxData[
    \({9.27999999999997271`\ Second, 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]}\)], "Output"]
}, Closed]],

Cell["\<\
The proof fails. (See the notebook \
Proof-Attempt-1-Multiplication-Commutativity.nb or ....ps.)\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Failure Analysis Leads to Conjectures", "Subsubsection"],

Cell[BoxData[
    FormBox[
      RowBox[{\(An\ anlysis\ of\ the\ proof\ shows\ that\), ",", " ", 
        RowBox[{"for", " ", "a", " ", "constant", " ", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[1, 0, 0],
            Background->None]}], ",", " ", 
        \(the\ prover\ would\ have\ needed\ the\ \(knowledge : \)\)}], 
      TextForm]], "Text"],

Cell[TextData[{
  "          ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"0", "=", 
          RowBox[{"0", "*", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}],
        FontColor->RGBColor[1, 0, 0]]], "Text"],
  "."
}], "Text"],

Cell[TextData[{
  "Let's first prove this for arbitrary ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[1, 0, 0],
            Background->None]}], TextForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Multiplication of Zero from Left\>\"", ",", \(any[n]\), ",", "\n", 
        "\t", GridBox[{
            {\(0*n = 0\), "\"\<0* \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Multiplication", "Multiplication of Zero from Left", "Zero from Left"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", 
        \(Proposition["\<Multiplication of Zero from Left\>"], \n\t
        using \[Rule] {Definition["\<Multiplication\>"], 
            Propositions["\<Equational Properties of Addition\>"]}, \ \n\t
        by \[Rule] NNEqIndProver\), "]"}], "//", " ", "Timing"}]], "Input"],

Cell[BoxData[
    \({3.41000000000008185`\ Second, 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]}\)], "Output"]
}, Closed]],

Cell["\<\
(See the notebook Proof-Multiplication-0-From-Left.nb or ...ps.)\
\>", "Text"],

Cell["\<\
After expansion of the knowledge base, we return to the main proof:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", 
        \(Proposition["\<Commutativity of Multiplication\>"], \n\t
        using \[Rule] {Definition["\<Multiplication\>"], 
            Propositions["\<Equational Properties of Addition\>"], 
            Proposition["\<Multiplication of Zero from Left\>"]}, \ \n\t
        by \[Rule] NNEqIndProver\), "]"}], "//", " ", "Timing"}]], "Input"],

Cell[BoxData[
    \({12.3500000000001364`\ Second, 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]}\)], "Output"]
}, Closed]],

Cell["\<\
The prover fails again but at some later point. (See the notebook \
Proof-Attempt-2-Multiplication-Commutativity.nb or ...ps.)\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(An\ anlysis\ of\ the\ proof\ shows\ that\), ",", " ", 
        RowBox[{"for", "  ", "constants", "  ", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[1, 0, 0],
            Background->None]}], ",", 
        RowBox[{
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[1, 0, 0],
            Background->None], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], "  "}]], "it", " ", "would", 
          " ", "have", " ", "needed", " ", "the", " ", \(knowledge : \)}]}], 
      TextForm]], "Text"],

Cell[BoxData[
    StyleBox[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}], "+"], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}], "+"]}],
      FontColor->RGBColor[1, 0, 0]]], "Input"],

Cell["In fact, the lhs and rhs are identical except for:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[1, 0, 0],
          Background->None], 
        StyleBox["+",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[1, 0, 0],
          Background->None]}], 
      StyleBox["=",
        FontColor->RGBColor[1, 0, 0]], 
      RowBox[{
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[1, 0, 0],
          Background->None], 
        StyleBox["+",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[1, 0, 0],
          Background->None]}]}]], "Input"],

Cell[TextData[{
  "Let's, hence, first prove this for arbitrary ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            FontColor->RGBColor[1, 0, 0],
            Background->None]}], TextForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[1, 0, 0],
          Background->None], TextForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Commutativity of Addition\>\"", ",", \(any[m, n]\), ",", "\n", 
        "\t", GridBox[{
            {\(m + n = n + m\), "\"\< + \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Commutativity of Addition", "Multiplication", 
    "Multiplication of Zero from Left", "Zero from Left"}],

Cell["\<\
In fact, we already know that this proof works with the prover NNEqIndProver.\
\
\>", "Text"],

Cell["\<\
After expansion of the knowledge base, we return to the main proof:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", 
        \(Proposition["\<Commutativity of Multiplication\>"], \n\t
        using \[Rule] {Definition["\<Multiplication\>"], 
            Propositions["\<Equational Properties of Addition\>"], \n\t\t\t
            Proposition["\<Commutativity of Addition\>"], 
            Proposition["\<Multiplication of Zero from Left\>"]}, \ \n\t
        by \[Rule] NNEqIndProver\), "]"}], "//", " ", "Timing"}]], "Input"],

Cell[BoxData[
    \({10.0599999999999467`\ Second, 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]}\)], "Output"]
}, Closed]],

Cell["\<\
Now, the proof works. (See the notebook Proof-Multiplication-Commutativity.nb \
or ...ps.)\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["What we can Learn From This", "Subsubsection"],

Cell["Given a prover and an exploration situation,", "Text"],

Cell["\<\
instead of exploring all possible interactions of new and old concepts \
systematically bottom-up (with a high chance to obtain successful proofs \
immediately but with the necessity of already having conjectures for the \
propositions to be proved),\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
we can \"challenge\" the prover with a top conjecture and analyze the failing \
proof, which may lead to a conjecture for a lower level proposition,   a n d  \
 s o   o n.   \
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["A Theory Generation Cascade", "Subsection"],

Cell[TextData[{
  "Given a prover ",
  StyleBox["P",
    FontSlant->"Italic"],
  ", a fixed knowledge base ",
  StyleBox["K",
    FontSlant->"Italic"],
  " and a statement ",
  StyleBox["G",
    FontSlant->"Italic"],
  " which we want to prove, the function \
\"Theory\[Dash]Generation\[Dash]Cascade\" produces a theory consisting of \
statements that comprise all statements of ",
  StyleBox["K",
    FontSlant->"Italic"],
  " plus possibly some (hopefully many) other statements that are provable \
from ",
  StyleBox["K",
    FontSlant->"Italic"],
  " by ",
  StyleBox["P",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[TextData["Theory\[Dash]Generation\[Dash]Cascade[G,K,P]:"], "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          StyleBox["G",
            FontSlant->"Italic"], ",", " ", 
          RowBox[{"using", "\[Rule]", 
            StyleBox["K",
              FontSlant->"Italic"]}], ",", 
          RowBox[{"by", "\[Rule]", 
            StyleBox["P",
              FontSlant->"Italic"]}]}], "]"}], "."}]], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox["If",
          FontWeight->"Bold"], " ", "proof", " ", "succeeds"}], 
      StyleBox[" ",
        FontWeight->"Bold"]}], 
    RowBox[{
      RowBox[{
        StyleBox["then",
          FontWeight->"Bold"], "  ", "resulting", " ", "theory", " ", "is", 
        "  ", 
        StyleBox["K",
          FontSlant->"Italic"]}], "\[Union]", 
      RowBox[{"{", 
        StyleBox["G",
          FontSlant->"Italic"], "}"}]}], 
    RowBox[{
      RowBox[{
        StyleBox["else",
          FontWeight->"Bold"], "  ", \((i . e . \ if\ proof\ fails)\), " ", 
        StyleBox["analyze",
          FontSlant->"Italic"], 
        StyleBox[" ",
          FontSlant->"Italic"], 
        StyleBox["the",
          FontSlant->"Italic"], 
        StyleBox[" ",
          FontSlant->"Italic"], 
        StyleBox["points",
          FontSlant->"Italic"], 
        StyleBox[" ",
          FontSlant->"Italic"], 
        StyleBox["where",
          FontSlant->"Italic"], 
        StyleBox[" ",
          FontSlant->"Italic"], 
        StyleBox["the",
          FontSlant->"Italic"], 
        StyleBox[" ",
          FontSlant->"Italic"], 
        StyleBox["proof",
          FontSlant->"Italic"], 
        StyleBox[" ",
          FontSlant->"Italic"], 
        StyleBox["fails",
          FontSlant->"Italic"]}], 
      StyleBox[" ",
        FontSlant->"Italic"]}], 
    RowBox[{"        ", 
      RowBox[{
        RowBox[{
          RowBox[{"and", " ", "derive", " ", "a", " ", "conjecture", " ", 
            StyleBox["C",
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], "such", " ", "that", " ", 
            StyleBox["G",
              FontSlant->"Italic"], " ", "might", " ", "be", " ", "provable", 
            " ", "by", " ", 
            StyleBox["P",
              FontSlant->"Italic"], " ", "using", " ", 
            StyleBox["K",
              FontSlant->"Italic"]}], "\[Union]", 
          RowBox[{
            RowBox[{"{", 
              StyleBox["C",
                FontSlant->"Italic"], "}"}], ".", "\n", "\n", "        ", 
            StyleBox["T",
              FontSlant->"Italic"]}]}], ":=", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"Theory\[Dash]Generation\[Dash]Cascade", "[", 
                StyleBox[\(C, K, P\),
                  FontSlant->"Italic"], "]"}], ".", "\n", "\n", 
              StyleBox[
                RowBox[{"       ", 
                  StyleBox[" ",
                    FontWeight->"Bold"]}]], 
              StyleBox["If",
                FontWeight->"Bold"]}], 
            StyleBox[
              RowBox[{
                StyleBox[" ",
                  FontWeight->"Bold"], "  "}]], 
            StyleBox["T",
              FontSlant->"Italic"]}], 
          StyleBox["=",
            FontSlant->"Italic"], 
          RowBox[{
            StyleBox["K",
              FontSlant->"Italic"], 
            StyleBox["  ",
              FontSlant->"Italic"], 
            \((i . e . \ no\ additional\ theorems\ were\ provable\ by\ P\ 
                using\ K)\)}]}]}], " \t"}], 
    RowBox[{"            ", 
      RowBox[{
        StyleBox["then",
          FontWeight->"Bold"], "  ", "resulting", " ", "theory", " ", "is", 
        "  ", "K"}]}], 
    RowBox[{"            ", 
      RowBox[{
        StyleBox["else",
          FontWeight->"Bold"], 
        StyleBox[
          RowBox[{
            StyleBox["   ",
              FontWeight->"Bold"], " "}]], 
        RowBox[{
          RowBox[{"Prove", "[", 
            RowBox[{
              StyleBox["G",
                FontSlant->"Italic"], ",", " ", 
              RowBox[{"using", "\[Rule]", 
                StyleBox["T",
                  FontSlant->"Italic"]}], ",", 
              RowBox[{"by", "\[Rule]", 
                StyleBox["P",
                  FontSlant->"Italic"]}]}], 
            StyleBox["]",
              FontSlant->"Italic"]}], 
          StyleBox[".",
            FontSlant->"Italic"], "\n", "\n", 
          StyleBox[
            RowBox[{"              ", 
              StyleBox["  ",
                FontWeight->"Bold"]}]], 
          StyleBox["If",
            FontWeight->"Bold"]}], 
        StyleBox[
          RowBox[{
            StyleBox[" ",
              FontWeight->"Bold"], " "}]], "proof", " ", "succeeds"}], 
      "  "}], 
    RowBox[{"\t                      ", 
      RowBox[{
        RowBox[{
          StyleBox["then",
            FontWeight->"Bold"], "  ", "resulting", " ", "theory", " ", "is", 
          " ", 
          StyleBox["T",
            FontSlant->"Italic"]}], "\[Union]", 
        RowBox[{"{", 
          StyleBox["G",
            FontSlant->"Italic"], "}"}]}], " "}], 
    RowBox[{"\t\t                 ", 
      RowBox[{
        StyleBox["else",
          FontWeight->"Bold"], "   ", "resulting", " ", "theory", " ", "is", 
        "  ", 
        RowBox[{
          StyleBox["T",
            FontSlant->"Italic"], "."}]}]}]}], "Input"],

Cell["Note: Importance of displaying failing proofs!", "Text"],

Cell[TextData[{
  "If we have an algorithmic failure analyzer for ",
  StyleBox["P",
    FontSlant->"Italic"],
  " then the theory generation cascade turns the prover ",
  StyleBox["P",
    FontSlant->"Italic"],
  " into a more powerful prover ",
  StyleBox["P'",
    FontSlant->"Italic"],
  ", which is also a theorem generator:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          StyleBox["G",
            FontSlant->"Italic"], ",", 
          RowBox[{"using", "\[Rule]", 
            StyleBox["K",
              FontSlant->"Italic"]}], ",", 
          RowBox[{"by", "\[Rule]", 
            StyleBox[\(P'\),
              FontSlant->"Italic"]}]}], 
        StyleBox["]",
          FontSlant->"Italic"]}], 
      StyleBox[
        RowBox[{":", 
          StyleBox["=",
            FontSlant->"Italic"]}]], 
      RowBox[{
        RowBox[{"Theory\[Dash]Generation\[Dash]Cascade", "[", 
          RowBox[{
            StyleBox["G",
              FontSlant->"Italic"], ",", 
            StyleBox["K",
              FontSlant->"Italic"], ",", 
            StyleBox["P",
              FontSlant->"Italic"]}], "]"}], "."}]}]], "Input"],

Cell[TextData[{
  "In the current version of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " this cascade is implemented, see the paper B-Buchberger-1999-Paper-",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo which can be loaded from the home page \
www.risc.uni-linz.ac.at/people/buchberg/papers"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["The Transfer of Knowledge to the Status of Inference Rule", "Section"],

Cell[CellGroupData[{

Cell["Let's Look to a Successful Proof", "Subsection"],

Cell["Consider the following scenario:", "Text"],

Cell[TextData[{
  "Complete exploration of + over 0, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Placeholder]\^+\)\)]],
  ": Done."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["Next exploration situation: * inductively defined over +.", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
Let's prove, for example, associativity of *, knowing already some facts \
about + and *:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Propositions",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Equational Properties of Addition\>\"", ",", \(any[m, n, p]\), 
        ",", "\n", "\t", GridBox[{
            {\(m + 0 = m\), "\"\< +0\>\""},
            {\(m + \(n\^+\) = \(\((m + n)\)\^+\)\), "\"\< + ^+\>\""},
            {\(0 + n = n\), "\"\<0+ \>\""},
            {\(\(m\^+\) + n = \(\((m + n)\)\^+\)\), "\"\<^++ \>\""},
            {\(m + n = n + m\), "\"\< + \>\""},
            {\(\((m + n)\) + p = m + \((n + p)\)\), "\"\<( + ) + \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Equational Properties of Addition"],

Cell[BoxData[
    RowBox[{
      StyleBox[
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "s"}]], "[", 
      RowBox[{
      "\"\<Some Equational Properties of Multiplication\>\"", ",", 
        \(any[m, n]\), ",", "\n", "\t", GridBox[{
            {\(m*0 = 0\), "\"\< *0\>\""},
            {\(m*\(n\^+\) = \((m*n)\) + m\), "\"\< *  ^+\>\""},
            {\(0*n = 0\), "\"\<0*\>\""},
            {\(\(m\^+\)*n = \((m*n)\) + n\), "\"\< ^+*\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Multiplication", "Some Equational Properties of Multiplication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Associativity of Multiplication\>\"", ",", \(any[m, n, p]\), ",", 
        "\n", "\t", GridBox[{
            {\(\((m*n)\)*p = m*\((n*p)\)\), "\"\<( * ) * \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "Associativity of Multiplication", "Associativity of Multiplicatios", 
    "Multiplication"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", 
        \(Proposition["\<Associativity of Multiplication\>"], \n\t
        using \[Rule] {
            Propositions["\<Some Equational Properties of Multiplication\>"], 
            Propositions["\<Equational Properties of Addition\>"]}, \ \n\t
        by \[Rule] NNEqIndProver\), "]"}], "//", " ", "Timing"}]], "Input"],

Cell[BoxData[
    \({79.3099999999999472`\ Second, 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]}\)], "Output"]
}, Closed]],

Cell["\<\
(See the notebook Proof-Multiplication-Associativity-with-AddAC-in-KB.nb or \
...ps.)\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Let's Analyze the Longest Part of the Proof", "Subsection"],

Cell["Now we analyze the longest part of the proof:", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}], "*", 
          SuperscriptBox[
            StyleBox[\(p\_6\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( *  ^+)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "+", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  SuperscriptBox[
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"]}]}], ")"}], "*", 
            StyleBox[\(p\_6\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "+", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(( * ) * .IS.S.IS.IH)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    SuperscriptBox[
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+"]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "+", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( *  ^+)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "+", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( *  ^+)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "+", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( ^+*)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "+", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(^++ )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "+", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}], "+"]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + ^+)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}]}], ")"}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}]}], ")"}], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(( + ) + )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          RowBox[{
                            StyleBox[\(m\_1\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "*", 
                            StyleBox[\(n\_3\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}]}], ")"}]}], ")"}], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "*", 
            SuperscriptBox[
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( *  ^+)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( *  ^+)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    SuperscriptBox[
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+"]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( *  ^+)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( *  ^+)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( ^+*)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + ^+)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+"], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(^++ )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "+", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}]}], ")"}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}]}], ")"}], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}]}], ")"}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}]}], ")"}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(( + ) + )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(p\_6\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          RowBox[{
                            StyleBox[\(n\_3\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "*", 
                            StyleBox[\(p\_6\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}]}], ")"}]}], ")"}], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(p\_6\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          RowBox[{
                            StyleBox[\(n\_3\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "*", 
                            StyleBox[\(p\_6\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}]}], ")"}]}], ")"}]}], ")"}], 
              "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(( + ) + )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          RowBox[{
                            StyleBox[\(m\_1\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "*", 
                            StyleBox[\(n\_3\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}]}], ")"}], "+", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          RowBox[{
                            StyleBox[\(m\_1\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "*", 
                            StyleBox[\(n\_3\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}]}], ")"}]}], ")"}], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  "\[RightFloor]"
}], "Text"],

Cell["\<\
We see that, in fact, most of the time is spent in applying associativity and \
commutativity of +. Furthermore, \"it is clear\" what the outcome of these \
AC-simplification steps is, i.e. we can predict the outcome, i.e. we can \
invent an easy algorithm that produces the outcome of these AC-simplification \
steps a priori:\
\>", "Text"],

Cell["\<\
view the term as composed of  '+' on the highest level and 'elementary terms' \
that start with a symbol other than '+'\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["put all paretheses to the left", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["order the elementary terms according to some fixed ordering.", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
Note that this algorithm is not just a reformulation of the AC-steps. \
\"Prediction algorithms\" can be arbitrarily far away from the inference \
rules whose effect is predicted and may involve some high-level nontrivial \
mathematics. (Examples: Groebner bases simplification for boolean combination \
of equalities over the complex numbers; Collins' algorithm for arbitrary \
formulae of the theory of real closed fields; etc.)\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Consequence: Transfer of Knowledge to the Status of Inference Rule\
\>", "Subsection"],

Cell["\<\
Consequence: In this exploration situation, an appropriate prover should use \
a special \"black box\" inference rule for '+' applying the above prediction \
algorithm and not show details of applying this inference rule because this \
is \"uninteresting\" in the present exploration situation, in which our \
attention is on exploring '*'. In contrast, '+' is already supposed to be \
\"completely explored\". \
\>", "Text"],

Cell["Hence, we cancel AC for '+' in the knowledge base", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Propositions",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Equational Properties of Addition\>\"", ",", \(any[m, n, p]\), 
        ",", "\n", "\t", GridBox[{
            {\(m + 0 = m\), "\"\< +0\>\""},
            {\(m + \(n\^+\) = \(\((m + n)\)\^+\)\), "\"\< + ^+\>\""},
            {\(0 + n = n\), "\"\<0+ \>\""},
            {\(\(m\^+\) + n = \(\((m + n)\)\^+\)\), "\"\<^++ \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Equational Properties of Addition"],

Cell["\<\
and, instead, add AC of addition as a special inference rule:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", 
        \(Proposition["\<Associativity of Multiplication\>"], \n\t
        using \[Rule] {
            Propositions["\<Some Equational Properties of Multiplication\>"], 
            Propositions["\<Equational Properties of Addition\>"]}, \ \n\t
        built\[Dash]in -> {
            Property[\(+\( \[Rule] {Associative, Commutative}\)\)]}, \n\t
        by \[Rule] NNEqIndProver, 
        proof\[Dash]object \[Rule] "\<SuccessBranch\>"\), "]"}], "//", " ", 
      "Timing"}]], "Input"],

Cell[BoxData[
    \({15.929999999999838`\ Second, 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]}\)], "Output"]
}, Closed]],

Cell["\<\
(See the notebook \
Proof-Multiplication-Associativity-with-AddAC-as-Inference-Rule.nb or ...ps.)\
\
\>", "Text"],

Cell["\<\
Of course, adding AC for addition as an inference rule needs extra \
programming work in the prover, it does not \"come for free\". The critical \
part of the proof now looks as follows:\
\>", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(Special Simpl)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], "+", 
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( *  ^+)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}], "*", 
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}]}], ")"}], 
          "+", 
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(Special Simpl)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            StyleBox[\(m\_1\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "+", 
                            RowBox[{"(", 
                              RowBox[{
                                StyleBox[\(n\_3\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "+", 
                                RowBox[{
                                  StyleBox[\(m\_1\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "*", 
                                  StyleBox[\(n\_3\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None]}]}], ")"}]}], ")"}], 
                        "*", 
                        StyleBox[\(p\_5\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}]}], ")"}], 
          "+", 
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + ^+)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox[\(m\_1\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "*", 
                            StyleBox[\(n\_3\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], "+", 
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{
                                StyleBox[\(m\_1\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "+", 
                                RowBox[{"(", 
                                  RowBox[{
                                    StyleBox[\(n\_3\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "+", 
                                    RowBox[{
                                      StyleBox[\(m\_1\),
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "*", 
                                      StyleBox[\(n\_3\),
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None]}]}], ")"}]}], 
                              ")"}], "*", 
                            StyleBox[\(p\_5\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}]}], ")"}]}], ")"}]}], ")"}], 
              "+", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(Special Simpl)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(p\_5\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{
                                StyleBox[\(m\_1\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "+", 
                                RowBox[{"(", 
                                  RowBox[{
                                    StyleBox[\(n\_3\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "+", 
                                    RowBox[{
                                      StyleBox[\(m\_1\),
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "*", 
                                      StyleBox[\(n\_3\),
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None]}]}], ")"}]}], 
                              ")"}], "*", 
                            StyleBox[\(p\_5\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}]}], ")"}], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}]}], ")"}], 
          "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(( * ) * .IS.S.IS.S.IH)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(p\_5\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                StyleBox[\(n\_3\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "*", 
                                StyleBox[\(p\_5\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}], "+", 
                              RowBox[{
                                RowBox[{"(", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "+", 
                                    RowBox[{
                                      StyleBox[\(m\_1\),
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "*", 
                                      StyleBox[\(n\_3\),
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None]}]}], ")"}], "*", 
                                StyleBox[\(p\_5\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}]}], ")"}]}], ")"}], 
                      "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}]}], ")"}], 
          "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(Special Simpl )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(p\_5\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox[\(m\_1\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "*", 
                            StyleBox[\(n\_3\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], "+", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                StyleBox[\(n\_3\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "*", 
                                StyleBox[\(p\_5\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}], "+", 
                              RowBox[{
                                RowBox[{"(", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "+", 
                                    RowBox[{
                                      StyleBox[\(m\_1\),
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "*", 
                                      StyleBox[\(n\_3\),
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None]}]}], ")"}], "*", 
                                StyleBox[\(p\_5\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}]}], ")"}]}], ")"}]}], 
                    ")"}]}], ")"}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                SuperscriptBox[
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(Special Simpl)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                SuperscriptBox[
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], "+", 
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( *  ^+)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                SuperscriptBox[
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], "+", 
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(Special Simpl)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                SuperscriptBox[
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], "+", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( *  ^+)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}], "*", 
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}], "+", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(Special Simpl)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox[\(n\_3\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "*", 
                            StyleBox[\(p\_5\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], "+", 
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{
                                StyleBox[\(m\_1\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "+", 
                                RowBox[{
                                  StyleBox[\(m\_1\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "*", 
                                  StyleBox[\(n\_3\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None]}]}], ")"}], "*", 
                            StyleBox[\(p\_5\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}]}], ")"}]}], ")"}]}], 
                ")"}]}], ")"}], "+", 
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["( + ^+)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox[\(m\_1\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "*", 
                            StyleBox[\(n\_3\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], "+", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                StyleBox[\(n\_3\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "*", 
                                StyleBox[\(p\_5\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}], "+", 
                              RowBox[{
                                RowBox[{"(", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "+", 
                                    RowBox[{
                                      StyleBox[\(m\_1\),
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "*", 
                                      StyleBox[\(n\_3\),
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None]}]}], ")"}], "*", 
                                StyleBox[\(p\_5\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}]}], ")"}]}], ")"}]}], 
                    ")"}]}], ")"}], "+", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  " =",
  "   ",
  "by ",
  StyleBox["(Special Simpl )",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "        ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(p\_5\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox[\(m\_1\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "*", 
                            StyleBox[\(n\_3\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], "+", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                StyleBox[\(n\_3\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "*", 
                                StyleBox[\(p\_5\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}], "+", 
                              RowBox[{
                                RowBox[{"(", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "+", 
                                    RowBox[{
                                      StyleBox[\(m\_1\),
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "*", 
                                      StyleBox[\(n\_3\),
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None]}]}], ")"}], "*", 
                                StyleBox[\(p\_5\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}]}], ")"}]}], ")"}]}], 
                    ")"}]}], ")"}]}], ")"}], "+"],
        FontColor->RGBColor[1, 0, 1]]], "Text"],
  "\[RightFloor]"
}], "Text"],

Cell["\<\
One sees that long sequences of AC-steps for addition have been replaced by \
one invocation of the AC-simplifier for addition (marked by '(Special \
Simpl)').  The proof becomes faster, shorter and easier to read.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
This Transfer Principle is Ubiquitous in Human Practical Proving\
\>", "Subsection"],

Cell["\<\
If one ananlyzes lots of \"real-life\" exploration situations, one detects \
that this transfer principle is not an exotic and special happening but, \
rather, the main principle by which human exploration of entire theories in \
the definition-proposition-proof style becomes practically feasible.\
\>", "Text"],

Cell["Other examples:", "Text"],

Cell["\<\
In fact, we already tacitly applied this principle right at the beginning \
when we formulated induction as a proof method instead of putting induction \
axioms to the knowledge base and using a general predicate logic prover.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[
"Explore properties of \[CapitalSigma] as a function, then introduce \
\[CapitalSigma] as a quantifier and transfer the properties proved about the \
function \[CapitalSigma] into special inference rules for the quantifier \
\[CapitalSigma]."], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "Go further and develop an algebraic theory and a corresponding algorithm \
for checking the identity of \[CapitalSigma]-expressions, see the \
Zeilberger-Paule-... theory. Call to this algorithm \"whenever appropriate\". \
(See the demo of the Zeilberger-Paule-method in the paper \
B-Buchberger-1999-Paper-",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo which can be loaded from the home page www.risc.uni-linz.ac.at \
/people/buchberg/papers.)"
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[
"Explore rewrite properties of 'lim', 'df/dx', '\[Integral]' first for these \
functions. Then introduce the corresponding quantifiers and transfer the \
properties proved about the functions into special inference rules for the \
quantifiers."], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
Go further and develop an algebraic theory and a corresponding algorithm for \
checking the integrability of certain classes of functions defined by certain \
classes of expressions, see Risch, ... . Call to this algorithm \"whenever \
appropriate\".\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "Develop a theory of polynomial ideal membership and a membership \
(congruence, ...) algorithm based on it, see the author's Groebner bases \
theory. Call this algorithm \"whenever appropriate\". (See the demo of the \
Groebner-bases-method below and in the paper B-Buchberger-1999-Paper-",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo which can be downloaded from the home page www.risc.uni-linz.ac.at \
/people/buchberg/papers.)"
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
Develop a theory of \"cylindric algebraic decompositions\" of the real space \
w.r.t. systems of polynomials and develop an algorithm based on it for \
checking the truth of arbitrary formulae of the theory of real closed fields, \
see Collins, .... Call this algorithm \"whenever appropriate\".\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[BoxData[
    \(Needs["\<Theorema`Provers`UserProvers`GroebnerBasesProver`\>"]\)], 
  "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Formula",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<GB-Test\>\"", ",", \(any[x, y]\), ",", "\n", "\t", GridBox[{
            {
              \(\((\((\(x\^3\) y\^4 + 27  xy\^3 - 15  x\^3 = 0)\) \[And] 
                    \((\(1\/5\) \(x\^2\) y - 23  x\ y + 17 = 0)\))\) 
                \[Implies] \n\t
                \((225\ x\^3 + \(-405\)\ xy\^3 + 255\ x\ y + 
                      \(-15\)\ x\^4\ y + 27\ x\ xy\^3\ y + 
                      \(-328\)\ x\^2\ y\^2 + 3\ x\^3\ y\^2 + 
                      \(-23\)\ x\^3\ y\^3 + \(x\^4\ y\^3\)\/5 + 
                      \(-15\)\ x\^3\ y\^4 + x\^4\ y\^5 = 0)\)\), 
              "\"\<f=0\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"GB-Test", "GBTest11"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Formula["\<GB-Test\>"], by \[Rule] GroebnerBasesProver] // Timing
      \)], "Input"],

Cell[BoxData[
    \({2.86000000000012732`\ Second, 
      \[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]}\)], "Output"]
}, Closed]],

Cell["(See the notebook Proof-by-Groebner-Bases.nb or ...ps.)", "Text"],

Cell["\<\
There is a seamless transition from near-at-hand special inference rules to \
gigantic black box decision procedures for special classes of formulae. \
However, the logics of integrating special inference mechanisms is always the \
same.\
\>", "Text",
  CellDingbat->None]
}, Closed]],

Cell[CellGroupData[{

Cell["A Logically Sound Integration of Special Inferencing", "Subsection"],

Cell[TextData[{
  "We start from ",
  StyleBox["one ",
    FontSlant->"Italic"],
  "logic system, e.g. a variant of higher order predicate logic. For this \
system we have a semantical notion of logical consequence."
}], "Text"],

Cell[TextData[{
  "Whenever we establish a special prover ",
  StyleBox["P",
    FontSlant->"Italic"],
  ", we must specify two essential things:"
}], "Text"],

Cell[TextData[{
  "the class of knowledge bases and goals for which ",
  StyleBox["P",
    FontSlant->"Italic"],
  " can be applied"
}], "Text"],

Cell[TextData[{
  "the \"tacit (implicit, built-in, ...) theory\" ",
  StyleBox["T",
    FontSlant->"Italic"],
  " under which correctness of ",
  StyleBox["P",
    FontSlant->"Italic"],
  " is guaranteed."
}], "Text"],

Cell[TextData[{
  "In more detail: For a correct special prover ",
  StyleBox["P",
    FontSlant->"Italic"],
  " for the theory ",
  StyleBox["T",
    FontSlant->"Italic"],
  " the following correctness theorem for ",
  StyleBox["T",
    FontSlant->"Italic"],
  " must be proved:"
}], "Text"],

Cell[TextData[{
  "If ",
  StyleBox["P",
    FontSlant->"Italic"],
  " proves ",
  StyleBox["G",
    FontSlant->"Italic"],
  " from ",
  StyleBox["K",
    FontSlant->"Italic"],
  ", then ",
  StyleBox["G",
    FontSlant->"Italic"],
  " must be a logical consequence of ",
  StyleBox["K",
    FontSlant->"Italic"],
  " and ",
  StyleBox["T",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "The correctness theorem for ",
  StyleBox["T",
    FontSlant->"Italic"],
  " is a meta-theorem."
}], "Text"],

Cell["\<\
For many important special provers (various special simplifiers, Collins' \
method, Groebner Bases method, Zeilberger method, ...) the correctness \
theorem is well established in the mathematical literature.\
\>", "Text"],

Cell[TextData[{
  "These proofs could also be given using a formalization of (parts of) logic \
within the proof system itself. (A challenge! Example: Formal proof of \
Groebner bases theory is one of the motivations for ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ".)"
}], "Text"],

Cell[TextData[{
  "However, note that the proof of the correctness theorem for the special \
prover ",
  StyleBox["P",
    FontSlant->"Italic"],
  " will normally be much harder then the proofs of the theorems that are \
automatically proved by ",
  StyleBox["P",
    FontSlant->"Italic"],
  ". (\"A practical version of Goedel's second theorem\".)"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Avoiding Correctness Proofs for Special Provers", "Subsection"],

Cell["\<\
Formal proofs of the correctness theorem for provers (as for any other \
algorithms) - and their implementation ! -  may be difficult. \
\>", "Text"],

Cell["\<\
Most people just \"trust\" the correctness of special proof technique proved \
\"manually\" in the literature and \"carefully implemented\" using the \
literature.\
\>", "Text"],

Cell[TextData[{
  "One can, however, also consider a special proof technique as a \
\"conjecture generating black box\". For each \"proof\" \[Pi] generated by a \
prover relying on the special proof technique one would then have to check \
the correctness of each black box step by proving it by a prover that does \
not rely on the special proof technique but on a general proof technique with \
the corresponding implicit theory ",
  StyleBox["T",
    FontSlant->"Italic"],
  " in the knowledge base."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Conclusion", "Section"],

Cell["\<\
We argued that, for \"real-life\" application of proving / solving / \
computing systems, these systems should support the \"theory exploration\" \
paradigm rather than concentrate only on the \"isolated theorem proving\" \
paradigm.   (Example: At CADE, we need a \"Computer-supported theory \
exploration\" competition in addition to the \"single theorem proving\" \
competition!)\
\>", "Text",
  CellFrame->False,
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
We discussed some strategies and approaches to facilitate theory exploration:\
\
\>", "Text",
  CellFrame->False,
  CellDingbat->"\[FilledSmallCircle]",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
Practical facilities for manipulating large amounts of formal text.\
\>", "Text",
  CellFrame->False,
  CellDingbat->"\[EmptySmallCircle]",
  Background->None],

Cell["\<\
Establishing provers that are \"appropriate\" for a given exploration \
situation.\
\>", "Text",
  CellFrame->False,
  CellDingbat->"\[EmptySmallCircle]",
  Background->None],

Cell["\<\
Complete exploration by bottom-up analysis of all possible interactions \
(hopefully in the form of algorithmic formulae)  of new concepts with given \
concepts.\
\>", "Text",
  CellFrame->False,
  CellDingbat->"\[EmptySmallCircle]",
  Background->None],

Cell["Decomposition of goals with nested alternating quantifiers.", "Text",
  CellFrame->False,
  CellDingbat->"\[EmptySmallCircle]",
  Background->None],

Cell["\<\
Top-down conjectures generation by challenging provers and (automated) \
analysis of failing proofs (the \"cascade\").\
\>", "Text",
  CellFrame->False,
  CellDingbat->"\[EmptySmallCircle]",
  Background->None],

Cell["\<\
Transfer of knowledge to the status of proof methods as the main principle \
for \"human-like\" exploration and generation of short proofs.\
\>", "Text",
  CellFrame->False,
  CellDingbat->"\[EmptySmallCircle]",
  Background->None],

Cell["\<\
Importance of a uniform semantics for a clear understanding and manipulation \
of the correctness of special provers.\
\>", "Text",
  CellFrame->False,
  CellDingbat->"\[EmptySmallCircle]",
  Background->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Appendix: Proofs", "Section"],

Cell[CellGroupData[{

Cell["Proof Addition 0 From Left - All Branches", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ )", "Label"],
  " ",
  Cell["", "Blank"],
  " ",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"0+ "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +succ)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" +succ"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["0+ ",
      ButtonData:>"0+ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails.(The Simplifier was unable to transform the proof situation.)"
}], "Text"],

Cell["Alternative proof 2: proved", "Text"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["0+ ",
      ButtonData:>"0+ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      \(0 + 0 = 0\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Assumption"]
}], "Assumption",
  CellTags->"2"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof Addition 0 From Left", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"0+ "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +succ)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" +succ"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["0+ ",
      ButtonData:>"0+ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      \(0 + 0 = 0\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Assumption"]
}], "Assumption",
  CellTags->"2"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof Addition From Left", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(succ+ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"succ+ "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +succ)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" +succ"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["succ+ ",
      ButtonData:>"succ+ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(0\^+\), "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)  ", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\(0\^+\) + 0 = \(\((0 + 0)\)\^+\)\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"4"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\) + 0\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\)\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(\((0 + 0)\)\^+\)\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\)\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{\(0\^+\), "+", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Assumption"]
}], "Assumption",
  CellTags->"5"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{\(0\^+\), "+", 
          SuperscriptBox[
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              SuperscriptBox[
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"6"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{\(0\^+\), "+", 
        SuperscriptBox[
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{\(0\^+\), "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"0", "+", 
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+"], ")"}], "+"]], 
    "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            SuperscriptBox[
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"0", "+", 
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+"], ")"}], "+"]], 
    "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"]
}], "Assumption",
  CellTags->"2"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], ")"}], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)  ", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], ")"}], "+"], "+", 
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"7"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], ")"}], "+"], "+", 
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+"], ")"}], "+"]], 
    "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], ")"}], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox["n",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "+"], ")"}], "+"]}], 
          ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"8"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], ")"}], "+"], "+", "0"}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", "0"}], ")"}], "+"], ")"}], 
          "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"9"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["9",
      ButtonData:>"9",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], ")"}], "+"], "+", "0"}]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", "0"}], ")"}], "+"], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], ")"}], "+"], "+", 
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(n\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"], ")"}], "+"]}]], 
    "Assumption"]
}], "Assumption",
  CellTags->"10"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)  ", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], ")"}], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  SuperscriptBox[
                    StyleBox[\(n\_4\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"]}], ")"}], "+"], ")"}], "+"]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"11"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["11",
      ButtonData:>"11",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], ")"}], "+"], "+", 
        SuperscriptBox[
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], ")"}], "+"], "+", 
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    StyleBox[\(n\_4\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+"], ")"}], "+"], ")"}], 
        "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                SuperscriptBox[
                  StyleBox[\(n\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], ")"}], "+"], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    StyleBox[\(n\_4\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+"], ")"}], "+"], ")"}], 
        "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof Addition Associativity", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + )+ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"( + )+ "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +succ)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" +succ"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["( + )+ ",
      ButtonData:>"( + )+ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{"0", "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\((0 + 0)\), "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{"0", "+", 
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"4"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{\((0 + 0)\), "+", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{"0", "+", 
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"7"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{\((0 + 0)\), "+", 
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{"0", "+", 
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"8"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["p",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      \(0 + 0 = 0 + \((0 + 0)\)\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"9"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["9",
      ButtonData:>"9",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + \((0 + 0)\)\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{"0", "+", 
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(p\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"10"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          SuperscriptBox[
            StyleBox[\(p\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{"0", "+", 
          RowBox[{"(", 
            RowBox[{"0", "+", 
              SuperscriptBox[
                StyleBox[\(p\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"11"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["11",
      ButtonData:>"11",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(p\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"(", 
          RowBox[{"0", "+", 
            SuperscriptBox[
              StyleBox[\(p\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(p\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            RowBox[{"(", 
              RowBox[{"0", "+", 
                StyleBox[\(p\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(p\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  StyleBox[\(n\_2\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{"0", "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_2\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"5"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  SuperscriptBox[
                    StyleBox[\(n\_2\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{"0", "+", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(n\_2\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"6"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(12)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"0", "+", 
              SuperscriptBox[
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "+", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{"0", "+", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(p\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"12"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"0", "+", 
            SuperscriptBox[
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "+", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"], "+", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            StyleBox[\(p\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(13)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"0", "+", 
                    StyleBox[\(n\_2\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+"], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{"0", "+", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(n\_2\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"13"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["13",
      ButtonData:>"13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["p",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(14)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"0", "+", 
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+"], "+", "0"}], "=", 
        RowBox[{"0", "+", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", "0"}], ")"}]}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"14"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["14",
      ButtonData:>"14",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"], "+", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", "0"}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(15)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"0", "+", 
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+"], "+", 
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{"0", "+", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"15"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(16)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"0", "+", 
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{"0", "+", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"16"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["16",
      ButtonData:>"16",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"], "+", 
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  StyleBox[\(n\_2\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"], "+", 
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(n\_2\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "+", 
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["15",
      ButtonData:>"15",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  StyleBox[\(n\_2\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"], "+", 
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"2"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(17)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", "0"}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"17"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["17",
      ButtonData:>"17",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(20)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", "0"}], ")"}], "+", 
          StyleBox[\(p\_7\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(p\_7\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"20"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", "0"}], ")"}], "+", 
        StyleBox[\(p\_7\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        StyleBox[\(p\_7\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(p\_7\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(21)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"21"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["21",
      ButtonData:>"21",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["p",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(22)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", "0"}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", \((0 + 0)\)}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"22"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["22",
      ButtonData:>"22",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", "0"}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", \((0 + 0)\)}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", "0"}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(23)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(p\_8\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(p\_8\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"23"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(24)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(p\_8\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{"(", 
            RowBox[{"0", "+", 
              SuperscriptBox[
                StyleBox[\(p\_8\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"24"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["24",
      ButtonData:>"24",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        SuperscriptBox[
          StyleBox[\(p\_8\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            StyleBox[\(p\_8\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        RowBox[{"(", 
          RowBox[{"0", "+", 
            SuperscriptBox[
              StyleBox[\(p\_8\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(p\_8\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{"(", 
              RowBox[{"0", "+", 
                StyleBox[\(p\_8\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["23",
      ButtonData:>"23",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            StyleBox[\(p\_8\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(18)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  StyleBox[\(n\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"18"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(19)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  SuperscriptBox[
                    StyleBox[\(n\_4\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(n\_4\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"19"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["19",
      ButtonData:>"19",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(25)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              SuperscriptBox[
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "+", 
          StyleBox[\(p\_9\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(p\_9\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"25"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            SuperscriptBox[
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "+", 
        StyleBox[\(p\_9\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"], "+", 
        StyleBox[\(p\_9\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            StyleBox[\(p\_9\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(26)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+"], "+", 
                    StyleBox[\(n\_4\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+"], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(n\_4\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"26"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["26",
      ButtonData:>"26",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["p",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(27)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "+", 
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+"], "+", "0"}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", "0"}], ")"}]}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"27"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["27",
      ButtonData:>"27",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"], "+", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", "0"}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        SuperscriptBox[
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(28)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "+", 
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+"], "+", 
          StyleBox[\(p\_10\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(p\_10\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"28"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(29)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "+", 
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(p\_10\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              SuperscriptBox[
                StyleBox[\(p\_10\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"29"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["29",
      ButtonData:>"29",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"], "+", 
        SuperscriptBox[
          StyleBox[\(p\_10\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  StyleBox[\(n\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"], "+", 
            StyleBox[\(p\_10\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            SuperscriptBox[
              StyleBox[\(p\_10\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(p\_10\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(n\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "+", 
                StyleBox[\(p\_10\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["28",
      ButtonData:>"28",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  StyleBox[\(n\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"], "+", 
            StyleBox[\(p\_10\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof  Attempt Addition Commutativity", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->" + "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +succ)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" +succ"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "  fails.(The Simplifier was unable to transform the proof situation.)"
}], "Text"],

Cell["Alternative proof 2: failed", "Text"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: proved", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", "0"}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"4"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      StyleBox[\(n\_1\),
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"5"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      \(0 + 0 = 0\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"6"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Assumption"]
}], "Assumption",
  CellTags->"7"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          SuperscriptBox[
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"8"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Alternative proof 2: pending", "Text"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text",
  Background->GrayLevel[0.659998]],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"2"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"9"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"10"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", "0"}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"11"],

Cell[TextData[{
  "We simplify ",
  Cell[TextData[{
    "(",
    ButtonBox["11",
      ButtonData:>"11",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", "0"}], ")"}], "+"]], "Expression"],
  " = ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(14)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"14"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["14",
      ButtonData:>"14",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails.(No applicable inference rule was found.)"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(12)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Assumption"]
}], "Assumption",
  CellTags->"12"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(13)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"13"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["13",
      ButtonData:>"13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text",
  Background->GrayLevel[0.659998]],

Cell["Alternative proof 2: failed", "Text"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(15)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", "0"}], "=", 
        RowBox[{"0", "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"15"],

Cell[TextData[{
  "We simplify ",
  Cell[TextData[{
    "(",
    ButtonBox["15",
      ButtonData:>"15",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(18)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"18"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["18",
      ButtonData:>"18",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "fails.",
  "(No applicable inference rule was found.)"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(16)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(n\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"16"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(17)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(n\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"17"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["17",
      ButtonData:>"17",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text",
  Background->GrayLevel[0.659998]]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof  Sequence Expanding KB - 1", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ )", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"0+ "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +succ)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" +succ"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["0+ ",
      ButtonData:>"0+ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ .IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      \(0 + 0 = 0\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"0+ .IB"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["0+ .IB",
      ButtonData:>"0+ .IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ .IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Assumption"]
}], "Assumption",
  CellTags->"0+ .IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ .IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"0+ .IS"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["0+ .IS",
      ButtonData:>"0+ .IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0+ .IH",
      ButtonData:>"0+ .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof  Sequence Expanding KB - 2", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"^++ "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0+ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +succ)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" +succ"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ ",
      ButtonData:>"^++ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ .IB)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(0\^+\), "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"^++ .IB"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ .IB",
      ButtonData:>"^++ .IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ .IB.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{\(0\^+\), "+", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"^++ .IB.F"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{\(0\^+\), "+", 
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0+ ",
      ButtonData:>"0+ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ .IB.S)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(0\^+\), "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"^++ .IB.S"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ .IB.S",
      ButtonData:>"^++ .IB.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ .IB.S.IB)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      \(\(0\^+\) + 0 = \(0\^+\)\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"^++ .IB.S.IB"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ .IB.S.IB",
      ButtonData:>"^++ .IB.S.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\) + 0\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\)\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\)\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ .IB.S.IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{\(0\^+\), "+", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Assumption"]
}], "Assumption",
  CellTags->"^++ .IB.S.IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ .IB.S.IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{\(0\^+\), "+", 
          SuperscriptBox[
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"^++ .IB.S.IS"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ .IB.S.IS",
      ButtonData:>"^++ .IB.S.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{\(0\^+\), "+", 
        SuperscriptBox[
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{\(0\^+\), "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ .IB.S.IH",
      ButtonData:>"^++ .IB.S.IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ .IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"]
}], "Assumption",
  CellTags->"^++ .IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ .IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], ")"}], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"^++ .IS"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ .IS",
      ButtonData:>"^++ .IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ .IS.F)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], ")"}], "+"], "+", 
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"^++ .IS.F"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], ")"}], "+"], "+", 
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ .IH",
      ButtonData:>"^++ .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+"], ")"}], "+"]], 
    "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ .IS.S)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], ")"}], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox["n",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "+"], ")"}], "+"]}], 
          ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"^++ .IS.S"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ .IS.S",
      ButtonData:>"^++ .IS.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ .IS.S.IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], ")"}], "+"], "+", "0"}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", "0"}], ")"}], "+"], ")"}], 
          "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"^++ .IS.S.IB"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ .IS.S.IB",
      ButtonData:>"^++ .IS.S.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], ")"}], "+"], "+", "0"}]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", "0"}], ")"}], "+"], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ .IS.S.IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], ")"}], "+"], "+", 
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(n\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"], ")"}], "+"]}]], 
    "Assumption"]
}], "Assumption",
  CellTags->"^++ .IS.S.IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ .IS.S.IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], ")"}], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  SuperscriptBox[
                    StyleBox[\(n\_4\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"]}], ")"}], "+"], ")"}], "+"]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"^++ .IS.S.IS"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ .IS.S.IS",
      ButtonData:>"^++ .IS.S.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], ")"}], "+"], "+", 
        SuperscriptBox[
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], ")"}], "+"], "+", 
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ .IS.S.IH",
      ButtonData:>"^++ .IS.S.IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    StyleBox[\(n\_4\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+"], ")"}], "+"], ")"}], 
        "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                SuperscriptBox[
                  StyleBox[\(n\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], ")"}], "+"], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    StyleBox[\(n\_4\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+"], ")"}], "+"], ")"}], 
        "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof  Sequence Expanding KB - 3", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->" + "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"^++ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0+ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +succ)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" +succ"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + .IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" + .IB"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .IB",
      ButtonData:>" + .IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + .IB.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", "0"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" + .IB.F"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .IB.F",
      ButtonData:>" + .IB.F",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox["0+ ",
      ButtonData:>"0+ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      StyleBox[\(n\_1\),
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      StyleBox[\(n\_1\),
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + .IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->" + .IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + .IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" + .IS"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .IS",
      ButtonData:>" + .IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + .IS.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" + .IS.F"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .IS.F",
      ButtonData:>" + .IS.F",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ ",
      ButtonData:>"^++ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .IH",
      ButtonData:>" + .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof  Sequence Expanding KB - 4", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + ) + )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"( + ) + "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" + "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ )", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"^++ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0+ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +succ)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" +succ"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + ) + .F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(n\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+", 
          StyleBox[\(p\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(m\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(p\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"( + ) + .F"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(n\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+", 
        StyleBox[\(p\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(n\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(m\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(p\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + ) + .S)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], "=", 
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( + ) + .S"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + .S",
      ButtonData:>"( + ) + .S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + ) + .S.IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], "=", 
            RowBox[{"0", "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( + ) + .S.IB"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + .S.IB",
      ButtonData:>"( + ) + .S.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + ) + .S.IB.F)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(p\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}], "=", 
        RowBox[{"0", "+", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(p\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( + ) + .S.IB.F"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + .S.IB.F",
      ButtonData:>"( + ) + .S.IB.F",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0+ ",
      ButtonData:>"0+ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(p\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0+ ",
      ButtonData:>"0+ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + ) + .S.IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], "=", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"( + ) + .S.IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + ) + .S.IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], "=", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( + ) + .S.IS"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + .S.IS",
      ButtonData:>"( + ) + .S.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + ) + .S.IS.F)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( + ) + .S.IS.F"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + .S.IS.F",
      ButtonData:>"( + ) + .S.IS.F",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +succ",
      ButtonData:>" +succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ ",
      ButtonData:>"^++ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(p\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + .S.IH",
      ButtonData:>"( + ) + .S.IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(n\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof  Sum 4-ary Limit", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["M",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Delta]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Delta]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["M",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}], "\[And]", 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["N",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "\[CirclePlus]", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["\[Delta]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{"max", "[", 
                  RowBox[{
                    StyleBox["M",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ",", 
                    StyleBox["N",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "]"}]}], "]"}]}], ")"}]}]], 
    "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"l4+"],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4:)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox["f",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["a",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["N",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}], ":=", 
            RowBox[{
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], " "}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[GreaterEqual]", 
                    StyleBox["N",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "\[Implies]", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        RowBox[{
                          StyleBox["f",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "[", 
                          StyleBox["n",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "]"}], "-", 
                        StyleBox["a",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "\[RightBracketingBar]"}], "<",
                     
                    StyleBox["\[Epsilon]",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"l4:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(\[CirclePlus]:)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "\[CirclePlus]", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "[", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "+", 
              RowBox[{
                StyleBox["g",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"\[CirclePlus]:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(\[LeftBracketingBar]++\[RightBracketingBar])", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["y",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Delta]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "-", 
                    StyleBox["a",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Delta]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "\[And]", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "-", 
                    StyleBox["b",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "-", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["a",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox["b",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}]}], 
                "\[RightBracketingBar]"}], "<", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"\[LeftBracketingBar]++\[RightBracketingBar]"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(max:)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["M",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["M",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", 
              RowBox[{"max", "[", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{
              RowBox[{
                StyleBox["M",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[GreaterEqual]", 
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "\[And]", 
              RowBox[{
                StyleBox["M",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[GreaterEqual]", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"max:"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+",
      ButtonData:>"l4+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we take all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"limit", "[", 
            RowBox[{
              StyleBox[\(f\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(a\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(\[Delta]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(M\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "]"}], "\[And]", 
          RowBox[{"limit", "[", 
            RowBox[{
              StyleBox[\(g\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(b\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(\[Epsilon]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(N\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "]"}]}], "\[Implies]", 
        RowBox[{"limit", "[", 
          RowBox[{
            RowBox[{
              StyleBox[\(f\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[CirclePlus]", 
              StyleBox[\(g\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ",", 
            RowBox[{
              StyleBox[\(a\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(b\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ",", 
            RowBox[{
              StyleBox[\(\[Delta]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(\[Epsilon]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ",", 
            RowBox[{"max", "[", 
              RowBox[{
                StyleBox[\(M\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox[\(N\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l4+'"],

Cell[TextData[{
  "We prove ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'",
      ButtonData:>"l4+'",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by the deduction rule."
}], "Text"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+'.A)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Delta]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(M\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}], "\[And]", 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(N\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  " "
}], "Assumption",
  CellTags->"l4+'.A"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+'.C)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "\[CirclePlus]", 
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(\[Delta]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{"max", "[", 
            RowBox[{
              StyleBox[\(M\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(N\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "]"}]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l4+'.C"],

Cell[TextData[{
  "The conjunction ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.A",
      ButtonData:>"l4+'.A",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " splits into ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.A.1",
      ButtonData:>"l4+'.A.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.A.2",
      ButtonData:>"l4+'.A.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.C",
      ButtonData:>"l4+'.C",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by the definition ",
  Cell[TextData[{
    "(",
    ButtonBox["l4:",
      ButtonData:>"l4:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", it suffices to prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+'.C')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", 
              RowBox[{"max", "[", 
                RowBox[{
                  StyleBox[\(M\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox[\(N\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "\[CirclePlus]", 
                        StyleBox[\(g\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "[", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "-", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(a\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox[\(b\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}]}], 
                "\[RightBracketingBar]"}], "<", 
              RowBox[{
                StyleBox[\(\[Delta]\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(\[Epsilon]\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l4+'.C'"],

Cell[TextData[{
  "The formula ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.A.1",
      ButtonData:>"l4+'.A.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is expanded by the definition ",
  Cell[TextData[{
    "(",
    ButtonBox["l4:",
      ButtonData:>"l4:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " into:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+'.A.1')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", 
              StyleBox[\(M\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "-", 
                  StyleBox[\(a\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[RightBracketingBar]"}], "<", 
              StyleBox[\(\[Delta]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"l4+'.A.1'"],

Cell[TextData[{
  "The formula ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.A.2",
      ButtonData:>"l4+'.A.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is expanded by the definition ",
  Cell[TextData[{
    "(",
    ButtonBox["l4:",
      ButtonData:>"l4:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " into:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+'.A.2')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", 
              StyleBox[\(N\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(g\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "-", 
                  StyleBox[\(b\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[RightBracketingBar]"}], "<", 
              StyleBox[\(\[Epsilon]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"l4+'.A.2'"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.C'",
      ButtonData:>"l4+'.C'",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we take all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+'.C'')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "\[GreaterEqual]", 
          RowBox[{"max", "[", 
            RowBox[{
              StyleBox[\(M\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(N\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "]"}]}], "\[Implies]", 
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[CirclePlus]", 
                    StyleBox[\(g\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "[", 
                StyleBox[\(n\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "-", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(a\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(b\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], "\[RightBracketingBar]"}], 
          "<", 
          RowBox[{
            StyleBox[\(\[Delta]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l4+'.C''"],

Cell[TextData[{
  "We prove ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.C''",
      ButtonData:>"l4+'.C''",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by the deduction rule."
}], "Text"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+'.C''.A)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "\[GreaterEqual]", 
        RowBox[{"max", "[", 
          RowBox[{
            StyleBox[\(M\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(N\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  " "
}], "Assumption",
  CellTags->"l4+'.C''.A"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+'.C''.C)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "\[CirclePlus]", 
                  StyleBox[\(g\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "[", 
              StyleBox[\(n\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "-", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(a\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(b\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], "\[RightBracketingBar]"}], 
        "<", 
        RowBox[{
          StyleBox[\(\[Delta]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l4+'.C''.C"],

Cell[TextData[{
  "Using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[CirclePlus]",
      ButtonData:>"\[CirclePlus]:",
      ButtonStyle->"Hyperlink"],
    ButtonBox[":",
      ButtonData:>"\[CirclePlus]:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", the goal ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.C''.C",
      ButtonData:>"l4+'.C''.C",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is transformed into:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+'.C''.C')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "[", 
                  StyleBox[\(n\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "]"}], "+", 
                RowBox[{
                  StyleBox[\(g\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "[", 
                  StyleBox[\(n\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "]"}]}], ")"}], "-", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(a\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(b\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], "\[RightBracketingBar]"}], 
        "<", 
        RowBox[{
          StyleBox[\(\[Delta]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l4+'.C''.C'"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.C''.C'",
      ButtonData:>"l4+'.C''.C'",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["\[LeftBracketingBar]",
      ButtonData:>"\[LeftBracketingBar]++\[RightBracketingBar]",
      ButtonStyle->"Hyperlink"],
    ButtonBox["++",
      ButtonData:>"\[LeftBracketingBar]++\[RightBracketingBar]",
      ButtonStyle->"Hyperlink"],
    ButtonBox["\[RightBracketingBar]",
      ButtonData:>"\[LeftBracketingBar]++\[RightBracketingBar]",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", it suffices to prove"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+'.C''.C'.A)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              RowBox[{
                StyleBox[\(f\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox[\(n\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "-", 
              StyleBox[\(a\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[RightBracketingBar]"}], "<", 
          StyleBox[\(\[Delta]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "\[And]", 
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              RowBox[{
                StyleBox[\(g\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox[\(n\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "-", 
              StyleBox[\(b\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[RightBracketingBar]"}], "<", 
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l4+'.C''.C'.A"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.C''.C'.A",
      ButtonData:>"l4+'.C''.C'.A",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.C''.C'.A.1",
      ButtonData:>"l4+'.C''.C'.A.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              StyleBox[\(f\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(n\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "-", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "\[RightBracketingBar]"}], "<", 
        StyleBox[\(\[Delta]\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.C''.C'.A.1",
      ButtonData:>"l4+'.C''.C'.A.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.A.1'",
      ButtonData:>"l4+'.A.1'",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", it suffices to prove"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+'.C''.C'.A.1.A)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "\[GreaterEqual]", 
        StyleBox[\(M\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l4+'.C''.C'.A.1.A"],

Cell[TextData[{
  "From ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.C''.A",
      ButtonData:>"l4+'.C''.A",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["max:",
      ButtonData:>"max:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", we obtain:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(max:/1)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "\[GreaterEqual]", 
          StyleBox[\(M\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "\[And]", 
        RowBox[{
          StyleBox[\(n\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "\[GreaterEqual]", 
          StyleBox[\(N\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"max:/1"],

Cell[TextData[{
  "The conjunction ",
  Cell[TextData[{
    "(",
    ButtonBox["max:/1",
      ButtonData:>"max:/1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " splits into ",
  Cell[TextData[{
    "(",
    ButtonBox["max:/1.1",
      ButtonData:>"max:/1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", ",
  Cell[TextData[{
    "(",
    ButtonBox["max:/1.2",
      ButtonData:>"max:/1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.C''.C'.A.1.A",
      ButtonData:>"l4+'.C''.C'.A.1.A",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["max:/1.1",
      ButtonData:>"max:/1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.C''.C'.A.2",
      ButtonData:>"l4+'.C''.C'.A.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              StyleBox[\(g\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(n\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "-", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "\[RightBracketingBar]"}], "<", 
        StyleBox[\(\[Epsilon]\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.C''.C'.A.2",
      ButtonData:>"l4+'.C''.C'.A.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.A.2'",
      ButtonData:>"l4+'.A.2'",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", it suffices to prove"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+'.C''.C'.A.2.A)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "\[GreaterEqual]", 
        StyleBox[\(N\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l4+'.C''.C'.A.2.A"],

Cell[TextData[{
  "From ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.C''.A",
      ButtonData:>"l4+'.C''.A",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["max:",
      ButtonData:>"max:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", we obtain:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(max:/13)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "\[GreaterEqual]", 
          StyleBox[\(M\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "\[And]", 
        RowBox[{
          StyleBox[\(n\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "\[GreaterEqual]", 
          StyleBox[\(N\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"max:/13"],

Cell[TextData[{
  "The conjunction ",
  Cell[TextData[{
    "(",
    ButtonBox["max:/13",
      ButtonData:>"max:/13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " splits into ",
  Cell[TextData[{
    "(",
    ButtonBox["max:/13.1",
      ButtonData:>"max:/13.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", ",
  Cell[TextData[{
    "(",
    ButtonBox["max:/13.2",
      ButtonData:>"max:/13.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+'.C''.C'.A.2.A",
      ButtonData:>"l4+'.C''.C'.A.2.A",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["max:/13.2",
      ButtonData:>"max:/13.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof  Sum 3-ary Limit", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Delta]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Delta]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}], "\[And]", 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "\[CirclePlus]", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["\[Delta]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], "]"}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"l3+"],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3:)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox["f",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["a",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}], ":=", 
            RowBox[{
              UnderscriptBox["\[Exists]", 
                RowBox[{
                  StyleBox["N",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], " "}]], 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["N",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"l3:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["M",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Delta]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Delta]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["M",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}], "\[And]", 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["N",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "\[CirclePlus]", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["\[Delta]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{"max", "[", 
                  RowBox[{
                    StyleBox["M",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ",", 
                    StyleBox["N",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "]"}]}], "]"}]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->"l4+"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+",
      ButtonData:>"l3+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we take all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"limit", "[", 
            RowBox[{
              StyleBox[\(f\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(a\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(\[Delta]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "]"}], "\[And]", 
          RowBox[{"limit", "[", 
            RowBox[{
              StyleBox[\(g\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(b\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(\[Epsilon]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "]"}]}], "\[Implies]", 
        RowBox[{"limit", "[", 
          RowBox[{
            RowBox[{
              StyleBox[\(f\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[CirclePlus]", 
              StyleBox[\(g\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ",", 
            RowBox[{
              StyleBox[\(a\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(b\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ",", 
            RowBox[{
              StyleBox[\(\[Delta]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(\[Epsilon]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l3+'"],

Cell[TextData[{
  "We prove ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'",
      ButtonData:>"l3+'",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by the deduction rule."
}], "Text"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+'.A)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Delta]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}], "\[And]", 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  " "
}], "Assumption",
  CellTags->"l3+'.A"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+'.C)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "\[CirclePlus]", 
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(\[Delta]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l3+'.C"],

Cell[TextData[{
  "The conjunction ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.A",
      ButtonData:>"l3+'.A",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " splits into ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.A.1",
      ButtonData:>"l3+'.A.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.A.2",
      ButtonData:>"l3+'.A.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C",
      ButtonData:>"l3+'.C",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by the definition ",
  Cell[TextData[{
    "(",
    ButtonBox["l3:",
      ButtonData:>"l3:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", it suffices to prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+'.C')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"limit", "[", 
          RowBox[{
            RowBox[{
              StyleBox[\(f\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[CirclePlus]", 
              StyleBox[\(g\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ",", 
            RowBox[{
              StyleBox[\(a\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(b\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ",", 
            RowBox[{
              StyleBox[\(\[Delta]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(\[Epsilon]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ",", 
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l3+'.C'"],

Cell[TextData[{
  "The formula ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.A.1",
      ButtonData:>"l3+'.A.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is expanded by the definition ",
  Cell[TextData[{
    "(",
    ButtonBox["l3:",
      ButtonData:>"l3:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " into:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+'.A.1')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Delta]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"l3+'.A.1'"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.A.1'",
      ButtonData:>"l3+'.A.1'",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take appropriate values such that:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+'.A.1'')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(f\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(a\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(\[Delta]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(N\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "]"}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"l3+'.A.1''"],

Cell[TextData[{
  "The formula ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.A.2",
      ButtonData:>"l3+'.A.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is expanded by the definition ",
  Cell[TextData[{
    "(",
    ButtonBox["l3:",
      ButtonData:>"l3:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " into:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+'.A.2')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"l3+'.A.2'"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.A.2'",
      ButtonData:>"l3+'.A.2'",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take appropriate values such that:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+'.A.2'')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(g\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(b\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(N\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "]"}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"l3+'.A.2''"],

Cell[TextData[{
  "Because a literal of the formula ",
  Cell[TextData[{
    "(",
    ButtonBox["l4+",
      ButtonData:>"l4+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " matches the goal ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C'",
      ButtonData:>"l3+'.C'",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", we specialize it to:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+'.C'')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["M",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox[\(a\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox[\(\[Delta]\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["M",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}], "\[And]", 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox[\(g\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox[\(b\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox[\(\[Epsilon]\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["N",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "\[CirclePlus]", 
                  StyleBox[\(g\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox[\(a\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(b\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox[\(\[Delta]\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(\[Epsilon]\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{"max", "[", 
                  RowBox[{
                    StyleBox["M",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ",", 
                    StyleBox["N",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "]"}]}], "]"}]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->"l3+'.C''"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C'",
      ButtonData:>"l3+'.C'",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C''",
      ButtonData:>"l3+'.C''",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", it suffices to prove"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+'.C'.A)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["M",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox[\(f\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox[\(a\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox[\(\[Delta]\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["M",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}], "\[And]", 
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox[\(g\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox[\(b\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox[\(\[Epsilon]\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["N",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l3+'.C'.A"],

Cell[TextData[{
  "Because ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.A.1''",
      ButtonData:>"l3+'.A.1''",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " matches a part of ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C'.A",
      ButtonData:>"l3+'.C'.A",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", we can proceed in several ways."
}], "Text"],

Cell["Alternative proof 1: proved", "Text"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C'.A",
      ButtonData:>"l3+'.C'.A",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " it is sufficient to prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+'.C'.A/2)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox[\(f\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox[\(a\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox[\(\[Delta]\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox[\(N\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}], "\[And]", 
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox[\(g\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox[\(b\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox[\(\[Epsilon]\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["N",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l3+'.C'.A/2"],

Cell[TextData[{
  "Because ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.A.2''",
      ButtonData:>"l3+'.A.2''",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " matches a part of ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C'.A/2",
      ButtonData:>"l3+'.C'.A/2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", we can proceed in several ways."
}], "Text"],

Cell["Alternative proof 1: proved", "Text"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C'.A/2",
      ButtonData:>"l3+'.C'.A/2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " it is sufficient to prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+'.C'.A/2/1)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Delta]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(N\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}], "\[And]", 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(N\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l3+'.C'.A/2/1"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C'.A/2/1",
      ButtonData:>"l3+'.C'.A/2/1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C'.A/2/1.1",
      ButtonData:>"l3+'.C'.A/2/1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(f\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(a\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(\[Delta]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(N\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "]"}]], "Expression",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C'.A/2/1.1",
      ButtonData:>"l3+'.C'.A/2/1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.A.1''",
      ButtonData:>"l3+'.A.1''",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C'.A/2/1.2",
      ButtonData:>"l3+'.C'.A/2/1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(g\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(b\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(N\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "]"}]], "Expression",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C'.A/2/1.2",
      ButtonData:>"l3+'.C'.A/2/1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.A.2''",
      ButtonData:>"l3+'.A.2''",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell["Alternative proof 2: pending", "Text"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C'.A/2",
      ButtonData:>"l3+'.C'.A/2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text",
  Background->GrayLevel[0.659998]],

Cell["Alternative proof 2: pending", "Text"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+'.C'.A",
      ButtonData:>"l3+'.C'.A",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text",
  Background->GrayLevel[0.659998]]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof  Sum 2-ary Limit", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l2+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}], "\[And]", 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "\[CirclePlus]", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], "]"}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"l2+"],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l2:)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox["f",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["a",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}], ":=", 
            RowBox[{
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], " "}]], 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"l2:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  FractionBox[
                    StyleBox["\[Epsilon]",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "2"]}], "]"}], "\[And]", 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  FractionBox[
                    StyleBox["\[Epsilon]",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "2"]}], "]"}]}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "\[CirclePlus]", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"l3+"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+",
      ButtonData:>"l2+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we take all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l2+')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"limit", "[", 
            RowBox[{
              StyleBox[\(f\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(a\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "]"}], "\[And]", 
          RowBox[{"limit", "[", 
            RowBox[{
              StyleBox[\(g\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(b\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "]"}]}], "\[Implies]", 
        RowBox[{"limit", "[", 
          RowBox[{
            RowBox[{
              StyleBox[\(f\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[CirclePlus]", 
              StyleBox[\(g\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ",", 
            RowBox[{
              StyleBox[\(a\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(b\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l2+'"],

Cell[TextData[{
  "We prove ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'",
      ButtonData:>"l2+'",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by the deduction rule."
}], "Text"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l2+'.A)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}], "\[And]", 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  " "
}], "Assumption",
  CellTags->"l2+'.A"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l2+'.C)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "\[CirclePlus]", 
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l2+'.C"],

Cell[TextData[{
  "The conjunction ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.A",
      ButtonData:>"l2+'.A",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " splits into ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.A.1",
      ButtonData:>"l2+'.A.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.A.2",
      ButtonData:>"l2+'.A.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.C",
      ButtonData:>"l2+'.C",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by the definition ",
  Cell[TextData[{
    "(",
    ButtonBox["l2:",
      ButtonData:>"l2:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", it suffices to prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l2+'.C')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"limit", "[", 
          RowBox[{
            RowBox[{
              StyleBox[\(f\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[CirclePlus]", 
              StyleBox[\(g\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ",", 
            RowBox[{
              StyleBox[\(a\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(b\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l2+'.C'"],

Cell[TextData[{
  "The formula ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.A.1",
      ButtonData:>"l2+'.A.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is expanded by the definition ",
  Cell[TextData[{
    "(",
    ButtonBox["l2:",
      ButtonData:>"l2:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " into:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l2+'.A.1')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"l2+'.A.1'"],

Cell[TextData[{
  "The formula ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.A.2",
      ButtonData:>"l2+'.A.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is expanded by the definition ",
  Cell[TextData[{
    "(",
    ButtonBox["l2:",
      ButtonData:>"l2:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " into:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l2+'.A.2')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"l2+'.A.2'"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.C'",
      ButtonData:>"l2+'.C'",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we take all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l2+'.C'')", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "\[CirclePlus]", 
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l2+'.C''"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.C''",
      ButtonData:>"l2+'.C''",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+",
      ButtonData:>"l3+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", it suffices to prove"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l2+'.C''.A)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            FractionBox[
              StyleBox[\(\[Epsilon]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "2"]}], "]"}], "\[And]", 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            FractionBox[
              StyleBox[\(\[Epsilon]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "2"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"l2+'.C''.A"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.C''.A",
      ButtonData:>"l2+'.C''.A",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.C''.A.1",
      ButtonData:>"l2+'.C''.A.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(f\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(a\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          FractionBox[
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "2"]}], "]"}]], "Expression",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.C''.A.1",
      ButtonData:>"l2+'.C''.A.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is proved because it is an instance of ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.A.1'",
      ButtonData:>"l2+'.A.1'",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.C''.A.2",
      ButtonData:>"l2+'.C''.A.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(g\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(b\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          FractionBox[
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "2"]}], "]"}]], "Expression",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.C''.A.2",
      ButtonData:>"l2+'.C''.A.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is proved because it is an instance of ",
  Cell[TextData[{
    "(",
    ButtonBox["l2+'.A.2'",
      ButtonData:>"l2+'.A.2'",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof  Attempt 1- Multiplication Commutativity", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * )", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->" * "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( *0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}], "=", "0"}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" *0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * ^+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" * ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + ^+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" + ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0+ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"^++ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + ) + )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"( + ) + "],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ",
      ButtonData:>" * ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails.(The Simplifier was unable to transform the proof situation.)"
}], "Text"],

Cell["Alternative proof 2: failed", "Text"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ",
      ButtonData:>" * ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IB"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: proved", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IB",
      ButtonData:>" * .IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IB.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", "0"}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->" * .IB.F"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "*", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IB.S)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", "0"}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IB.S"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IB.S",
      ButtonData:>" * .IB.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IB.S.IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      \(0*0 = 0\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IB.S.IB"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IB.S.IB",
      ButtonData:>" * .IB.S.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0*0\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IB.S.IH)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", "0"}]], "Assumption"]
}], "Assumption",
  CellTags->" * .IB.S.IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IB.S.IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          SuperscriptBox[
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", "0"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IB.S.IS"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IB.S.IS",
      ButtonData:>" * .IB.S.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        SuperscriptBox[
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IB.S.IH",
      ButtonData:>" * .IB.S.IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Alternative proof 2: pending", "Text"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IB",
      ButtonData:>" * .IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text",
  Background->GrayLevel[0.659998]],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IH)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->" * .IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS",
      ButtonData:>" * .IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->" * .IS.F"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", 
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "*", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IH",
      ButtonData:>" * .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.S)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.S"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.S",
      ButtonData:>" * .IS.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.S.IB)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", "0"}], "=", 
        RowBox[{
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", "0"}], "+", "0"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.S.IB"],

Cell[TextData[{
  "We simplify ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.S.IB",
      ButtonData:>" * .IS.S.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", "0"}], "+", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IH",
      ButtonData:>" * .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.S.IB.S)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{"0", "=", 
        RowBox[{"0", "*", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.S.IB.S"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.S.IB.S",
      ButtonData:>" * .IS.S.IB.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails.(No applicable inference rule was found.)"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.S.IH)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "+", 
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Assumption"]
}], "Assumption",
  CellTags->" * .IS.S.IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.S.IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          SuperscriptBox[
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            SuperscriptBox[
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], "+", 
          SuperscriptBox[
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.S.IS"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.S.IS",
      ButtonData:>" * .IS.S.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text",
  Background->GrayLevel[0.659998]],

Cell["Alternative proof 2: failed", "Text"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS",
      ButtonData:>" * .IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.IB)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", "0"}], "=", 
        RowBox[{"0", "*", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.IB"],

Cell[TextData[{
  "We simplify ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.IB",
      ButtonData:>" * .IS.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.IB.S)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"0", "=", 
        RowBox[{"0", "*", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.IB.S"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.IB.S",
      ButtonData:>" * .IS.IB.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails.(No applicable inference rule was found.)"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.IH)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(n\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Assumption"]
}], "Assumption",
  CellTags->" * .IS.IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.IS)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          SuperscriptBox[
            StyleBox[\(n\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.IS"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.IS",
      ButtonData:>" * .IS.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text",
  Background->GrayLevel[0.659998]]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof   Multiplication 0 From Left", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0* )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", "0"}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"0* "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( *0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}], "=", "0"}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" *0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * ^+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" * ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + ^+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" + ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0+ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ )", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"^++ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + ) + )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"( + ) + "],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["0* ",
      ButtonData:>"0* ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails.(The Simplifier was unable to transform the proof situation.)"
}], "Text"],

Cell["Alternative proof 2: proved", "Text"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["0* ",
      ButtonData:>"0* ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0* .IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      \(0*0 = 0\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"0* .IB"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["0* .IB",
      ButtonData:>"0* .IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0*0\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0* .IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", "0"}]], "Assumption"]
}], "Assumption",
  CellTags->"0* .IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0* .IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", "0"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"0* .IS"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["0* .IS",
      ButtonData:>"0* .IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        SuperscriptBox[
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0* .IH",
      ButtonData:>"0* .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof  Attempt 2- Multiplication Commutativity", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * )", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->" * "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( *0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}], "=", "0"}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" *0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * ^+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" * ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + ^+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" + ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0+ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"^++ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + ) + )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"( + ) + "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0* )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", "0"}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"0* "],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ",
      ButtonData:>" * ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails.(The Simplifier was unable to transform the proof situation.)"
}], "Text"],

Cell["Alternative proof 2: failed", "Text"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ",
      ButtonData:>" * ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IB"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: proved", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IB",
      ButtonData:>" * .IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IB.F)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", "0"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IB.F"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IB.F",
      ButtonData:>" * .IB.F",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0* ",
      ButtonData:>"0* ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "*", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Alternative proof 2: pending", "Text"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IB",
      ButtonData:>" * .IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text",
  Background->GrayLevel[0.659998]],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->" * .IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS",
      ButtonData:>" * .IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->" * .IS.F"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", 
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "*", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IH",
      ButtonData:>" * .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.S)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.S"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.S",
      ButtonData:>" * .IS.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.S.IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", "0"}], "=", 
        RowBox[{
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", "0"}], "+", "0"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.S.IB"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.S.IB",
      ButtonData:>" * .IS.S.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", "0"}], "+", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IH",
      ButtonData:>" * .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0* ",
      ButtonData:>"0* ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.S.IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "+", 
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Assumption"]
}], "Assumption",
  CellTags->" * .IS.S.IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.S.IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], "+", 
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.S.IS"],

Cell[TextData[{
  "We simplify ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.S.IS",
      ButtonData:>" * .IS.S.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", 
        SuperscriptBox[
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.S.IH",
      ButtonData:>" * .IS.S.IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "+", 
        SuperscriptBox[
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+", 
        SuperscriptBox[
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+", 
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.S.IS.S)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}], "+"], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}], "+"]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.S.IS.S"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.S.IS.S",
      ButtonData:>" * .IS.S.IS.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails.(No applicable inference rule was found.)"
}], "Text"],

Cell["Alternative proof 2: failed", "Text"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS",
      ButtonData:>" * .IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", "0"}], "=", 
        RowBox[{"0", "*", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.IB"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.IB",
      ButtonData:>" * .IS.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", "0"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0* ",
      ButtonData:>"0* ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Assumption"]
}], "Assumption",
  CellTags->" * .IS.IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          SuperscriptBox[
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.IS"],

Cell[TextData[{
  "We simplify ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.IS",
      ButtonData:>" * .IS.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", 
        SuperscriptBox[
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.IH",
      ButtonData:>" * .IS.IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IH",
      ButtonData:>" * .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        SuperscriptBox[
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IH",
      ButtonData:>" * .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          SuperscriptBox[
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "+", 
        SuperscriptBox[
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+", 
        SuperscriptBox[
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+", 
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.IS.S)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}], "+"], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(n\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}], "+"]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.IS.S"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.IS.S",
      ButtonData:>" * .IS.IS.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails.(No applicable inference rule was found.)"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof  Multiplication Commutativity", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->" * "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( *0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}], "=", "0"}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" *0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * ^+)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" * ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + ^+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" + ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0+ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"^++ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + ) + )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"( + ) + "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" + "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0* )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", "0"}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"0* "],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ",
      ButtonData:>" * ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails.(The Simplifier was unable to transform the proof situation.)"
}], "Text"],

Cell["Alternative proof 2: proved", "Text"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ",
      ButtonData:>" * ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IB"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: proved", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IB",
      ButtonData:>" * .IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IB.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", "0"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IB.F"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IB.F",
      ButtonData:>" * .IB.F",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0* ",
      ButtonData:>"0* ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "*", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Alternative proof 2: pending", "Text"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IB",
      ButtonData:>" * .IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text",
  Background->GrayLevel[0.659998]],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->" * .IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: proved", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS",
      ButtonData:>" * .IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->" * .IS.F"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", 
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "*", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IH",
      ButtonData:>" * .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.S)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.S"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.S",
      ButtonData:>" * .IS.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.S.IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", "0"}], "=", 
        RowBox[{"0", "+", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", "0"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.S.IB"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.S.IB",
      ButtonData:>" * .IS.S.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", "0"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IH",
      ButtonData:>" * .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"0", "*", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0+ ",
      ButtonData:>"0+ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0* ",
      ButtonData:>"0* ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.S.IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->" * .IS.S.IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( * .IS.S.IS)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->" * .IS.S.IS"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.S.IS",
      ButtonData:>" * .IS.S.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", 
        SuperscriptBox[
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS.S.IH",
      ButtonData:>" * .IS.S.IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" * ^+",
      ButtonData:>" * ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ ",
      ButtonData:>"^++ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Alternative proof 2: pending", "Text"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" * .IS",
      ButtonData:>" * .IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text",
  Background->GrayLevel[0.659998]]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof  Multiplication Associativity with Addition AC in KB", \
"Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"( * ) * "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( *0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}], "=", "0"}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" *0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( *  ^+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" *  ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0*)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", "0"}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0*"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( ^+*)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" ^+*"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + ^+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" + ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0+ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"^++ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" + "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + ) + )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"( + ) + "],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * ",
      ButtonData:>"( * ) * ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails.(The Simplifier was unable to transform the proof situation.)"
}], "Text"],

Cell["Alternative proof 2: proved", "Text"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * ",
      ButtonData:>"( * ) * ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IB)", "Label"],
  Cell["", "Blank"],
  "  ",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"0", "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{"0", "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IB"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: proved", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IB",
      ButtonData:>"( * ) * .IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IB.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"0", "*", 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{"0", "*", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IB.F"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IB.F",
      ButtonData:>"( * ) * .IB.F",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"0", "*", 
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Alternative proof 2: pending", "Text"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IB",
      ButtonData:>"( * ) * .IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text",
  Background->GrayLevel[0.659998]],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"( * ) * .IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: proved", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS",
      ButtonData:>"( * ) * .IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"( * ) * .IS.F"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "*", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "*", 
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}], "+", 
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IH",
      ButtonData:>"( * ) * .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S",
      ButtonData:>"( * ) * .IS.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", "0"}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{"0", "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", "0"}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IB"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: proved", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IB",
      ButtonData:>"( * ) * .IS.S.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IB.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"0", "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", "0"}]}], ")"}], "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          RowBox[{"0", "*", 
            StyleBox[\(p\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", "0"}], ")"}], "*", 
            StyleBox[\(p\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IB.F"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IB.F",
      ButtonData:>"( * ) * .IS.S.IB.F",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"0", "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}]}], ")"}], "*", 
        StyleBox[\(p\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{\((0 + 0)\), "*", 
        StyleBox[\(p\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(p\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}], ")"}], "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Alternative proof 2: pending", "Text"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IB",
      ButtonData:>"( * ) * .IS.S.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text",
  Background->GrayLevel[0.659998]],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"( * ) * .IS.S.IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    SuperscriptBox[
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+"]}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    SuperscriptBox[
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+"]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IS"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IS",
      ButtonData:>"( * ) * .IS.S.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "*", 
            StyleBox[\(p\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], ")"}], "*", 
            StyleBox[\(p\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IS.F"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ ",
      ButtonData:>"^++ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}], "+"], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(p\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(p\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(p\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS.S)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], "=", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["p",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IS.S"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IS.S",
      ButtonData:>"( * ) * .IS.S.IS.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["p",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS.S.IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "*", "0"}]}], "=", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"0", "+", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", "0"}]}], ")"}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "*", "0"}]}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IS.S.IB"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IS.S.IB",
      ButtonData:>"( * ) * .IS.S.IS.S.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "*", "0"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"0", "+", 
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}]}], ")"}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "*", "0"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{\((0 + 0)\), "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "*", "0"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\((0 + 0)\) + 0\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS.S.IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "*", 
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}], "=", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "*", 
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"( * ) * .IS.S.IS.S.IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS.S.IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}]}], "=", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IS.S.IS"],

Cell[TextData[{
  "We simplify ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IS.S.IS",
      ButtonData:>"( * ) * .IS.S.IS.S.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "*", 
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ ",
      ButtonData:>"^++ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], ")"}], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}]}], ")"}], "+"]],
     "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], ")"}], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}]}], ")"}], "+", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "*", 
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "*", 
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ ",
      ButtonData:>"^++ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}], "+"], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ ",
      ButtonData:>"^++ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_5\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}]}], ")"}], "+"]],
     "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_5\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}]}], ")"}], "+"]],
     "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_5\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(p\_5\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(p\_5\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}]}], ")"}], 
            "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}], "+", 
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_5\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_5\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(p\_5\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{"(", 
                          RowBox[{
                            StyleBox[\(m\_1\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "+", 
                            RowBox[{
                              StyleBox[\(m\_1\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "*", 
                              StyleBox[\(n\_3\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]}], ")"}]}], ")"}], "+", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(p\_5\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{"(", 
                          RowBox[{
                            StyleBox[\(m\_1\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "+", 
                            RowBox[{
                              StyleBox[\(m\_1\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "*", 
                              StyleBox[\(n\_3\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]}], ")"}]}], ")"}]}], 
                  ")"}], "+", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        StyleBox[\(p\_5\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}], "+", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            StyleBox[\(n\_3\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "+", 
                            StyleBox[\(p\_5\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], ")"}], "+", 
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{"(", 
                          RowBox[{
                            StyleBox[\(n\_3\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "+", 
                            StyleBox[\(p\_5\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], ")"}]}], ")"}], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            StyleBox[\(m\_1\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "+", 
                            StyleBox[\(n\_3\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], ")"}], "+", 
                        StyleBox[\(p\_5\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(p\_5\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{"(", 
                          RowBox[{
                            StyleBox[\(m\_1\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "+", 
                            StyleBox[\(n\_3\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], ")"}]}], ")"}], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS.S.IS.S)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(p\_5\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], ")"}]}], ")"}], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "+"], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(p\_5\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          RowBox[{"(", 
                            RowBox[{
                              StyleBox[\(m\_1\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "+", 
                              StyleBox[\(n\_3\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], ")"}]}], ")"}], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "+", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IS.S.IS.S"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IS.S.IS.S",
      ButtonData:>"( * ) * .IS.S.IS.S.IS.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails.(No applicable inference rule was found.)"
}], "Text"],

Cell["Alternative proof 2: proved", "Text"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IS",
      ButtonData:>"( * ) * .IS.S.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["p",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS.IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}], "*", "0"}], "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "*", "0"}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], ")"}], "*", "0"}]}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IS.IB"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IS.IB",
      ButtonData:>"( * ) * .IS.S.IS.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}], "*", "0"}]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", "0"}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "*", "0"}]}]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IH",
      ButtonData:>"( * ) * .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", "0"}], "+", 
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", "0"}], ")"}]}]}]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", "0"}], ")"}]}]}]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", "0"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS.IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}], "*", 
          StyleBox[\(p\_6\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "*", 
            StyleBox[\(p\_6\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], ")"}], "*", 
            StyleBox[\(p\_6\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"( * ) * .IS.S.IS.IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS.IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}], "*", 
          SuperscriptBox[
            StyleBox[\(p\_6\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "*", 
            SuperscriptBox[
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IS.IS"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IS.IS",
      ButtonData:>"( * ) * .IS.S.IS.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}], "*", 
        SuperscriptBox[
          StyleBox[\(p\_6\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}], "*", 
          StyleBox[\(p\_6\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IS.IH",
      ButtonData:>"( * ) * .IS.S.IS.IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  SuperscriptBox[
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ ",
      ButtonData:>"^++ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}], "+"]}]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          SuperscriptBox[
            StyleBox[\(p\_6\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "*", 
          SuperscriptBox[
            StyleBox[\(p\_6\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "*", 
          SuperscriptBox[
            StyleBox[\(p\_6\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  SuperscriptBox[
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ ",
      ButtonData:>"^++ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(p\_6\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(p\_6\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}]}], ")"}], 
            "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}], "+", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Alternative proof 2: pending", "Text"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS",
      ButtonData:>"( * ) * .IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text",
  Background->GrayLevel[0.659998]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Proof  Multiplication Associativity with Addition AC  as Iference Rule\
\>", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"( * ) * "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( *0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}], "=", "0"}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" *0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( *  ^+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" *  ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0*)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", "0"}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0*"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( ^+*)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" ^+*"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + ^+)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" + ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0+ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ )", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->"^++ "],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * ",
      ButtonData:>"( * ) * ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"0", "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{"0", "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IB"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IB",
      ButtonData:>"( * ) * .IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IB.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"0", "*", 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{"0", "*", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IB.F"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IB.F",
      ButtonData:>"( * ) * .IB.F",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"0", "*", 
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " = ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"( * ) * .IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS",
      ButtonData:>"( * ) * .IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"( * ) * .IS.F"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "*", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl ",
      ButtonData:>"Special Simpl ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "*", 
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}], "+", 
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IH",
      ButtonData:>"( * ) * .IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl ",
      ButtonData:>"Special Simpl ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S",
      ButtonData:>"( * ) * .IS.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", "0"}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{"0", "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", "0"}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IB"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IB",
      ButtonData:>"( * ) * .IS.S.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IB.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"0", "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", "0"}]}], ")"}], "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          RowBox[{"0", "*", 
            StyleBox[\(p\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", "0"}], ")"}], "*", 
            StyleBox[\(p\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IB.F"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IB.F",
      ButtonData:>"( * ) * .IS.S.IB.F",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"0", "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}]}], ")"}], "*", 
        StyleBox[\(p\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{\((0 + 0)\), "*", 
        StyleBox[\(p\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(p\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}], ")"}], "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"( * ) * .IS.S.IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    SuperscriptBox[
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+"]}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    SuperscriptBox[
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+"]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IS"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IS",
      ButtonData:>"( * ) * .IS.S.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS.F)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "*", 
            StyleBox[\(p\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], ")"}], "*", 
            StyleBox[\(p\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IS.F"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "+", 
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "+"], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl ",
      ButtonData:>"Special Simpl ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(p\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl ",
      ButtonData:>"Special Simpl ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS.S)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], "=", 
            RowBox[{
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["p",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}], "*", 
                    StyleBox["p",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IS.S"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IS.S",
      ButtonData:>"( * ) * .IS.S.IS.S",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["p",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS.S.IB)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "*", "0"}]}], 
        "=", 
        RowBox[{"0", "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", "0"}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", "0"}]}], 
            ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IS.S.IB"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IS.S.IB",
      ButtonData:>"( * ) * .IS.S.IS.S.IB",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "*", "0"}]}]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", "0"}]}], ")"}]}]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"(", 
          RowBox[{"0", "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", "0"}]}], ")"}]}]], 
    "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + \((0 + 0)\)\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\((0 + 0)\) + 0\)], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS.S.IH)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "*", 
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}], "=", 
        RowBox[{
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"( * ) * .IS.S.IS.S.IH"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * .IS.S.IS.S.IS)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                SuperscriptBox[
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"( * ) * .IS.S.IS.S.IS"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IS.S.IS",
      ButtonData:>"( * ) * .IS.S.IS.S.IS",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "*", 
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "*", 
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "+", 
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}]}], ")"}], "+", 
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          RowBox[{"(", 
                            RowBox[{
                              StyleBox[\(n\_3\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "+", 
                              RowBox[{
                                StyleBox[\(m\_1\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "*", 
                                StyleBox[\(n\_3\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}]}], ")"}]}], ")"}], "*", 
                      
                      StyleBox[\(p\_5\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}]}], ")"}], "+", 
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{
                              StyleBox[\(m\_1\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "+", 
                              RowBox[{"(", 
                                RowBox[{
                                  StyleBox[\(n\_3\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "+", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "*", 
                                    StyleBox[\(n\_3\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], ")"}]}], ")"}], 
                          "*", 
                          StyleBox[\(p\_5\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}]}], ")"}], 
            "+", 
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "^", "+"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(p\_5\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{
                              StyleBox[\(m\_1\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "+", 
                              RowBox[{"(", 
                                RowBox[{
                                  StyleBox[\(n\_3\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "+", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "*", 
                                    StyleBox[\(n\_3\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], ")"}]}], ")"}], 
                          "*", 
                          StyleBox[\(p\_5\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}]}], ")"}], "^", 
        "+"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * .IS.S.IS.S.IH",
      ButtonData:>"( * ) * .IS.S.IS.S.IH",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(p\_5\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(n\_3\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], "+", 
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  StyleBox[\(m\_1\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "+", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "*", 
                                    StyleBox[\(n\_3\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], ")"}], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]}], ")"}]}], ")"}], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}]}], ")"}], "^", 
        "+"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl ",
      ButtonData:>"Special Simpl ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(n\_3\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], "+", 
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  StyleBox[\(m\_1\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "+", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "*", 
                                    StyleBox[\(n\_3\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], ")"}], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]}], ")"}]}], ")"}]}], 
                  ")"}]}], ")"}]}], ")"}], "^", "+"}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "+", 
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "+", 
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "+", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "+", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "  by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "+", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(p\_5\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{
                              StyleBox[\(m\_1\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "+", 
                              RowBox[{
                                StyleBox[\(m\_1\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "*", 
                                StyleBox[\(n\_3\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}]}], ")"}], "*", 
                          StyleBox[\(p\_5\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}]}], ")"}]}], 
          ")"}], "+", 
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(n\_3\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], "+", 
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  StyleBox[\(m\_1\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "+", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "*", 
                                    StyleBox[\(n\_3\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], ")"}], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]}], ")"}]}], ")"}]}], 
                  ")"}]}], ")"}], "+", 
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "^", "+"}]], "Expression"],
  " =  ",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl ",
      ButtonData:>"Special Simpl ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(n\_3\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], "+", 
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  StyleBox[\(m\_1\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "+", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "*", 
                                    StyleBox[\(n\_3\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], ")"}], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]}], ")"}]}], ")"}]}], 
                  ")"}]}], ")"}]}], ")"}], "^", "+"}]], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof  by Groebner Bases", "Subsection"],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(f=0)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["y",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          SuperscriptBox[
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "3"], "*", 
                          SuperscriptBox[
                            StyleBox["y",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "4"]}], "+", \(27*xy\^3\)}], 
                      ")"}], "-", 
                    RowBox[{"15", "*", 
                      SuperscriptBox[
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "3"]}]}], "=", "0"}], ")"}], 
              "\[And]", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(1\/5\), "*", 
                          SuperscriptBox[
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "2"], "*", 
                          StyleBox["y",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "-", 
                        RowBox[{"23", "*", 
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox["y",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}], "+", "17"}], "=", 
                  "0"}], ")"}]}], "\[Implies]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"225", "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "3"]}], 
                  "+", \(\((\(-405\))\)*xy\^3\), "+", 
                  RowBox[{"255", "*", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{\((\(-15\))\), "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "4"], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{"27", "*", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", \(xy\^3\), "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{\((\(-328\))\), "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"]}], "+", 
                  RowBox[{"3", "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "3"], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"]}], "+", 
                  RowBox[{\((\(-23\))\), "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "3"], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "3"]}], "+", 
                  FractionBox[
                    RowBox[{
                      SuperscriptBox[
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "4"], "*", 
                      SuperscriptBox[
                        StyleBox["y",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "3"]}], "5"], "+", 
                  RowBox[{\((\(-15\))\), "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "3"], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "4"]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "4"], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "5"]}]}], "=", "0"}], ")"}]}], 
          ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"f=0"],

Cell["with no assumptions.", "Text"],

Cell["Proved.", "Text"],

Cell["\<\
The Theorem is proved by the Groebner Bases method.      

      The formula in the scope of the universal quantifier is transformed \
into an equivalent formula that is a conjunction of disjunctions of \
equalities and negated equalities. The universal quantifier can then be \
distributed over the individual parts of the conjunction. By this, we obtain:\
\
\>", "Text"],

Cell["Independent proof problems:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(f=0.1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{\(\[ForAll] \+\(x, y\)\), 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(\(-405\)*xy\^3\), "+", 
                  RowBox[{"225", "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "3"]}], "+", 
                  RowBox[{"255", "*", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{"27", "*", \(xy\^3\), "*", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{\(-15\), "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "4"], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{\(-328\), "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"]}], "+", 
                  RowBox[{"3", "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "3"], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"]}], "+", 
                  RowBox[{\(-23\), "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "3"], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "3"]}], "+", 
                  RowBox[{\(1\/5\), "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "4"], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "3"]}], "+", 
                  RowBox[{\(-15\), "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "3"], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "4"]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "4"], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "5"]}]}], "=", "0"}], ")"}], 
            "\[Or]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(27*xy\^3\), "+", 
                  RowBox[{\(-15\), "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "3"]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "3"], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "4"]}]}], "\[NotEqual]", "0"}], 
              ")"}], "\[Or]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"17", "+", 
                  RowBox[{\(-23\), "*", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{\(1\/5\), "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], "\[NotEqual]", "0"}], ")"}]}], 
          ")"}]}]], "Conclusion"],
  " "
}], "Conclusion",
  CellTags->"f=0.1"],

Cell["We now prove the above individual problems separately:", "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["f=0.1",
      ButtonData:>"f=0.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "Text"],

Cell["This proof problem has the following structure:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(f=0.1.structure)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[ForAll] \+\(x, y\)\((\((Poly[1] \[NotEqual] 
                0)\) \[Or] \((Poly[2] \[NotEqual] 0)\) \[Or] \((Poly[3] = 
                0)\))\)\)], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"f=0.1.structure"],

Cell["where", "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {\(\(Poly[1]\)\(\ \)\(=\)\), 
          RowBox[{"17", "+", 
            RowBox[{\(-23\), "*", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{\(1\/5\), "*", 
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"], "*", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}]},
        {\(\(Poly[2]\)\(\ \)\(=\)\), 
          RowBox[{\(27*xy\^3\), "+", 
            RowBox[{\(-15\), "*", 
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "3"]}], "+", 
            RowBox[{
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "3"], "*", 
              SuperscriptBox[
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "4"]}]}]},
        {\(\(Poly[3]\)\(\ \)\(=\)\), 
          RowBox[{\(\(-405\)*xy\^3\), "+", 
            RowBox[{"225", "*", 
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "3"]}], "+", 
            RowBox[{"255", "*", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"27", "*", \(xy\^3\), "*", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{\(-15\), "*", 
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "4"], "*", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{\(-328\), "*", 
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"], "*", 
              SuperscriptBox[
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"]}], "+", 
            RowBox[{"3", "*", 
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "3"], "*", 
              SuperscriptBox[
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"]}], "+", 
            RowBox[{\(-23\), "*", 
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "3"], "*", 
              SuperscriptBox[
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "3"]}], "+", 
            RowBox[{\(1\/5\), "*", 
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "4"], "*", 
              SuperscriptBox[
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "3"]}], "+", 
            RowBox[{\(-15\), "*", 
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "3"], "*", 
              SuperscriptBox[
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "4"]}], "+", 
            RowBox[{
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "4"], "*", 
              SuperscriptBox[
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "5"]}]}]}
        },
      ColumnAlignments->{Left}]]]], "Text"],

Cell[TextData[{
  Cell[TextData[{
    "(",
    ButtonBox["f=0.1.structure",
      ButtonData:>"f=0.1.structure",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is equivalent to"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(f=0.1.implication)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[ForAll] \+\(x, y\)\((\((Poly[1] = 0)\) \[And] \((Poly[2] = 
                  0)\) \[Implies] \((Poly[3] = 0)\))\)\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"f=0.1.implication"],

Cell[TextData[{
  Cell[TextData[{
    "(",
    ButtonBox["f=0.1.implication",
      ButtonData:>"f=0.1.implication",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is equivalent to"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(f=0.1.not-exists)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[NotExists] \+\(x, y\)\((\((\((Poly[1] = 0)\) \[And] \((Poly[2] = 
                    0)\))\) \[And] \((Poly[3] \[NotEqual] 0)\))\)\)], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"f=0.1.not-exists"],

Cell["By introducing the slack variable(s)", "Text"],

Cell["{\[Xi]}", "Text"],

Cell[TextData[{
  Cell[TextData[{
    "(",
    ButtonBox["f=0.1.not-exists",
      ButtonData:>"f=0.1.not-exists",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is transformed into the equivalent formula"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(f=0.1.not-exists-slack)", "Label"],
  "  ",
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[NotExists] \+\(x, y, \[Xi]\)\((\((\((Poly[1] = 
                    0)\) \[And] \((Poly[2] = 
                    0)\))\) \[And] \((\(-1\) + \[Xi]\ Poly[3] = 0)\))\)\)], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"f=0.1.not-exists-slack"],

Cell["\<\
Hence, we see that the proof problem is transformed into the question on \
whether or not a system of polynomial equations has a solution or not. This \
question can be answered by checking whether or not the (reduced) Groebner \
basis of\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \({Poly[1], Poly[2], \(-1\) + \[Xi]\ Poly[3]}\)]]], "Text"],

Cell["\<\
is exactly {1}.                  

Hence, we compute the Groebner basis for the following polynomial list:\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \({\(-1\) + 225\ x\^3\ \[Xi] + \(-405\)\ xy\^3\ \[Xi] + 
        255\ x\ y\ \[Xi] + \(-15\)\ x\^4\ y\ \[Xi] + 
        27\ x\ xy\^3\ y\ \[Xi] + \(-328\)\ x\^2\ y\^2\ \[Xi] + 
        3\ x\^3\ y\^2\ \[Xi] + \(-23\)\ x\^3\ y\^3\ \[Xi] + 
        1\/5\ x\^4\ y\^3\ \[Xi] + \(-15\)\ x\^3\ y\^4\ \[Xi] + 
        x\^4\ y\^5\ \[Xi], \(-15\)\ x\^3 + 27\ xy\^3 + x\^3\ y\^4, 
      17 + \(-23\)\ x\ y + \(x\^2\ y\)\/5}\)]]], "Text"],

Cell["The Groebner basis:", "Text"],

Cell[TextData[Cell[BoxData[
    \({1}\)]]], "Text"],

Cell[TextData[{
  "Hence, ",
  Cell[TextData[{
    "(",
    ButtonBox["f=0.1",
      ButtonData:>"f=0.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is ",
  "proved."
}], "Text"],

Cell["\<\
Since all of the individual subtheorems are proved, the original formula is \
proved.\
\>", "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowToolbars->"EditBar",
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 26}},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    AutoItalicWords->{"Theorema"},
    LimitsPositioningTokens->{},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 0]],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names. \
Some attributes for these styles are actually set in FormatType Styles (in \
the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Times New Roman",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9,
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Addition"->{
    Cell[12491, 410, 418, 11, 122, "Input",
      CellTags->"Addition"]},
  "Addition of Zero from Left"->{
    Cell[14858, 502, 390, 11, 88, "Input",
      CellTags->"Addition of Zero from Left"]},
  "Addition from Left"->{
    Cell[17453, 589, 404, 11, 89, "Input",
      CellTags->"Addition from Left"]},
  "Associativity of Addition"->{
    Cell[18487, 625, 422, 11, 88, "Input",
      CellTags->"Associativity of Addition"]},
  "Commutativity of Addition"->{
    Cell[19541, 661, 395, 11, 88, "Input",
      CellTags->"Commutativity of Addition"],
    Cell[50162, 1627, 446, 12, 88, "Input",
      CellTags->{
      "Commutativity of Addition", "Multiplication", 
        "Multiplication of Zero from Left", "Zero from Left"}]},
  "Equational Properties of Addition"->{
    Cell[22108, 751, 601, 14, 180, "Input",
      CellTags->"Equational Properties of Addition"],
    Cell[40984, 1333, 667, 15, 212, "Input",
      CellTags->"Equational Properties of Addition"],
    Cell[60806, 1981, 715, 16, 241, "Input",
      CellTags->"Equational Properties of Addition"],
    Cell[138071, 4110, 594, 14, 182, "Input",
      CellTags->"Equational Properties of Addition"]},
  "2-ary limit"->{
    Cell[25642, 878, 833, 18, 113, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[26989, 910, 452, 11, 106, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[27444, 923, 476, 10, 126, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[27923, 935, 600, 12, 112, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[28827, 963, 456, 11, 113, "Input",
      CellTags->{
      "1-ary limit", "2-ary limit", "3-ary limit", "4-ary limit", "limit"}],
    Cell[29505, 983, 463, 12, 106, "Input",
      CellTags->"2-ary limit"],
    Cell[29971, 997, 486, 12, 113, "Input",
      CellTags->{"2-ary limit", "3-ary limit"}],
    Cell[30460, 1011, 704, 15, 113, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[37451, 1215, 362, 9, 119, "Input",
      CellTags->"2-ary limit"],
    Cell[39038, 1268, 419, 10, 149, "Input",
      CellTags->{"1-ary limit", "2-ary limit"}],
    Cell[39460, 1280, 527, 12, 126, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}]},
  "3-ary limit"->{
    Cell[25642, 878, 833, 18, 113, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[26989, 910, 452, 11, 106, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[27444, 923, 476, 10, 126, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[27923, 935, 600, 12, 112, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[28827, 963, 456, 11, 113, "Input",
      CellTags->{
      "1-ary limit", "2-ary limit", "3-ary limit", "4-ary limit", "limit"}],
    Cell[29971, 997, 486, 12, 113, "Input",
      CellTags->{"2-ary limit", "3-ary limit"}],
    Cell[30460, 1011, 704, 15, 113, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[35311, 1152, 353, 9, 119, "Input",
      CellTags->"3-ary limit"],
    Cell[39460, 1280, 527, 12, 126, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}]},
  "4-ary limit"->{
    Cell[25642, 878, 833, 18, 113, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[26989, 910, 452, 11, 106, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[27444, 923, 476, 10, 126, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[27923, 935, 600, 12, 112, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[28827, 963, 456, 11, 113, "Input",
      CellTags->{
      "1-ary limit", "2-ary limit", "3-ary limit", "4-ary limit", "limit"}],
    Cell[30460, 1011, 704, 15, 113, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
    Cell[33305, 1095, 446, 11, 178, "Input",
      CellTags->"4-ary limit"],
    Cell[39460, 1280, 527, 12, 126, "Input",
      CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}]},
  "1-ary limit"->{
    Cell[28827, 963, 456, 11, 113, "Input",
      CellTags->{
      "1-ary limit", "2-ary limit", "3-ary limit", "4-ary limit", "limit"}],
    Cell[29286, 976, 204, 4, 34, "Message",
      CellTags->"1-ary limit"],
    Cell[39038, 1268, 419, 10, 149, "Input",
      CellTags->{"1-ary limit", "2-ary limit"}]},
  "limit"->{
    Cell[28827, 963, 456, 11, 113, "Input",
      CellTags->{
      "1-ary limit", "2-ary limit", "3-ary limit", "4-ary limit", "limit"}]},
  "sum of sequences"->{
    Cell[31260, 1033, 411, 11, 88, "Input",
      CellTags->"sum of sequences"]},
  "distance of sum"->{
    Cell[31674, 1046, 787, 17, 88, "Input",
      CellTags->"distance of sum"]},
  "max"->{
    Cell[32486, 1067, 459, 12, 88, "Input",
      CellTags->"max"],
    Cell[32948, 1081, 192, 4, 35, "Message",
      CellTags->"max"]},
  "4-ary limit of sum"->{
    Cell[33754, 1108, 618, 13, 137, "Input",
      CellTags->"4-ary limit of sum"]},
  "3-ary limit of sum"->{
    Cell[35667, 1163, 570, 12, 137, "Input",
      CellTags->"3-ary limit of sum"]},
  "3-ary limit of sum: variant"->{
    Cell[36843, 1199, 605, 14, 137, "Input",
      CellTags->"3-ary limit of sum: variant"]},
  "2-ary limit of sum"->{
    Cell[37816, 1226, 499, 12, 137, "Input",
      CellTags->"2-ary limit of sum"]},
  "Multiplication"->{
    Cell[41654, 1350, 398, 11, 122, "Input",
      CellTags->"Multiplication"],
    Cell[44277, 1441, 410, 11, 88, "Input",
      CellTags->{
      "Multiplication", "Multiplication of Zero from Left", 
        "Zero from Left"}],
    Cell[50162, 1627, 446, 12, 88, "Input",
      CellTags->{
      "Commutativity of Addition", "Multiplication", 
        "Multiplication of Zero from Left", "Zero from Left"}],
    Cell[61524, 1999, 635, 16, 182, "Input",
      CellTags->{
      "Multiplication", "Some Equational Properties of Multiplication"}],
    Cell[62162, 2017, 459, 12, 88, "Input",
      CellTags->{
      "Associativity of Multiplication", "Associativity of Multiplicatios", 
        "Multiplication"}]},
  "Commutativity of Multiplication"->{
    Cell[42055, 1363, 372, 10, 88, "Input",
      CellTags->"Commutativity of Multiplication"]},
  "Multiplication of Zero from Left"->{
    Cell[44277, 1441, 410, 11, 88, "Input",
      CellTags->{
      "Multiplication", "Multiplication of Zero from Left", 
        "Zero from Left"}],
    Cell[50162, 1627, 446, 12, 88, "Input",
      CellTags->{
      "Commutativity of Addition", "Multiplication", 
        "Multiplication of Zero from Left", "Zero from Left"}]},
  "Zero from Left"->{
    Cell[44277, 1441, 410, 11, 88, "Input",
      CellTags->{
      "Multiplication", "Multiplication of Zero from Left", 
        "Zero from Left"}],
    Cell[50162, 1627, 446, 12, 88, "Input",
      CellTags->{
      "Commutativity of Addition", "Multiplication", 
        "Multiplication of Zero from Left", "Zero from Left"}]},
  "Some Equational Properties of Multiplication"->{
    Cell[61524, 1999, 635, 16, 182, "Input",
      CellTags->{
      "Multiplication", "Some Equational Properties of Multiplication"}]},
  "Associativity of Multiplication"->{
    Cell[62162, 2017, 459, 12, 88, "Input",
      CellTags->{
      "Associativity of Multiplication", "Associativity of Multiplicatios", 
        "Multiplication"}]},
  "Associativity of Multiplicatios"->{
    Cell[62162, 2017, 459, 12, 88, "Input",
      CellTags->{
      "Associativity of Multiplication", "Associativity of Multiplicatios", 
        "Multiplication"}]},
  "GB-Test"->{
    Cell[182395, 5271, 847, 19, 192, "Input",
      CellTags->{"GB-Test", "GBTest11"}]},
  "GBTest11"->{
    Cell[182395, 5271, 847, 19, 192, "Input",
      CellTags->{"GB-Test", "GBTest11"}]},
  "0+ "->{
    Cell[189921, 5539, 739, 27, 43, "Conclusion",
      CellTags->"0+ "],
    Cell[197635, 5884, 733, 26, 43, "Conclusion",
      CellTags->"0+ "],
    Cell[335959, 11415, 733, 26, 43, "Conclusion",
      CellTags->"0+ "],
    Cell[344627, 11785, 733, 26, 43, "Assumption",
      CellTags->"0+ "],
    Cell[375818, 13006, 733, 26, 43, "Assumption",
      CellTags->"0+ "],
    Cell[392932, 13675, 733, 26, 43, "Assumption",
      CellTags->"0+ "],
    Cell[528357, 18455, 733, 26, 43, "Assumption",
      CellTags->"0+ "],
    Cell[564897, 19978, 733, 26, 43, "Assumption",
      CellTags->"0+ "],
    Cell[578690, 20535, 733, 26, 43, "Assumption",
      CellTags->"0+ "],
    Cell[634301, 22711, 733, 26, 43, "Assumption",
      CellTags->"0+ "],
    Cell[673085, 24218, 733, 26, 43, "Assumption",
      CellTags->"0+ "],
    Cell[901063, 31457, 733, 26, 43, "Assumption",
      CellTags->"0+ "]},
  " +0"->{
    Cell[190704, 5570, 733, 26, 43, "Assumption",
      CellTags->" +0"],
    Cell[198412, 5914, 733, 26, 43, "Assumption",
      CellTags->" +0"],
    Cell[206239, 6254, 733, 26, 43, "Assumption",
      CellTags->" +0"],
    Cell[233925, 7348, 733, 26, 43, "Assumption",
      CellTags->" +0"],
    Cell[306230, 10139, 733, 26, 43, "Assumption",
      CellTags->" +0"],
    Cell[336736, 11445, 733, 26, 43, "Assumption",
      CellTags->" +0"],
    Cell[345363, 11813, 733, 26, 43, "Assumption",
      CellTags->" +0"],
    Cell[376554, 13034, 733, 26, 43, "Assumption",
      CellTags->" +0"],
    Cell[393668, 13703, 733, 26, 43, "Assumption",
      CellTags->" +0"],
    Cell[526290, 18382, 733, 26, 43, "Assumption",
      CellTags->" +0"],
    Cell[562830, 19905, 733, 26, 43, "Assumption",
      CellTags->" +0"],
    Cell[576623, 20462, 733, 26, 43, "Assumption",
      CellTags->" +0"],
    Cell[632234, 22638, 733, 26, 43, "Assumption",
      CellTags->" +0"],
    Cell[671018, 24145, 733, 26, 43, "Assumption",
      CellTags->" +0"],
    Cell[898996, 31384, 733, 26, 43, "Assumption",
      CellTags->" +0"]},
  " +succ"->{
    Cell[191440, 5598, 1330, 43, 45, "Assumption",
      CellTags->" +succ"],
    Cell[199148, 5942, 1330, 43, 45, "Assumption",
      CellTags->" +succ"],
    Cell[206975, 6282, 1330, 43, 45, "Assumption",
      CellTags->" +succ"],
    Cell[234661, 7376, 1330, 43, 45, "Assumption",
      CellTags->" +succ"],
    Cell[306966, 10167, 1330, 43, 45, "Assumption",
      CellTags->" +succ"],
    Cell[337472, 11473, 1330, 43, 45, "Assumption",
      CellTags->" +succ"],
    Cell[346099, 11841, 1330, 43, 45, "Assumption",
      CellTags->" +succ"],
    Cell[377290, 13062, 1330, 43, 45, "Assumption",
      CellTags->" +succ"],
    Cell[394404, 13731, 1330, 43, 45, "Assumption",
      CellTags->" +succ"]},
  "1"->{
    Cell[193638, 5686, 184, 9, 33, "Conclusion",
      CellTags->"1"],
    Cell[200870, 6009, 184, 9, 33, "Conclusion",
      CellTags->"1"],
    Cell[208703, 6349, 869, 30, 43, "Conclusion",
      CellTags->"1"],
    Cell[236391, 7443, 1358, 43, 46, "Conclusion",
      CellTags->"1"],
    Cell[309172, 10255, 770, 27, 43, "Conclusion",
      CellTags->"1"]},
  "2"->{
    Cell[194740, 5750, 452, 17, 33, "Assumption",
      CellTags->"2"],
    Cell[201972, 6073, 452, 17, 33, "Assumption",
      CellTags->"2"],
    Cell[215398, 6655, 1193, 38, 43, "Assumption",
      CellTags->"2"],
    Cell[265026, 8602, 1643, 50, 46, "Assumption",
      CellTags->"2"],
    Cell[317279, 10635, 1039, 34, 43, "Assumption",
      CellTags->"2"]},
  "3"->{
    Cell[195273, 5774, 537, 20, 33, "Conclusion",
      CellTags->"3"],
    Cell[202505, 6097, 537, 20, 33, "Conclusion",
      CellTags->"3"],
    Cell[216672, 6700, 1341, 42, 43, "Conclusion",
      CellTags->"3"],
    Cell[266750, 8659, 1742, 53, 46, "Conclusion",
      CellTags->"3"],
    Cell[318399, 10676, 1134, 37, 43, "Conclusion",
      CellTags->"3"]},
  "succ+ "->{
    Cell[204865, 6207, 1330, 43, 45, "Conclusion",
      CellTags->"succ+ "]},
  "4"->{
    Cell[209960, 6403, 202, 8, 33, "Conclusion",
      CellTags->"4"],
    Cell[238137, 7510, 866, 29, 46, "Conclusion",
      CellTags->"4"],
    Cell[310336, 10303, 489, 18, 33, "Conclusion",
      CellTags->"4"]},
  "5"->{
    Cell[211384, 6482, 575, 20, 33, "Assumption",
      CellTags->"5"],
    Cell[247767, 7936, 1231, 38, 46, "Assumption",
      CellTags->"5"],
    Cell[311872, 10372, 729, 26, 43, "Conclusion",
      CellTags->"5"]},
  "6"->{
    Cell[212040, 6509, 666, 23, 33, "Conclusion",
      CellTags->"6"],
    Cell[249079, 7981, 1334, 41, 46, "Conclusion",
      CellTags->"6"],
    Cell[312989, 10422, 184, 9, 33, "Conclusion",
      CellTags->"6"]},
  "7"->{
    Cell[218229, 6756, 993, 31, 33, "Conclusion",
      CellTags->"7"],
    Cell[239219, 7553, 577, 20, 33, "Conclusion",
      CellTags->"7"],
    Cell[314091, 10486, 452, 17, 33, "Assumption",
      CellTags->"7"]},
  "8"->{
    Cell[221095, 6862, 1412, 43, 43, "Conclusion",
      CellTags->"8"],
    Cell[240962, 7627, 858, 29, 46, "Conclusion",
      CellTags->"8"],
    Cell[314624, 10510, 537, 20, 33, "Conclusion",
      CellTags->"8"]},
  "9"->{
    Cell[222895, 6929, 802, 27, 33, "Conclusion",
      CellTags->"9"],
    Cell[242208, 7680, 198, 9, 33, "Conclusion",
      CellTags->"9"],
    Cell[319927, 10734, 813, 28, 33, "Conclusion",
      CellTags->"9"]},
  "10"->{
    Cell[225852, 7056, 1067, 34, 33, "Assumption",
      CellTags->"10"],
    Cell[243342, 7744, 571, 20, 33, "Assumption",
      CellTags->"10"],
    Cell[322940, 10856, 1202, 39, 43, "Conclusion",
      CellTags->"10"]},
  "11"->{
    Cell[227000, 7097, 1156, 36, 33, "Conclusion",
      CellTags->"11"],
    Cell[243994, 7771, 662, 23, 33, "Conclusion",
      CellTags->"11"],
    Cell[324539, 10919, 619, 22, 33, "Conclusion",
      CellTags->"11"]},
  "( + )+ "->{
    Cell[232094, 7289, 1787, 55, 46, "Conclusion",
      CellTags->"( + )+ "]},
  "12"->{
    Cell[250629, 8036, 999, 32, 33, "Conclusion",
      CellTags->"12"],
    Cell[327898, 11070, 872, 29, 33, "Assumption",
      CellTags->"12"]},
  "13"->{
    Cell[253428, 8141, 1336, 41, 46, "Conclusion",
      CellTags->"13"],
    Cell[328851, 11106, 963, 32, 33, "Conclusion",
      CellTags->"13"]},
  "14"->{
    Cell[255154, 8206, 751, 26, 33, "Conclusion",
      CellTags->"14"],
    Cell[326973, 11028, 580, 21, 33, "Conclusion",
      CellTags->"14"]},
  "15"->{
    Cell[258447, 8350, 999, 32, 33, "Assumption",
      CellTags->"15"],
    Cell[330501, 11177, 578, 21, 33, "Conclusion",
      CellTags->"15"]},
  "16"->{
    Cell[259527, 8389, 1090, 35, 33, "Conclusion",
      CellTags->"16"],
    Cell[333796, 11327, 815, 28, 33, "Assumption",
      CellTags->"16"]},
  "17"->{
    Cell[268880, 8736, 1316, 41, 46, "Conclusion",
      CellTags->"17"],
    Cell[334692, 11362, 902, 31, 33, "Conclusion",
      CellTags->"17"]},
  "20"->{
    Cell[270414, 8791, 979, 32, 33, "Conclusion",
      CellTags->"20"]},
  "21"->{
    Cell[273087, 8894, 1224, 39, 46, "Conclusion",
      CellTags->"21"]},
  "22"->{
    Cell[274701, 8957, 586, 21, 33, "Conclusion",
      CellTags->"22"]},
  "23"->{
    Cell[276721, 9048, 895, 30, 33, "Assumption",
      CellTags->"23"]},
  "24"->{
    Cell[277697, 9085, 986, 33, 33, "Conclusion",
      CellTags->"24"]},
  "18"->{
    Cell[282766, 9290, 1617, 48, 46, "Assumption",
      CellTags->"18"],
    Cell[332866, 11284, 580, 21, 33, "Conclusion",
      CellTags->"18"]},
  "19"->{
    Cell[284464, 9345, 1720, 51, 46, "Conclusion",
      CellTags->"19"]},
  "25"->{
    Cell[286402, 9410, 1343, 42, 33, "Conclusion",
      CellTags->"25"]},
  "26"->{
    Cell[290051, 9540, 1730, 51, 46, "Conclusion",
      CellTags->"26"]},
  "27"->{
    Cell[292171, 9615, 1105, 36, 33, "Conclusion",
      CellTags->"27"]},
  "28"->{
    Cell[296648, 9794, 1355, 42, 33, "Assumption",
      CellTags->"28"]},
  "29"->{
    Cell[298084, 9843, 1446, 45, 33, "Conclusion",
      CellTags->"29"]},
  " + "->{
    Cell[305016, 10096, 1170, 39, 45, "Conclusion",
      CellTags->" + "],
    Cell[373275, 12918, 1170, 39, 45, "Conclusion",
      CellTags->" + "],
    Cell[390430, 13589, 1170, 39, 45, "Assumption",
      CellTags->" + "],
    Cell[638158, 22841, 1170, 39, 45, "Assumption",
      CellTags->" + "],
    Cell[675150, 24291, 1170, 39, 45, "Assumption",
      CellTags->" + "]},
  "0+ .IB"->{
    Cell[339194, 11540, 194, 9, 33, "Conclusion",
      CellTags->"0+ .IB"]},
  "0+ .IH"->{
    Cell[340316, 11604, 462, 17, 33, "Assumption",
      CellTags->"0+ .IH"]},
  "0+ .IS"->{
    Cell[340859, 11628, 547, 20, 33, "Conclusion",
      CellTags->"0+ .IS"]},
  "^++ "->{
    Cell[343257, 11738, 1326, 43, 45, "Conclusion",
      CellTags->"^++ "],
    Cell[374489, 12961, 1326, 43, 45, "Assumption",
      CellTags->"^++ "],
    Cell[391603, 13630, 1326, 43, 45, "Assumption",
      CellTags->"^++ "],
    Cell[529093, 18483, 1326, 43, 45, "Assumption",
      CellTags->"^++ "],
    Cell[565633, 20006, 1326, 43, 45, "Assumption",
      CellTags->"^++ "],
    Cell[579426, 20563, 1326, 43, 45, "Assumption",
      CellTags->"^++ "],
    Cell[635037, 22739, 1326, 43, 45, "Assumption",
      CellTags->"^++ "],
    Cell[673821, 24246, 1326, 43, 45, "Assumption",
      CellTags->"^++ "],
    Cell[901799, 31485, 1326, 43, 45, "Assumption",
      CellTags->"^++ "]},
  "^++ .IB"->{
    Cell[347823, 11908, 881, 30, 43, "Conclusion",
      CellTags->"^++ .IB"]},
  "^++ .IB.F"->{
    Cell[348932, 11952, 591, 20, 33, "Conclusion",
      CellTags->"^++ .IB.F"]},
  "^++ .IB.S"->{
    Cell[350688, 12026, 792, 27, 43, "Conclusion",
      CellTags->"^++ .IB.S"]},
  "^++ .IB.S.IB"->{
    Cell[351884, 12077, 220, 9, 33, "Conclusion",
      CellTags->"^++ .IB.S.IB"]},
  "^++ .IB.S.IH"->{
    Cell[353065, 12141, 517, 18, 33, "Assumption",
      CellTags->"^++ .IB.S.IH"]},
  "^++ .IB.S.IS"->{
    Cell[353663, 12166, 645, 22, 33, "Conclusion",
      CellTags->"^++ .IB.S.IS"]},
  "^++ .IH"->{
    Cell[356343, 12282, 1205, 38, 43, "Assumption",
      CellTags->"^++ .IH"]},
  "^++ .IS"->{
    Cell[357629, 12327, 1353, 42, 43, "Conclusion",
      CellTags->"^++ .IS"]},
  "^++ .IS.F"->{
    Cell[359210, 12383, 1015, 32, 33, "Conclusion",
      CellTags->"^++ .IS.F"]},
  "^++ .IS.S"->{
    Cell[362110, 12490, 1428, 43, 43, "Conclusion",
      CellTags->"^++ .IS.S"]},
  "^++ .IS.S.IB"->{
    Cell[363942, 12557, 824, 27, 33, "Conclusion",
      CellTags->"^++ .IS.S.IB"]},
  "^++ .IS.S.IH"->{
    Cell[366943, 12684, 1087, 34, 33, "Assumption",
      CellTags->"^++ .IS.S.IH"]},
  "^++ .IS.S.IS"->{
    Cell[368111, 12725, 1182, 37, 33, "Conclusion",
      CellTags->"^++ .IS.S.IS"]},
  " + .IB"->{
    Cell[379012, 13129, 780, 27, 43, "Conclusion",
      CellTags->" + .IB"]},
  " + .IB.F"->{
    Cell[380028, 13170, 510, 19, 33, "Conclusion",
      CellTags->" + .IB.F"]},
  " + .IH"->{
    Cell[382190, 13274, 1049, 34, 43, "Assumption",
      CellTags->" + .IH"]},
  " + .IS"->{
    Cell[383320, 13315, 1144, 37, 43, "Conclusion",
      CellTags->" + .IS"]},
  " + .IS.F"->{
    Cell[384700, 13366, 834, 29, 33, "Conclusion",
      CellTags->" + .IS.F"]},
  "( + ) + "->{
    Cell[388597, 13530, 1789, 55, 46, "Conclusion",
      CellTags->"( + ) + "],
    Cell[530422, 18528, 1789, 55, 46, "Assumption",
      CellTags->"( + ) + "],
    Cell[566962, 20051, 1789, 55, 46, "Assumption",
      CellTags->"( + ) + "],
    Cell[580755, 20608, 1789, 55, 46, "Assumption",
      CellTags->"( + ) + "],
    Cell[636366, 22784, 1789, 55, 46, "Assumption",
      CellTags->"( + ) + "],
    Cell[676323, 24332, 1789, 55, 46, "Assumption",
      CellTags->"( + ) + "]},
  "( + ) + .F"->{
    Cell[395964, 13788, 1187, 38, 33, "Conclusion",
      CellTags->"( + ) + .F"]},
  "( + ) + .S"->{
    Cell[399193, 13908, 1793, 55, 46, "Conclusion",
      CellTags->"( + ) + .S"]},
  "( + ) + .S.IB"->{
    Cell[401392, 13987, 1382, 43, 46, "Conclusion",
      CellTags->"( + ) + .S.IB"]},
  "( + ) + .S.IB.F"->{
    Cell[403024, 14044, 944, 31, 33, "Conclusion",
      CellTags->"( + ) + .S.IB.F"]},
  "( + ) + .S.IH"->{
    Cell[406840, 14206, 1667, 50, 46, "Assumption",
      CellTags->"( + ) + .S.IH"]},
  "( + ) + .S.IS"->{
    Cell[408588, 14263, 1766, 53, 46, "Conclusion",
      CellTags->"( + ) + .S.IS"]},
  "( + ) + .S.IS.F"->{
    Cell[410604, 14330, 1288, 41, 33, "Conclusion",
      CellTags->"( + ) + .S.IS.F"]},
  "l4+"->{
    Cell[418381, 14629, 4387, 122, 46, "Conclusion",
      CellTags->"l4+"],
    Cell[470658, 16380, 4387, 122, 46, "Assumption",
      CellTags->"l4+"]},
  "l4:"->{
    Cell[422812, 14755, 3162, 87, 50, "Assumption",
      CellTags->"l4:"]},
  "\[CirclePlus]:"->{
    Cell[425977, 14844, 1959, 59, 46, "Assumption",
      CellTags->"\[CirclePlus]:"]},
  "\[LeftBracketingBar]++\[RightBracketingBar]"->{
    Cell[427939, 14905, 3795, 101, 46, "Assumption",
      CellTags->"\[LeftBracketingBar]++\[RightBracketingBar]"]},
  "max:"->{
    Cell[431737, 15008, 1975, 59, 45, "Assumption",
      CellTags->"max:"]},
  "l4+'"->{
    Cell[433951, 15081, 2960, 85, 33, "Conclusion",
      CellTags->"l4+'"]},
  "l4+'.A"->{
    Cell[437147, 15182, 1443, 45, 33, "Assumption",
      CellTags->"l4+'.A"]},
  "l4+'.C"->{
    Cell[438620, 15231, 1510, 47, 33, "Conclusion",
      CellTags->"l4+'.C"]},
  "l4+'.C'"->{
    Cell[441002, 15328, 2603, 70, 43, "Conclusion",
      CellTags->"l4+'.C'"]},
  "l4+'.A.1'"->{
    Cell[443974, 15420, 1587, 46, 43, "Assumption",
      CellTags->"l4+'.A.1'"]},
  "l4+'.A.2'"->{
    Cell[445930, 15488, 1589, 46, 43, "Assumption",
      CellTags->"l4+'.A.2'"]},
  "l4+'.C''"->{
    Cell[447766, 15548, 2157, 62, 33, "Conclusion",
      CellTags->"l4+'.C''"]},
  "l4+'.C''.A"->{
    Cell[450167, 15626, 667, 23, 33, "Assumption",
      CellTags->"l4+'.C''.A"]},
  "l4+'.C''.C"->{
    Cell[450864, 15653, 1537, 46, 33, "Conclusion",
      CellTags->"l4+'.C''.C"]},
  "l4+'.C''.C'"->{
    Cell[452872, 15724, 1739, 51, 33, "Conclusion",
      CellTags->"l4+'.C''.C'"]},
  "l4+'.C''.C'.A"->{
    Cell[455288, 15803, 1687, 49, 33, "Conclusion",
      CellTags->"l4+'.C''.C'.A"]},
  "l4+'.C''.C'.A.1.A"->{
    Cell[458570, 15921, 468, 17, 33, "Conclusion",
      CellTags->"l4+'.C''.C'.A.1.A"]},
  "max:/1"->{
    Cell[459386, 15960, 783, 27, 33, "Assumption",
      CellTags->"max:/1"]},
  "l4+'.C''.C'.A.2.A"->{
    Cell[462420, 16092, 468, 17, 33, "Conclusion",
      CellTags->"l4+'.C''.C'.A.2.A"]},
  "max:/13"->{
    Cell[463236, 16131, 785, 27, 33, "Assumption",
      CellTags->"max:/13"]},
  "l3+"->{
    Cell[465029, 16215, 3387, 95, 46, "Conclusion",
      CellTags->"l3+"],
    Cell[505967, 17619, 3136, 88, 50, "Assumption",
      CellTags->"l3+"]},
  "l3:"->{
    Cell[468460, 16314, 2195, 64, 50, "Assumption",
      CellTags->"l3:"]},
  "l3+'"->{
    Cell[475284, 16516, 2287, 67, 33, "Conclusion",
      CellTags->"l3+'"]},
  "l3+'.A"->{
    Cell[477807, 16599, 1163, 37, 33, "Assumption",
      CellTags->"l3+'.A"]},
  "l3+'.C"->{
    Cell[479000, 16640, 1153, 37, 33, "Conclusion",
      CellTags->"l3+'.C"]},
  "l3+'.C'"->{
    Cell[481025, 16727, 1559, 48, 43, "Conclusion",
      CellTags->"l3+'.C'"]},
  "l3+'.A.1'"->{
    Cell[482953, 16797, 1005, 33, 43, "Assumption",
      CellTags->"l3+'.A.1'"]},
  "l3+'.A.1''"->{
    Cell[484189, 16844, 765, 26, 33, "Assumption",
      CellTags->"l3+'.A.1''"]},
  "l3+'.A.2'"->{
    Cell[485323, 16892, 1007, 33, 43, "Assumption",
      CellTags->"l3+'.A.2'"]},
  "l3+'.A.2''"->{
    Cell[486561, 16939, 767, 26, 33, "Assumption",
      CellTags->"l3+'.A.2''"]},
  "l3+'.C''"->{
    Cell[487719, 16987, 3631, 98, 45, "Assumption",
      CellTags->"l3+'.C''"]},
  "l3+'.C'.A"->{
    Cell[491717, 17107, 1957, 57, 45, "Conclusion",
      CellTags->"l3+'.C'.A"]},
  "l3+'.C'.A/2"->{
    Cell[494338, 17200, 1836, 53, 43, "Conclusion",
      CellTags->"l3+'.C'.A/2"]},
  "l3+'.C'.A/2/1"->{
    Cell[496846, 17289, 1457, 45, 33, "Conclusion",
      CellTags->"l3+'.C'.A/2/1"]},
  "l2+"->{
    Cell[501773, 17491, 2406, 70, 46, "Conclusion",
      CellTags->"l2+"]},
  "l2:"->{
    Cell[504223, 17565, 1741, 52, 50, "Assumption",
      CellTags->"l2:"]},
  "l2+'"->{
    Cell[509342, 17721, 1640, 50, 33, "Conclusion",
      CellTags->"l2+'"]},
  "l2+'.A"->{
    Cell[511218, 17787, 867, 29, 33, "Assumption",
      CellTags->"l2+'.A"]},
  "l2+'.C"->{
    Cell[512115, 17820, 836, 28, 33, "Conclusion",
      CellTags->"l2+'.C"]},
  "l2+'.C'"->{
    Cell[513823, 17898, 1242, 39, 43, "Conclusion",
      CellTags->"l2+'.C'"]},
  "l2+'.A.1'"->{
    Cell[515434, 17959, 876, 29, 43, "Assumption",
      CellTags->"l2+'.A.1'"]},
  "l2+'.A.2'"->{
    Cell[516679, 18010, 876, 29, 43, "Assumption",
      CellTags->"l2+'.A.2'"]},
  "l2+'.C''"->{
    Cell[517802, 18053, 981, 32, 33, "Conclusion",
      CellTags->"l2+'.C''"]},
  "l2+'.C''.A"->{
    Cell[519142, 18107, 1251, 39, 44, "Conclusion",
      CellTags->"l2+'.C''.A"]},
  " \[RawStar] "->{
    Cell[523055, 18267, 1170, 39, 45, "Conclusion",
      CellTags->" \[RawStar] "],
    Cell[573388, 20347, 1170, 39, 45, "Conclusion",
      CellTags->" \[RawStar] "],
    Cell[628999, 22523, 1170, 39, 45, "Conclusion",
      CellTags->" \[RawStar] "]},
  " \[RawStar]0"->{
    Cell[524269, 18310, 613, 23, 43, "Assumption",
      CellTags->" \[RawStar]0"],
    Cell[560809, 19833, 613, 23, 43, "Assumption",
      CellTags->" \[RawStar]0"],
    Cell[574602, 20390, 613, 23, 43, "Assumption",
      CellTags->" \[RawStar]0"],
    Cell[630213, 22566, 613, 23, 43, "Assumption",
      CellTags->" \[RawStar]0"],
    Cell[666983, 24002, 613, 23, 43, "Assumption",
      CellTags->" \[RawStar]0"],
    Cell[894961, 31241, 613, 23, 43, "Assumption",
      CellTags->" \[RawStar]0"]},
  " \[RawStar] ^+"->{
    Cell[524885, 18335, 1402, 45, 45, "Assumption",
      CellTags->" \[RawStar] ^+"],
    Cell[561425, 19858, 1402, 45, 45, "Assumption",
      CellTags->" \[RawStar] ^+"],
    Cell[575218, 20415, 1402, 45, 45, "Assumption",
      CellTags->" \[RawStar] ^+"],
    Cell[630829, 22591, 1402, 45, 45, "Assumption",
      CellTags->" \[RawStar] ^+"]},
  " + ^+"->{
    Cell[527026, 18410, 1328, 43, 45, "Assumption",
      CellTags->" + ^+"],
    Cell[563566, 19933, 1328, 43, 45, "Assumption",
      CellTags->" + ^+"],
    Cell[577359, 20490, 1328, 43, 45, "Assumption",
      CellTags->" + ^+"],
    Cell[632970, 22666, 1328, 43, 45, "Assumption",
      CellTags->" + ^+"],
    Cell[671754, 24173, 1328, 43, 45, "Assumption",
      CellTags->" + ^+"],
    Cell[899732, 31412, 1328, 43, 45, "Assumption",
      CellTags->" + ^+"]},
  " \[RawStar] .IB"->{
    Cell[533086, 18628, 780, 27, 43, "Conclusion",
      CellTags->" \[RawStar] .IB"],
    Cell[584030, 20732, 780, 27, 43, "Conclusion",
      CellTags->" \[RawStar] .IB"],
    Cell[640807, 22949, 780, 27, 43, "Conclusion",
      CellTags->" \[RawStar] .IB"]},
  " \[RawStar] .IB.F"->{
    Cell[534270, 18676, 503, 18, 33, "Conclusion",
      CellTags->" \[RawStar] .IB.F"],
    Cell[585224, 20780, 510, 19, 33, "Conclusion",
      CellTags->" \[RawStar] .IB.F"],
    Cell[642001, 22997, 510, 19, 33, "Conclusion",
      CellTags->" \[RawStar] .IB.F"]},
  " \[RawStar] .IB.S"->{
    Cell[535723, 18742, 618, 22, 43, "Conclusion",
      CellTags->" \[RawStar] .IB.S"]},
  " \[RawStar] .IB.S.IB"->{
    Cell[536743, 18788, 202, 9, 33, "Conclusion",
      CellTags->" \[RawStar] .IB.S.IB"]},
  " \[RawStar] .IB.S.IH"->{
    Cell[537881, 18852, 358, 13, 33, "Assumption",
      CellTags->" \[RawStar] .IB.S.IH"]},
  " \[RawStar] .IB.S.IS"->{
    Cell[538320, 18872, 405, 15, 33, "Conclusion",
      CellTags->" \[RawStar] .IB.S.IS"]},
  " \[RawStar] .IH"->{
    Cell[540855, 18999, 1049, 34, 43, "Assumption",
      CellTags->" \[RawStar] .IH"],
    Cell[587493, 20893, 1049, 34, 43, "Assumption",
      CellTags->" \[RawStar] .IH"],
    Cell[644270, 23110, 1049, 34, 43, "Assumption",
      CellTags->" \[RawStar] .IH"]},
  " \[RawStar] .IS"->{
    Cell[541985, 19040, 1144, 37, 43, "Conclusion",
      CellTags->" \[RawStar] .IS"],
    Cell[588623, 20934, 1144, 37, 43, "Conclusion",
      CellTags->" \[RawStar] .IS"],
    Cell[645400, 23151, 1144, 37, 43, "Conclusion",
      CellTags->" \[RawStar] .IS"]},
  " \[RawStar] .IS.F"->{
    Cell[543533, 19098, 827, 28, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.F"],
    Cell[590171, 20992, 827, 28, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.F"],
    Cell[646948, 23209, 827, 28, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.F"]},
  " \[RawStar] .IS.S"->{
    Cell[546700, 19226, 1288, 41, 43, "Conclusion",
      CellTags->" \[RawStar] .IS.S"],
    Cell[593338, 21120, 1288, 41, 43, "Conclusion",
      CellTags->" \[RawStar] .IS.S"],
    Cell[650786, 23366, 1288, 41, 43, "Conclusion",
      CellTags->" \[RawStar] .IS.S"]},
  " \[RawStar] .IS.S.IB"->{
    Cell[548397, 19291, 595, 21, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.S.IB"],
    Cell[595035, 21185, 595, 21, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.S.IB"],
    Cell[652476, 23431, 595, 21, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.S.IB"]},
  " \[RawStar] .IS.S.IB.S"->{
    Cell[551021, 19413, 369, 14, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.S.IB.S"]},
  " \[RawStar] .IS.S.IH"->{
    Cell[551757, 19448, 962, 32, 33, "Assumption",
      CellTags->" \[RawStar] .IS.S.IH"],
    Cell[598008, 21328, 962, 32, 33, "Assumption",
      CellTags->" \[RawStar] .IS.S.IH"],
    Cell[655449, 23574, 962, 32, 33, "Assumption",
      CellTags->" \[RawStar] .IS.S.IH"]},
  " \[RawStar] .IS.S.IS"->{
    Cell[552800, 19487, 1091, 36, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.S.IS"],
    Cell[599051, 21367, 1091, 36, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.S.IS"],
    Cell[656492, 23613, 1091, 36, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.S.IS"]},
  " \[RawStar] .IS.IB"->{
    Cell[554606, 19562, 592, 21, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.IB"],
    Cell[610827, 21805, 592, 21, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.IB"]},
  " \[RawStar] .IS.IB.S"->{
    Cell[557222, 19684, 365, 14, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.IB.S"]},
  " \[RawStar] .IS.IH"->{
    Cell[557950, 19719, 829, 28, 33, "Assumption",
      CellTags->" \[RawStar] .IS.IH"],
    Cell[613792, 21948, 829, 28, 33, "Assumption",
      CellTags->" \[RawStar] .IS.IH"]},
  " \[RawStar] .IS.IS"->{
    Cell[558860, 19754, 916, 31, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.IS"],
    Cell[614702, 21983, 916, 31, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.IS"]},
  "0\[RawStar] "->{
    Cell[560157, 19807, 608, 22, 43, "Conclusion",
      CellTags->"0\[RawStar] "],
    Cell[582547, 20665, 608, 22, 43, "Assumption",
      CellTags->"0\[RawStar] "],
    Cell[639331, 22882, 608, 22, 43, "Assumption",
      CellTags->"0\[RawStar] "]},
  "0\[RawStar] .IB"->{
    Cell[569619, 20151, 192, 9, 33, "Conclusion",
      CellTags->"0\[RawStar] .IB"]},
  "0\[RawStar] .IH"->{
    Cell[570737, 20215, 348, 13, 33, "Assumption",
      CellTags->"0\[RawStar] .IH"]},
  "0\[RawStar] .IS"->{
    Cell[571166, 20235, 395, 15, 33, "Conclusion",
      CellTags->"0\[RawStar] .IS"]},
  " \[RawStar] .IS.S.IS.S"->{
    Cell[608299, 21713, 1825, 54, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.S.IS.S"]},
  " \[RawStar] .IS.IS.S"->{
    Cell[626808, 22448, 1821, 54, 33, "Conclusion",
      CellTags->" \[RawStar] .IS.IS.S"]},
  "( \[RawStar] ) \[RawStar] "->{
    Cell[665150, 23943, 1789, 55, 46, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] "],
    Cell[893128, 31182, 1789, 55, 46, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] "]},
  " \[RawStar]  ^+"->{
    Cell[667599, 24027, 1404, 45, 45, "Assumption",
      CellTags->" \[RawStar]  ^+"],
    Cell[895577, 31266, 1404, 45, 45, "Assumption",
      CellTags->" \[RawStar]  ^+"]},
  "0\[RawStar]"->{
    Cell[669006, 24074, 606, 22, 43, "Assumption",
      CellTags->"0\[RawStar]"],
    Cell[896984, 31313, 606, 22, 43, "Assumption",
      CellTags->"0\[RawStar]"]},
  " ^+\[RawStar]"->{
    Cell[669615, 24098, 1400, 45, 45, "Assumption",
      CellTags->" ^+\[RawStar]"],
    Cell[897593, 31337, 1400, 45, 45, "Assumption",
      CellTags->" ^+\[RawStar]"]},
  "( \[RawStar] ) \[RawStar] .IB"->{
    Cell[679000, 24432, 1378, 43, 46, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IB"],
    Cell[903527, 31552, 1378, 43, 46, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IB"]},
  "( \[RawStar] ) \[RawStar] .IB.F"->{
    Cell[680802, 24496, 940, 31, 33, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IB.F"],
    Cell[905151, 31609, 940, 31, 33, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IB.F"]},
  "( \[RawStar] ) \[RawStar] .IH"->{
    Cell[684309, 24653, 1663, 50, 46, "Assumption",
      CellTags->"( \[RawStar] ) \[RawStar] .IH"],
    Cell[908346, 31751, 1663, 50, 46, "Assumption",
      CellTags->"( \[RawStar] ) \[RawStar] .IH"]},
  "( \[RawStar] ) \[RawStar] .IS"->{
    Cell[686053, 24710, 1762, 53, 46, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS"],
    Cell[910090, 31808, 1762, 53, 46, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS"]},
  "( \[RawStar] ) \[RawStar] .IS.F"->{
    Cell[688229, 24784, 1277, 40, 33, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.F"],
    Cell[912088, 31875, 1277, 40, 33, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.F"]},
  "( \[RawStar] ) \[RawStar] .IS.S"->{
    Cell[695868, 25068, 2258, 66, 46, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S"],
    Cell[919771, 32159, 2258, 66, 46, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S"]},
  "( \[RawStar] ) \[RawStar] .IS.S.IB"->{
    Cell[698538, 25158, 1530, 46, 46, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IB"],
    Cell[922441, 32249, 1530, 46, 46, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IB"]},
  "( \[RawStar] ) \[RawStar] .IS.S.IB.F"->{
    Cell[700502, 25225, 1189, 38, 33, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IB.F"],
    Cell[924227, 32309, 1189, 38, 33, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IB.F"]},
  "( \[RawStar] ) \[RawStar] .IS.S.IH"->{
    Cell[706200, 25479, 2147, 61, 46, "Assumption",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IH"],
    Cell[929604, 32548, 2147, 61, 46, "Assumption",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IH"]},
  "( \[RawStar] ) \[RawStar] .IS.S.IS"->{
    Cell[708428, 25547, 2348, 66, 46, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS"],
    Cell[931832, 32616, 2348, 66, 46, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS"]},
  "( \[RawStar] ) \[RawStar] .IS.S.IS.F"->{
    Cell[711200, 25634, 1920, 57, 33, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.F"],
    Cell[934426, 32696, 1920, 57, 33, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.F"]},
  "( \[RawStar] ) \[RawStar] .IS.S.IS.S"->{
    Cell[729885, 26275, 3118, 84, 46, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S"],
    Cell[953668, 33357, 3207, 85, 46, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S"]},
  "( \[RawStar] ) \[RawStar] .IS.S.IS.S.IB"->{
    Cell[733432, 26383, 1976, 57, 33, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IB"],
    Cell[957297, 33466, 2077, 58, 33, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IB"]},
  "( \[RawStar] ) \[RawStar] .IS.S.IS.S.IH"->{
    Cell[739391, 26604, 2630, 75, 33, "Assumption",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IH"],
    Cell[963872, 33709, 2714, 75, 33, "Assumption",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IH"]},
  "( \[RawStar] ) \[RawStar] .IS.S.IS.S.IS"->{
    Cell[742102, 26686, 2851, 81, 33, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IS"],
    Cell[966667, 33791, 2935, 81, 33, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IS"]},
  "( \[RawStar] ) \[RawStar] .IS.S.IS.S.IS.S"->{
    Cell[805372, 28505, 5137, 126, 54, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IS.S"]},
  "( \[RawStar] ) \[RawStar] .IS.S.IS.IB"->{
    Cell[811245, 28669, 1552, 47, 33, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.IB"]},
  "( \[RawStar] ) \[RawStar] .IS.S.IS.IH"->{
    Cell[817532, 28925, 1922, 57, 33, "Assumption",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.IH"]},
  "( \[RawStar] ) \[RawStar] .IS.S.IS.IS"->{
    Cell[819535, 28989, 2053, 61, 33, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.IS"]},
  "f=0"->{
    Cell[1008016, 34947, 7260, 177, 134, "Conclusion",
      CellTags->"f=0"]},
  "f=0.1"->{
    Cell[1015775, 35142, 6481, 158, 164, "Conclusion",
      CellTags->"f=0.1"]},
  "f=0.1.structure"->{
    Cell[1022583, 35318, 348, 11, 46, "Conclusion",
      CellTags->"f=0.1.structure"]},
  "f=0.1.implication"->{
    Cell[1028482, 35490, 323, 10, 46, "Conclusion",
      CellTags->"f=0.1.implication"]},
  "f=0.1.not-exists"->{
    Cell[1029018, 35513, 343, 11, 48, "Conclusion",
      CellTags->"f=0.1.not-exists"]},
  "f=0.1.not-exists-slack"->{
    Cell[1029679, 35541, 389, 12, 48, "Conclusion",
      CellTags->"f=0.1.not-exists-slack"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Addition", 1055747, 36477},
  {"Addition of Zero from Left", 1055855, 36480},
  {"Addition from Left", 1055972, 36483},
  {"Associativity of Addition", 1056088, 36486},
  {"Commutativity of Addition", 1056211, 36489},
  {"Equational Properties of Addition", 1056522, 36496},
  {"2-ary limit", 1056938, 36505},
  {"3-ary limit", 1058086, 36529},
  {"4-ary limit", 1059064, 36549},
  {"1-ary limit", 1059950, 36567},
  {"limit", 1060273, 36575},
  {"sum of sequences", 1060437, 36579},
  {"distance of sum", 1060542, 36582},
  {"max", 1060634, 36585},
  {"4-ary limit of sum", 1060798, 36590},
  {"3-ary limit of sum", 1060909, 36593},
  {"3-ary limit of sum: variant", 1061029, 36596},
  {"2-ary limit of sum", 1061149, 36599},
  {"Multiplication", 1061256, 36602},
  {"Commutativity of Multiplication", 1062011, 36620},
  {"Multiplication of Zero from Left", 1062148, 36623},
  {"Zero from Left", 1062502, 36632},
  {"Some Equational Properties of Multiplication", 1062886, 36641},
  {"Associativity of Multiplication", 1063063, 36645},
  {"Associativity of Multiplicatios", 1063270, 36650},
  {"GB-Test", 1063453, 36655},
  {"GBTest11", 1063558, 36658},
  {"0+ ", 1063658, 36661},
  {" +0", 1064568, 36686},
  {" +succ", 1065704, 36717},
  {"1", 1066421, 36736},
  {"2", 1066791, 36747},
  {"3", 1067165, 36758},
  {"succ+ ", 1067544, 36769},
  {"4", 1067632, 36772},
  {"5", 1067858, 36779},
  {"6", 1068086, 36786},
  {"7", 1068313, 36793},
  {"8", 1068540, 36800},
  {"9", 1068768, 36807},
  {"10", 1068995, 36814},
  {"11", 1069228, 36821},
  {"( + )+ ", 1069465, 36828},
  {"12", 1069555, 36831},
  {"13", 1069713, 36836},
  {"14", 1069872, 36841},
  {"15", 1070030, 36846},
  {"16", 1070188, 36851},
  {"17", 1070347, 36856},
  {"20", 1070506, 36861},
  {"21", 1070590, 36864},
  {"22", 1070675, 36867},
  {"23", 1070759, 36870},
  {"24", 1070843, 36873},
  {"18", 1070927, 36876},
  {"19", 1071086, 36881},
  {"25", 1071171, 36884},
  {"26", 1071256, 36887},
  {"27", 1071341, 36890},
  {"28", 1071426, 36893},
  {"29", 1071511, 36896},
  {" + ", 1071597, 36899},
  {"0+ .IB", 1071992, 36910},
  {"0+ .IH", 1072084, 36913},
  {"0+ .IS", 1072177, 36916},
  {"^++ ", 1072268, 36919},
  {"^++ .IB", 1072977, 36938},
  {"^++ .IB.F", 1073074, 36941},
  {"^++ .IB.S", 1073173, 36944},
  {"^++ .IB.S.IB", 1073275, 36947},
  {"^++ .IB.S.IH", 1073379, 36950},
  {"^++ .IB.S.IS", 1073484, 36953},
  {"^++ .IH", 1073584, 36956},
  {"^++ .IS", 1073680, 36959},
  {"^++ .IS.F", 1073778, 36962},
  {"^++ .IS.S", 1073878, 36965},
  {"^++ .IS.S.IB", 1073981, 36968},
  {"^++ .IS.S.IH", 1074086, 36971},
  {"^++ .IS.S.IS", 1074192, 36974},
  {" + .IB", 1074292, 36977},
  {" + .IB.F", 1074387, 36980},
  {" + .IH", 1074482, 36983},
  {" + .IS", 1074576, 36986},
  {" + .IS.F", 1074672, 36989},
  {"( + ) + ", 1074769, 36992},
  {"( + ) + .F", 1075274, 37005},
  {"( + ) + .S", 1075376, 37008},
  {"( + ) + .S.IB", 1075481, 37011},
  {"( + ) + .S.IB.F", 1075591, 37014},
  {"( + ) + .S.IH", 1075700, 37017},
  {"( + ) + .S.IS", 1075808, 37020},
  {"( + ) + .S.IS.F", 1075918, 37023},
  {"l4+", 1076018, 37026},
  {"l4:", 1076184, 37031},
  {"\[CirclePlus]:", 1076283, 37034},
  {"\[LeftBracketingBar]++\[RightBracketingBar]", 1076422, 37037},
  {"max:", 1076552, 37040},
  {"l4+'", 1076642, 37043},
  {"l4+'.A", 1076734, 37046},
  {"l4+'.C", 1076828, 37049},
  {"l4+'.C'", 1076923, 37052},
  {"l4+'.A.1'", 1077021, 37055},
  {"l4+'.A.2'", 1077121, 37058},
  {"l4+'.C''", 1077220, 37061},
  {"l4+'.C''.A", 1077320, 37064},
  {"l4+'.C''.C", 1077421, 37067},
  {"l4+'.C''.C'", 1077524, 37070},
  {"l4+'.C''.C'.A", 1077630, 37073},
  {"l4+'.C''.C'.A.1.A", 1077742, 37076},
  {"max:/1", 1077846, 37079},
  {"l4+'.C''.C'.A.2.A", 1077950, 37082},
  {"max:/13", 1078055, 37085},
  {"l3+", 1078146, 37088},
  {"l3:", 1078310, 37093},
  {"l3+'", 1078399, 37096},
  {"l3+'.A", 1078491, 37099},
  {"l3+'.C", 1078585, 37102},
  {"l3+'.C'", 1078680, 37105},
  {"l3+'.A.1'", 1078778, 37108},
  {"l3+'.A.1''", 1078879, 37111},
  {"l3+'.A.2'", 1078979, 37114},
  {"l3+'.A.2''", 1079080, 37117},
  {"l3+'.C''", 1079179, 37120},
  {"l3+'.C'.A", 1079278, 37123},
  {"l3+'.C'.A/2", 1079380, 37126},
  {"l3+'.C'.A/2/1", 1079486, 37129},
  {"l2+", 1079584, 37132},
  {"l2:", 1079672, 37135},
  {"l2+'", 1079761, 37138},
  {"l2+'.A", 1079853, 37141},
  {"l2+'.C", 1079946, 37144},
  {"l2+'.C'", 1080040, 37147},
  {"l2+'.A.1'", 1080138, 37150},
  {"l2+'.A.2'", 1080237, 37153},
  {"l2+'.C''", 1080335, 37156},
  {"l2+'.C''.A", 1080434, 37159},
  {" \[RawStar] ", 1080538, 37162},
  {" \[RawStar]0", 1080814, 37169},
  {" \[RawStar] ^+", 1081341, 37182},
  {" + ^+", 1081703, 37191},
  {" \[RawStar] .IB", 1082195, 37204},
  {" \[RawStar] .IB.F", 1082482, 37211},
  {" \[RawStar] .IB.S", 1082775, 37218},
  {" \[RawStar] .IB.S.IB", 1082893, 37221},
  {" \[RawStar] .IB.S.IH", 1083013, 37224},
  {" \[RawStar] .IB.S.IS", 1083134, 37227},
  {" \[RawStar] .IH", 1083250, 37230},
  {" \[RawStar] .IS", 1083538, 37237},
  {" \[RawStar] .IS.F", 1083828, 37244},
  {" \[RawStar] .IS.S", 1084121, 37251},
  {" \[RawStar] .IS.S.IB", 1084420, 37258},
  {" \[RawStar] .IS.S.IB.S", 1084727, 37265},
  {" \[RawStar] .IS.S.IH", 1084850, 37268},
  {" \[RawStar] .IS.S.IS", 1085155, 37275},
  {" \[RawStar] .IS.IB", 1085461, 37282},
  {" \[RawStar] .IS.IB.S", 1085670, 37287},
  {" \[RawStar] .IS.IH", 1085789, 37290},
  {" \[RawStar] .IS.IS", 1085996, 37295},
  {"0\[RawStar] ", 1086197, 37300},
  {"0\[RawStar] .IB", 1086473, 37307},
  {"0\[RawStar] .IH", 1086583, 37310},
  {"0\[RawStar] .IS", 1086694, 37313},
  {" \[RawStar] .IS.S.IS.S", 1086812, 37316},
  {" \[RawStar] .IS.IS.S", 1086936, 37319},
  {"( \[RawStar] ) \[RawStar] ", 1087064, 37322},
  {" \[RawStar]  ^+", 1087286, 37327},
  {"0\[RawStar]", 1087482, 37332},
  {" ^+\[RawStar]", 1087670, 37337},
  {"( \[RawStar] ) \[RawStar] .IB", 1087880, 37342},
  {"( \[RawStar] ) \[RawStar] .IB.F", 1088124, 37347},
  {"( \[RawStar] ) \[RawStar] .IH", 1088368, 37352},
  {"( \[RawStar] ) \[RawStar] .IS", 1088610, 37357},
  {"( \[RawStar] ) \[RawStar] .IS.F", 1088854, 37362},
  {"( \[RawStar] ) \[RawStar] .IS.S", 1089102, 37367},
  {"( \[RawStar] ) \[RawStar] .IS.S.IB", 1089353, 37372},
  {"( \[RawStar] ) \[RawStar] .IS.S.IB.F", 1089612, 37377},
  {"( \[RawStar] ) \[RawStar] .IS.S.IH", 1089873, 37382},
  {"( \[RawStar] ) \[RawStar] .IS.S.IS", 1090130, 37387},
  {"( \[RawStar] ) \[RawStar] .IS.S.IS.F", 1090389, 37392},
  {"( \[RawStar] ) \[RawStar] .IS.S.IS.S", 1090652, 37397},
  {"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IB", 1090918, 37402},
  {"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IH", 1091190, 37407},
  {"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IS", 1091462, 37412},
  {"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IS.S", 1091736, 37417},
  {"( \[RawStar] ) \[RawStar] .IS.S.IS.IB", 1091897, 37420},
  {"( \[RawStar] ) \[RawStar] .IS.S.IS.IH", 1092053, 37423},
  {"( \[RawStar] ) \[RawStar] .IS.S.IS.IS", 1092209, 37426},
  {"f=0", 1092331, 37429},
  {"f=0.1", 1092424, 37432},
  {"f=0.1.structure", 1092529, 37435},
  {"f=0.1.implication", 1092643, 37438},
  {"f=0.1.not-exists", 1092758, 37441},
  {"f=0.1.not-exists-slack", 1092878, 37444}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 116, 6, 321, "Title"],
Cell[1858, 59, 264, 10, 150, "Subsubtitle"],
Cell[2125, 71, 156, 5, 45, "SmallText"],
Cell[2284, 78, 325, 6, 96, "Text"],
Cell[2612, 86, 263, 8, 71, "Text"],

Cell[CellGroupData[{
Cell[2900, 98, 38, 0, 101, "Section"],

Cell[CellGroupData[{
Cell[2963, 102, 37, 0, 89, "Subsection"],
Cell[3003, 104, 57, 0, 46, "Text"],
Cell[3063, 106, 252, 8, 90, "Input"],
Cell[3318, 116, 169, 3, 71, "Text"],
Cell[3490, 121, 126, 5, 46, "Text"],
Cell[3619, 128, 128, 2, 64, "Input"],
Cell[3750, 132, 120, 5, 46, "Text"],
Cell[3873, 139, 131, 2, 64, "Input"],
Cell[4007, 143, 135, 2, 64, "Input"],
Cell[4145, 147, 438, 10, 121, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4620, 162, 40, 0, 89, "Subsection"],
Cell[4663, 164, 117, 3, 46, "Text"],
Cell[4783, 169, 63, 0, 46, "Text"],
Cell[4849, 171, 164, 4, 70, "Text"],
Cell[5016, 177, 200, 5, 70, "Text"],
Cell[5219, 184, 218, 5, 70, "Text"],
Cell[5440, 191, 195, 5, 70, "Text"],
Cell[5638, 198, 41, 0, 46, "Text"],
Cell[5682, 200, 286, 6, 95, "Text"],
Cell[5971, 208, 222, 5, 95, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6242, 219, 41, 0, 101, "Section"],

Cell[CellGroupData[{
Cell[6308, 223, 64, 0, 89, "Subsection"],
Cell[6375, 225, 123, 3, 46, "Text"],
Cell[6501, 230, 192, 7, 70, "Text"],
Cell[6696, 239, 276, 8, 70, "Text"],
Cell[6975, 249, 169, 6, 70, "Text"],
Cell[7147, 257, 234, 7, 70, "Text"],
Cell[7384, 266, 303, 8, 95, "Text"],
Cell[7690, 276, 808, 12, 196, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8535, 293, 79, 0, 63, "Subsection"],
Cell[8617, 295, 31, 0, 46, "Text"],
Cell[8651, 297, 279, 6, 95, "Text"],
Cell[8933, 305, 201, 5, 70, "Text"],
Cell[9137, 312, 121, 3, 46, "Text"],
Cell[9261, 317, 709, 13, 112, "Input"],
Cell[9973, 332, 766, 15, 112, "Input"],
Cell[10742, 349, 570, 12, 88, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11349, 366, 60, 0, 63, "Subsection"],

Cell[CellGroupData[{
Cell[11434, 370, 55, 1, 64, "Input"],
Cell[11492, 373, 183, 3, 58, "Print"]
}, Closed]],
Cell[11690, 379, 204, 7, 46, "Text"],
Cell[11897, 388, 130, 4, 46, "Text"],
Cell[12030, 394, 209, 4, 80, "Input"],
Cell[12242, 400, 110, 4, 46, "Text"],
Cell[12355, 406, 133, 2, 46, "Text"],
Cell[12491, 410, 418, 11, 122, "Input",
  CellTags->"Addition"],
Cell[12912, 423, 125, 4, 46, "Text"],
Cell[13040, 429, 77, 1, 80, "Input"],
Cell[13120, 432, 242, 8, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[13399, 445, 49, 0, 63, "Subsection"],
Cell[13451, 447, 104, 3, 46, "Text"],
Cell[13558, 452, 265, 7, 71, "Text"],
Cell[13826, 461, 115, 1, 46, "Text"],
Cell[13944, 464, 172, 6, 46, "Text"],
Cell[14119, 472, 208, 5, 71, "Text"],
Cell[14330, 479, 208, 5, 71, "Text"],
Cell[14541, 486, 145, 6, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[14723, 497, 43, 0, 63, "Subsection"],
Cell[14769, 499, 86, 1, 64, "Input"],
Cell[14858, 502, 390, 11, 88, "Input",
  CellTags->"Addition of Zero from Left"],

Cell[CellGroupData[{
Cell[15273, 517, 394, 10, 112, "Input"],
Cell[15670, 529, 89, 1, 40, "Output"]
}, Closed]],
Cell[15774, 533, 630, 15, 121, "Text"],

Cell[CellGroupData[{
Cell[16429, 552, 460, 11, 112, "Input"],
Cell[16892, 565, 89, 1, 40, "Output"]
}, Closed]],
Cell[16996, 569, 107, 3, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[17140, 577, 56, 0, 63, "Subsection"],
Cell[17199, 579, 175, 5, 46, "Text"],
Cell[17377, 586, 73, 1, 64, "Input"],
Cell[17453, 589, 404, 11, 89, "Input",
  CellTags->"Addition from Left"],

Cell[CellGroupData[{
Cell[17882, 604, 378, 10, 64, "Input"],
Cell[18263, 616, 89, 1, 40, "Output"]
}, Closed]],
Cell[18367, 620, 117, 3, 46, "Text"],
Cell[18487, 625, 422, 11, 88, "Input",
  CellTags->"Associativity of Addition"],

Cell[CellGroupData[{
Cell[18934, 640, 389, 10, 88, "Input"],
Cell[19326, 652, 89, 1, 40, "Output"]
}, Closed]],
Cell[19430, 656, 108, 3, 46, "Text"],
Cell[19541, 661, 395, 11, 88, "Input",
  CellTags->"Commutativity of Addition"],

Cell[CellGroupData[{
Cell[19961, 676, 317, 9, 64, "Input"],
Cell[20281, 687, 89, 1, 40, "Output"]
}, Closed]],
Cell[20385, 691, 171, 3, 71, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20605, 700, 50, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[20680, 704, 34, 0, 89, "Subsection"],
Cell[20717, 706, 221, 6, 70, "Text"],
Cell[20941, 714, 347, 8, 95, "Text"],
Cell[21291, 724, 274, 7, 95, "Text"],
Cell[21568, 733, 339, 7, 95, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[21944, 745, 83, 1, 89, "Subsection"],
Cell[22030, 748, 75, 1, 64, "Input"],
Cell[22108, 751, 601, 14, 180, "Input",
  CellTags->"Equational Properties of Addition"],
Cell[22712, 767, 233, 3, 71, "Text"],

Cell[CellGroupData[{
Cell[22970, 774, 394, 9, 112, "Input"],
Cell[23367, 785, 283, 4, 40, "Output"]
}, Closed]],
Cell[23665, 792, 150, 3, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[23852, 800, 103, 2, 89, "Subsection"],
Cell[23958, 804, 66, 1, 46, "Text"],
Cell[24027, 807, 224, 5, 71, "Text"],
Cell[24254, 814, 281, 5, 71, "Text"],
Cell[24538, 821, 194, 4, 71, "Text"],
Cell[24735, 827, 109, 3, 46, "Text"],
Cell[24847, 832, 112, 4, 46, "Text"],
Cell[24962, 838, 44, 1, 64, "Input"],
Cell[25009, 841, 42, 1, 64, "Input"],
Cell[25054, 844, 42, 1, 64, "Input"],
Cell[25099, 847, 49, 1, 65, "Input"],
Cell[25151, 850, 49, 1, 65, "Input"],
Cell[25203, 853, 42, 1, 64, "Input"],
Cell[25248, 856, 42, 1, 64, "Input"],
Cell[25293, 859, 52, 1, 64, "Input"],
Cell[25348, 862, 52, 1, 64, "Input"],
Cell[25403, 865, 54, 0, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[25494, 870, 53, 0, 89, "Subsection"],

Cell[CellGroupData[{
Cell[25572, 874, 37, 0, 84, "Subsubsection"],
Cell[25612, 876, 27, 0, 46, "Text"],
Cell[25642, 878, 833, 18, 113, "Input",
  CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
Cell[26478, 898, 39, 0, 46, "Text"],
Cell[26520, 900, 429, 6, 146, "Text"],
Cell[26952, 908, 34, 0, 46, "Text"],
Cell[26989, 910, 452, 11, 106, "Input",
  CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
Cell[27444, 923, 476, 10, 126, "Input",
  CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
Cell[27923, 935, 600, 12, 112, "Input",
  CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],
Cell[28526, 949, 198, 5, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[28761, 959, 41, 0, 84, "Subsubsection"],

Cell[CellGroupData[{
Cell[28827, 963, 456, 11, 113, "Input",
  CellTags->{
  "1-ary limit", "2-ary limit", "3-ary limit", "4-ary limit", "limit"}],
Cell[29286, 976, 204, 4, 34, "Message",
  CellTags->"1-ary limit"]
}, Closed]],
Cell[29505, 983, 463, 12, 106, "Input",
  CellTags->"2-ary limit"],
Cell[29971, 997, 486, 12, 113, "Input",
  CellTags->{"2-ary limit", "3-ary limit"}],
Cell[30460, 1011, 704, 15, 113, "Input",
  CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}]
}, Closed]],

Cell[CellGroupData[{
Cell[31201, 1031, 56, 0, 84, "Subsubsection"],
Cell[31260, 1033, 411, 11, 88, "Input",
  CellTags->"sum of sequences"],
Cell[31674, 1046, 787, 17, 88, "Input",
  CellTags->"distance of sum"],

Cell[CellGroupData[{
Cell[32486, 1067, 459, 12, 88, "Input",
  CellTags->"max"],
Cell[32948, 1081, 192, 4, 35, "Message",
  CellTags->"max"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[33189, 1091, 45, 0, 84, "Subsubsection"],
Cell[33237, 1093, 65, 0, 46, "Text"],
Cell[33305, 1095, 446, 11, 178, "Input",
  CellTags->"4-ary limit"],
Cell[33754, 1108, 618, 13, 137, "Input",
  CellTags->"4-ary limit of sum"],
Cell[34375, 1123, 272, 4, 88, "Input"],

Cell[CellGroupData[{
Cell[34672, 1131, 334, 7, 88, "Input"],
Cell[35009, 1140, 128, 2, 60, "Output"]
}, Closed]],
Cell[35152, 1145, 76, 0, 39, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[35265, 1150, 43, 0, 84, "Subsubsection"],
Cell[35311, 1152, 353, 9, 119, "Input",
  CellTags->"3-ary limit"],
Cell[35667, 1163, 570, 12, 137, "Input",
  CellTags->"3-ary limit of sum"],

Cell[CellGroupData[{
Cell[36262, 1179, 356, 8, 88, "Input"],
Cell[36621, 1189, 127, 2, 40, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[36797, 1197, 43, 0, 84, "Subsubsection"],
Cell[36843, 1199, 605, 14, 137, "Input",
  CellTags->"3-ary limit of sum: variant"],
Cell[37451, 1215, 362, 9, 119, "Input",
  CellTags->"2-ary limit"],
Cell[37816, 1226, 499, 12, 137, "Input",
  CellTags->"2-ary limit of sum"],

Cell[CellGroupData[{
Cell[38340, 1242, 325, 7, 88, "Input"],
Cell[38668, 1251, 128, 2, 40, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[38845, 1259, 43, 0, 84, "Subsubsection"],
Cell[38891, 1261, 144, 5, 46, "Text"],
Cell[39038, 1268, 419, 10, 149, "Input",
  CellTags->{"1-ary limit", "2-ary limit"}],
Cell[39460, 1280, 527, 12, 126, "Input",
  CellTags->{"2-ary limit", "3-ary limit", "4-ary limit"}],

Cell[CellGroupData[{
Cell[40012, 1296, 300, 9, 88, "Input"],
Cell[40315, 1307, 128, 2, 40, "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[40516, 1317, 49, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[40590, 1321, 43, 0, 89, "Subsection"],

Cell[CellGroupData[{
Cell[40658, 1325, 74, 0, 84, "Subsubsection"],
Cell[40735, 1327, 246, 4, 71, "Text"],
Cell[40984, 1333, 667, 15, 212, "Input",
  CellTags->"Equational Properties of Addition"],
Cell[41654, 1350, 398, 11, 122, "Input",
  CellTags->"Multiplication"],
Cell[42055, 1363, 372, 10, 88, "Input",
  CellTags->"Commutativity of Multiplication"],

Cell[CellGroupData[{
Cell[42452, 1377, 380, 8, 112, "Input"],
Cell[42835, 1387, 128, 2, 40, "Output"]
}, Closed]],
Cell[42978, 1392, 120, 3, 39, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[43135, 1400, 62, 0, 84, "Subsubsection"],
Cell[43200, 1402, 432, 10, 43, "Text"],
Cell[43635, 1414, 324, 12, 46, "Text"],
Cell[43962, 1428, 312, 11, 46, "Text"],
Cell[44277, 1441, 410, 11, 88, "Input",
  CellTags->{
  "Multiplication", "Multiplication of Zero from Left", "Zero from Left"}],

Cell[CellGroupData[{
Cell[44712, 1456, 381, 8, 112, "Input"],
Cell[45096, 1466, 128, 2, 40, "Output"]
}, Closed]],
Cell[45239, 1471, 88, 2, 46, "Text"],
Cell[45330, 1475, 91, 2, 46, "Text"],

Cell[CellGroupData[{
Cell[45446, 1481, 446, 9, 136, "Input"],
Cell[45895, 1492, 128, 2, 40, "Output"]
}, Closed]],
Cell[46038, 1497, 150, 3, 71, "Text"],
Cell[46191, 1502, 758, 20, 43, "Text"],
Cell[46952, 1524, 1707, 47, 65, "Input"],
Cell[48662, 1573, 66, 0, 46, "Text"],
Cell[48731, 1575, 895, 29, 64, "Input"],
Cell[49629, 1606, 530, 19, 46, "Text"],
Cell[50162, 1627, 446, 12, 88, "Input",
  CellTags->{
  "Commutativity of Addition", "Multiplication", 
    "Multiplication of Zero from Left", "Zero from Left"}],
Cell[50611, 1641, 103, 3, 46, "Text"],
Cell[50717, 1646, 91, 2, 46, "Text"],

Cell[CellGroupData[{
Cell[50833, 1652, 513, 10, 160, "Input"],
Cell[51349, 1664, 128, 2, 40, "Output"]
}, Closed]],
Cell[51492, 1669, 114, 3, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[51643, 1677, 52, 0, 84, "Subsubsection"],
Cell[51698, 1679, 60, 0, 46, "Text"],
Cell[51761, 1681, 313, 6, 71, "Text"],
Cell[52077, 1689, 237, 5, 71, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[52363, 1700, 49, 0, 89, "Subsection"],
Cell[52415, 1702, 621, 23, 96, "Text"],
Cell[53039, 1727, 104, 1, 70, "Text"],
Cell[53146, 1730, 376, 11, 64, "Input"],
Cell[53525, 1743, 5027, 154, 376, "Input"],
Cell[58555, 1899, 62, 0, 46, "Text"],
Cell[58620, 1901, 342, 11, 71, "Text"],
Cell[58965, 1914, 831, 26, 64, "Input"],
Cell[59799, 1942, 329, 9, 71, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[60177, 1957, 76, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[60278, 1961, 54, 0, 89, "Subsection"],
Cell[60335, 1963, 48, 0, 46, "Text"],
Cell[60386, 1965, 186, 6, 46, "Text"],
Cell[60575, 1973, 112, 1, 46, "Text"],
Cell[60690, 1976, 113, 3, 46, "Text"],
Cell[60806, 1981, 715, 16, 241, "Input",
  CellTags->"Equational Properties of Addition"],
Cell[61524, 1999, 635, 16, 182, "Input",
  CellTags->{
  "Multiplication", "Some Equational Properties of Multiplication"}],
Cell[62162, 2017, 459, 12, 88, "Input",
  CellTags->{
  "Associativity of Multiplication", "Associativity of Multiplicatios", 
    "Multiplication"}],

Cell[CellGroupData[{
Cell[62646, 2033, 425, 9, 136, "Input"],
Cell[63074, 2044, 128, 2, 60, "Output"]
}, Closed]],
Cell[63217, 2049, 109, 3, 39, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[63363, 2057, 65, 0, 89, "Subsection"],
Cell[63431, 2059, 61, 0, 46, "Text"],
Cell[63495, 2061, 47, 0, 46, "Text"],
Cell[63545, 2063, 1019, 33, 46, "Text"],
Cell[64567, 2098, 1684, 50, 46, "Text"],
Cell[66254, 2150, 1925, 56, 46, "Text"],
Cell[68182, 2208, 2094, 60, 46, "Text"],
Cell[70279, 2270, 2308, 65, 46, "Text"],
Cell[72590, 2337, 2524, 70, 46, "Text"],
Cell[75117, 2409, 2555, 70, 46, "Text"],
Cell[77675, 2481, 2776, 71, 46, "Text"],
Cell[80454, 2554, 2776, 71, 46, "Text"],
Cell[83233, 2627, 2776, 71, 46, "Text"],
Cell[86012, 2700, 2776, 71, 46, "Text"],
Cell[88791, 2773, 2781, 71, 46, "Text"],
Cell[91575, 2846, 2718, 67, 46, "Text"],
Cell[94296, 2915, 47, 0, 46, "Text"],
Cell[94346, 2917, 1222, 39, 46, "Text"],
Cell[95571, 2958, 1466, 45, 46, "Text"],
Cell[97040, 3005, 1925, 56, 46, "Text"],
Cell[98968, 3063, 2094, 60, 46, "Text"],
Cell[101065, 3125, 2308, 65, 46, "Text"],
Cell[103376, 3192, 2525, 70, 46, "Text"],
Cell[105904, 3264, 2554, 70, 46, "Text"],
Cell[108461, 3336, 2776, 71, 46, "Text"],
Cell[111240, 3409, 2776, 71, 46, "Text"],
Cell[114019, 3482, 2776, 71, 46, "Text"],
Cell[116798, 3555, 2776, 71, 46, "Text"],
Cell[119577, 3628, 2776, 71, 46, "Text"],
Cell[122356, 3701, 2781, 71, 46, "Text"],
Cell[125140, 3774, 2780, 71, 46, "Text"],
Cell[127923, 3847, 2800, 72, 46, "Text"],
Cell[130726, 3921, 2780, 71, 46, "Text"],
Cell[133509, 3994, 2718, 67, 46, "Text"],
Cell[136230, 4063, 351, 6, 96, "Text"],
Cell[136584, 4071, 182, 4, 46, "Text"],
Cell[136769, 4077, 85, 1, 46, "Text"],
Cell[136857, 4080, 115, 1, 46, "Text"],
Cell[136975, 4083, 454, 7, 121, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[137466, 4095, 96, 2, 89, "Subsection"],
Cell[137565, 4099, 435, 7, 121, "Text"],
Cell[138003, 4108, 65, 0, 46, "Text"],
Cell[138071, 4110, 594, 14, 182, "Input",
  CellTags->"Equational Properties of Addition"],
Cell[138668, 4126, 85, 2, 46, "Text"],

Cell[CellGroupData[{
Cell[138778, 4132, 591, 13, 160, "Input"],
Cell[139372, 4147, 127, 2, 40, "Output"]
}, Closed]],
Cell[139514, 4152, 123, 4, 46, "Text"],
Cell[139640, 4158, 210, 4, 71, "Text"],
Cell[139853, 4164, 47, 0, 46, "Text"],
Cell[139903, 4166, 1443, 43, 46, "Text"],
Cell[141349, 4211, 1436, 43, 46, "Text"],
Cell[142788, 4256, 2455, 66, 46, "Text"],
Cell[145246, 4324, 2648, 67, 46, "Text"],
Cell[147897, 4393, 2903, 68, 46, "Text"],
Cell[150803, 4463, 2887, 68, 46, "Text"],
Cell[153693, 4533, 3149, 73, 46, "Text"],
Cell[156845, 4608, 3083, 68, 46, "Text"],
Cell[159931, 4678, 47, 0, 46, "Text"],
Cell[159981, 4680, 1690, 49, 46, "Text"],
Cell[161674, 4731, 1663, 49, 46, "Text"],
Cell[163340, 4782, 1866, 54, 46, "Text"],
Cell[165209, 4838, 1907, 54, 46, "Text"],
Cell[167119, 4894, 2669, 70, 46, "Text"],
Cell[169791, 4966, 2886, 71, 46, "Text"],
Cell[172680, 5039, 3156, 72, 46, "Text"],
Cell[175839, 5113, 3083, 68, 46, "Text"],
Cell[178925, 5183, 238, 4, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[179200, 5192, 94, 2, 89, "Subsection"],
Cell[179297, 5196, 322, 5, 96, "Text"],
Cell[179622, 5203, 31, 0, 46, "Text"],
Cell[179656, 5205, 289, 5, 71, "Text"],
Cell[179948, 5212, 306, 5, 71, "Text"],
Cell[180257, 5219, 529, 11, 121, "Text"],
Cell[180789, 5232, 308, 5, 71, "Text"],
Cell[181100, 5239, 313, 6, 71, "Text"],
Cell[181416, 5247, 514, 10, 121, "Text"],
Cell[181933, 5259, 358, 6, 96, "Text"],
Cell[182294, 5267, 98, 2, 64, "Input"],
Cell[182395, 5271, 847, 19, 192, "Input",
  CellTags->{"GB-Test", "GBTest11"}],

Cell[CellGroupData[{
Cell[183267, 5294, 111, 2, 64, "Input"],
Cell[183381, 5298, 128, 2, 40, "Output"]
}, Closed]],
Cell[183524, 5303, 71, 0, 46, "Text"],
Cell[183598, 5305, 282, 6, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[183917, 5316, 74, 0, 89, "Subsection"],
Cell[183994, 5318, 228, 6, 71, "Text"],
Cell[184225, 5326, 158, 5, 46, "Text"],
Cell[184386, 5333, 144, 5, 46, "Text"],
Cell[184533, 5340, 218, 8, 46, "Text"],
Cell[184754, 5350, 292, 11, 46, "Text"],
Cell[185049, 5363, 438, 22, 70, "Text"],
Cell[185490, 5387, 127, 5, 46, "Text"],
Cell[185620, 5394, 232, 4, 71, "Text"],
Cell[185855, 5400, 291, 7, 71, "Text"],
Cell[186149, 5409, 361, 10, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[186547, 5424, 69, 0, 89, "Subsection"],
Cell[186619, 5426, 159, 3, 71, "Text"],
Cell[186781, 5431, 187, 4, 71, "Text"],
Cell[186971, 5437, 515, 10, 121, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[187535, 5453, 29, 0, 69, "Section"],
Cell[187567, 5455, 498, 10, 120, "Text"],
Cell[188068, 5467, 195, 6, 70, "Text"],
Cell[188266, 5475, 169, 5, 46, "Text"],
Cell[188438, 5482, 184, 6, 46, "Text"],
Cell[188625, 5490, 263, 7, 71, "Text"],
Cell[188891, 5499, 153, 3, 46, "Text"],
Cell[189047, 5504, 220, 6, 46, "Text"],
Cell[189270, 5512, 241, 6, 71, "Text"],
Cell[189514, 5520, 219, 6, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[189770, 5531, 35, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[189830, 5535, 63, 0, 89, "Subsection"],
Cell[189896, 5537, 22, 0, 46, "Text"],
Cell[189921, 5539, 739, 27, 43, "Conclusion",
  CellTags->"0+ "],
Cell[190663, 5568, 38, 0, 46, "Text"],
Cell[190704, 5570, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[191440, 5598, 1330, 43, 45, "Assumption",
  CellTags->" +succ"],
Cell[192773, 5643, 129, 3, 46, "Text"],
Cell[192905, 5648, 43, 0, 46, "Text"],
Cell[192951, 5650, 249, 10, 46, "Text"],
Cell[193203, 5662, 43, 0, 46, "Text"],
Cell[193249, 5664, 351, 18, 46, "Text"],
Cell[193603, 5684, 32, 0, 46, "Text"],
Cell[193638, 5686, 184, 9, 33, "Conclusion",
  CellTags->"1"],
Cell[193825, 5697, 200, 10, 46, "Text"],
Cell[194028, 5709, 47, 0, 46, "Text"],
Cell[194078, 5711, 267, 14, 46, "Text"],
Cell[194348, 5727, 112, 5, 46, "Text"],
Cell[194463, 5734, 47, 0, 46, "Text"],
Cell[194513, 5736, 112, 5, 46, "Text"],
Cell[194628, 5743, 31, 0, 46, "Text"],
Cell[194662, 5745, 75, 3, 46, "Text"],
Cell[194740, 5750, 452, 17, 33, "Assumption",
  CellTags->"2"],
Cell[195195, 5769, 75, 3, 46, "Text"],
Cell[195273, 5774, 537, 20, 33, "Conclusion",
  CellTags->"3"],
Cell[195813, 5796, 200, 10, 46, "Text"],
Cell[196016, 5808, 47, 0, 46, "Text"],
Cell[196066, 5810, 439, 19, 46, "Text"],
Cell[196508, 5831, 468, 20, 46, "Text"],
Cell[196979, 5853, 245, 9, 46, "Text"],
Cell[197227, 5864, 47, 0, 46, "Text"],
Cell[197277, 5866, 245, 9, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[197559, 5880, 48, 0, 63, "Subsection"],
Cell[197610, 5882, 22, 0, 46, "Text"],
Cell[197635, 5884, 733, 26, 43, "Conclusion",
  CellTags->"0+ "],
Cell[198371, 5912, 38, 0, 46, "Text"],
Cell[198412, 5914, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[199148, 5942, 1330, 43, 45, "Assumption",
  CellTags->" +succ"],
Cell[200481, 5987, 351, 18, 46, "Text"],
Cell[200835, 6007, 32, 0, 46, "Text"],
Cell[200870, 6009, 184, 9, 33, "Conclusion",
  CellTags->"1"],
Cell[201057, 6020, 200, 10, 46, "Text"],
Cell[201260, 6032, 47, 0, 46, "Text"],
Cell[201310, 6034, 267, 14, 46, "Text"],
Cell[201580, 6050, 112, 5, 46, "Text"],
Cell[201695, 6057, 47, 0, 46, "Text"],
Cell[201745, 6059, 112, 5, 46, "Text"],
Cell[201860, 6066, 31, 0, 46, "Text"],
Cell[201894, 6068, 75, 3, 46, "Text"],
Cell[201972, 6073, 452, 17, 33, "Assumption",
  CellTags->"2"],
Cell[202427, 6092, 75, 3, 46, "Text"],
Cell[202505, 6097, 537, 20, 33, "Conclusion",
  CellTags->"3"],
Cell[203045, 6119, 200, 10, 46, "Text"],
Cell[203248, 6131, 47, 0, 46, "Text"],
Cell[203298, 6133, 439, 19, 46, "Text"],
Cell[203740, 6154, 468, 20, 46, "Text"],
Cell[204211, 6176, 245, 9, 46, "Text"],
Cell[204459, 6187, 47, 0, 46, "Text"],
Cell[204509, 6189, 245, 9, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[204791, 6203, 46, 0, 63, "Subsection"],
Cell[204840, 6205, 22, 0, 46, "Text"],
Cell[204865, 6207, 1330, 43, 45, "Conclusion",
  CellTags->"succ+ "],
Cell[206198, 6252, 38, 0, 46, "Text"],
Cell[206239, 6254, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[206975, 6282, 1330, 43, 45, "Assumption",
  CellTags->" +succ"],
Cell[208308, 6327, 357, 18, 46, "Text"],
Cell[208668, 6347, 32, 0, 46, "Text"],
Cell[208703, 6349, 869, 30, 43, "Conclusion",
  CellTags->"1"],
Cell[209575, 6381, 347, 18, 46, "Text"],
Cell[209925, 6401, 32, 0, 46, "Text"],
Cell[209960, 6403, 202, 8, 33, "Conclusion",
  CellTags->"4"],
Cell[210165, 6413, 200, 10, 46, "Text"],
Cell[210368, 6425, 47, 0, 46, "Text"],
Cell[210418, 6427, 274, 14, 46, "Text"],
Cell[210695, 6443, 119, 5, 46, "Text"],
Cell[210817, 6450, 47, 0, 46, "Text"],
Cell[210867, 6452, 280, 14, 46, "Text"],
Cell[211150, 6468, 119, 5, 46, "Text"],
Cell[211272, 6475, 31, 0, 46, "Text"],
Cell[211306, 6477, 75, 3, 46, "Text"],
Cell[211384, 6482, 575, 20, 33, "Assumption",
  CellTags->"5"],
Cell[211962, 6504, 75, 3, 46, "Text"],
Cell[212040, 6509, 666, 23, 33, "Conclusion",
  CellTags->"6"],
Cell[212709, 6534, 200, 10, 46, "Text"],
Cell[212912, 6546, 47, 0, 46, "Text"],
Cell[212962, 6548, 444, 19, 46, "Text"],
Cell[213409, 6569, 473, 20, 46, "Text"],
Cell[213885, 6591, 411, 14, 46, "Text"],
Cell[214299, 6607, 47, 0, 46, "Text"],
Cell[214349, 6609, 520, 21, 46, "Text"],
Cell[214872, 6632, 411, 14, 46, "Text"],
Cell[215286, 6648, 31, 0, 46, "Text"],
Cell[215320, 6650, 75, 3, 46, "Text"],
Cell[215398, 6655, 1193, 38, 43, "Assumption",
  CellTags->"2"],
Cell[216594, 6695, 75, 3, 46, "Text"],
Cell[216672, 6700, 1341, 42, 43, "Conclusion",
  CellTags->"3"],
Cell[218016, 6744, 210, 10, 46, "Text"],
Cell[218229, 6756, 993, 31, 33, "Conclusion",
  CellTags->"7"],
Cell[219225, 6789, 32, 0, 46, "Text"],
Cell[219260, 6791, 47, 0, 46, "Text"],
Cell[219310, 6793, 477, 16, 46, "Text"],
Cell[219790, 6811, 47, 0, 46, "Text"],
Cell[219840, 6813, 640, 25, 46, "Text"],
Cell[220483, 6840, 557, 18, 46, "Text"],
Cell[221043, 6860, 49, 0, 46, "Text"],
Cell[221095, 6862, 1412, 43, 43, "Conclusion",
  CellTags->"8"],
Cell[222510, 6907, 347, 18, 46, "Text"],
Cell[222860, 6927, 32, 0, 46, "Text"],
Cell[222895, 6929, 802, 27, 33, "Conclusion",
  CellTags->"9"],
Cell[223700, 6958, 200, 10, 46, "Text"],
Cell[223903, 6970, 47, 0, 46, "Text"],
Cell[223953, 6972, 519, 22, 46, "Text"],
Cell[224475, 6996, 322, 11, 46, "Text"],
Cell[224800, 7009, 47, 0, 46, "Text"],
Cell[224850, 7011, 562, 23, 46, "Text"],
Cell[225415, 7036, 322, 11, 46, "Text"],
Cell[225740, 7049, 31, 0, 46, "Text"],
Cell[225774, 7051, 75, 3, 46, "Text"],
Cell[225852, 7056, 1067, 34, 33, "Assumption",
  CellTags->"10"],
Cell[226922, 7092, 75, 3, 46, "Text"],
Cell[227000, 7097, 1156, 36, 33, "Conclusion",
  CellTags->"11"],
Cell[228159, 7135, 202, 10, 46, "Text"],
Cell[228364, 7147, 47, 0, 46, "Text"],
Cell[228414, 7149, 672, 26, 46, "Text"],
Cell[229089, 7177, 731, 27, 46, "Text"],
Cell[229823, 7206, 670, 20, 46, "Text"],
Cell[230496, 7228, 47, 0, 46, "Text"],
Cell[230546, 7230, 760, 28, 46, "Text"],
Cell[231309, 7260, 670, 20, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[232016, 7285, 50, 0, 63, "Subsection"],
Cell[232069, 7287, 22, 0, 46, "Text"],
Cell[232094, 7289, 1787, 55, 46, "Conclusion",
  CellTags->"( + )+ "],
Cell[233884, 7346, 38, 0, 46, "Text"],
Cell[233925, 7348, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[234661, 7376, 1330, 43, 45, "Assumption",
  CellTags->" +succ"],
Cell[235994, 7421, 359, 18, 46, "Text"],
Cell[236356, 7441, 32, 0, 46, "Text"],
Cell[236391, 7443, 1358, 43, 46, "Conclusion",
  CellTags->"1"],
Cell[237752, 7488, 347, 18, 46, "Text"],
Cell[238102, 7508, 32, 0, 46, "Text"],
Cell[238137, 7510, 866, 29, 46, "Conclusion",
  CellTags->"4"],
Cell[239006, 7541, 210, 10, 46, "Text"],
Cell[239219, 7553, 577, 20, 33, "Conclusion",
  CellTags->"7"],
Cell[239799, 7575, 32, 0, 46, "Text"],
Cell[239834, 7577, 47, 0, 46, "Text"],
Cell[239884, 7579, 403, 18, 46, "Text"],
Cell[240290, 7599, 244, 9, 46, "Text"],
Cell[240537, 7610, 47, 0, 46, "Text"],
Cell[240587, 7612, 320, 11, 46, "Text"],
Cell[240910, 7625, 49, 0, 46, "Text"],
Cell[240962, 7627, 858, 29, 46, "Conclusion",
  CellTags->"8"],
Cell[241823, 7658, 347, 18, 46, "Text"],
Cell[242173, 7678, 32, 0, 46, "Text"],
Cell[242208, 7680, 198, 9, 33, "Conclusion",
  CellTags->"9"],
Cell[242409, 7691, 200, 10, 46, "Text"],
Cell[242612, 7703, 47, 0, 46, "Text"],
Cell[242662, 7705, 116, 5, 46, "Text"],
Cell[242781, 7712, 47, 0, 46, "Text"],
Cell[242831, 7714, 277, 14, 46, "Text"],
Cell[243111, 7730, 116, 5, 46, "Text"],
Cell[243230, 7737, 31, 0, 46, "Text"],
Cell[243264, 7739, 75, 3, 46, "Text"],
Cell[243342, 7744, 571, 20, 33, "Assumption",
  CellTags->"10"],
Cell[243916, 7766, 75, 3, 46, "Text"],
Cell[243994, 7771, 662, 23, 33, "Conclusion",
  CellTags->"11"],
Cell[244659, 7796, 202, 10, 46, "Text"],
Cell[244864, 7808, 47, 0, 46, "Text"],
Cell[244914, 7810, 439, 19, 46, "Text"],
Cell[245356, 7831, 321, 11, 46, "Text"],
Cell[245680, 7844, 47, 0, 46, "Text"],
Cell[245730, 7846, 519, 21, 46, "Text"],
Cell[246252, 7869, 519, 21, 46, "Text"],
Cell[246774, 7892, 554, 22, 46, "Text"],
Cell[247331, 7916, 321, 11, 46, "Text"],
Cell[247655, 7929, 31, 0, 46, "Text"],
Cell[247689, 7931, 75, 3, 46, "Text"],
Cell[247767, 7936, 1231, 38, 46, "Assumption",
  CellTags->"5"],
Cell[249001, 7976, 75, 3, 46, "Text"],
Cell[249079, 7981, 1334, 41, 46, "Conclusion",
  CellTags->"6"],
Cell[250416, 8024, 210, 10, 46, "Text"],
Cell[250629, 8036, 999, 32, 33, "Conclusion",
  CellTags->"12"],
Cell[251631, 8070, 32, 0, 46, "Text"],
Cell[251666, 8072, 47, 0, 46, "Text"],
Cell[251716, 8074, 633, 25, 46, "Text"],
Cell[252352, 8101, 476, 16, 46, "Text"],
Cell[252831, 8119, 47, 0, 46, "Text"],
Cell[252881, 8121, 492, 16, 46, "Text"],
Cell[253376, 8139, 49, 0, 46, "Text"],
Cell[253428, 8141, 1336, 41, 46, "Conclusion",
  CellTags->"13"],
Cell[254767, 8184, 349, 18, 46, "Text"],
Cell[255119, 8204, 32, 0, 46, "Text"],
Cell[255154, 8206, 751, 26, 33, "Conclusion",
  CellTags->"14"],
Cell[255908, 8234, 202, 10, 46, "Text"],
Cell[256113, 8246, 47, 0, 46, "Text"],
Cell[256163, 8248, 513, 21, 46, "Text"],
Cell[256679, 8271, 321, 11, 46, "Text"],
Cell[257003, 8284, 47, 0, 46, "Text"],
Cell[257053, 8286, 513, 21, 46, "Text"],
Cell[257569, 8309, 439, 19, 46, "Text"],
Cell[258011, 8330, 321, 11, 46, "Text"],
Cell[258335, 8343, 31, 0, 46, "Text"],
Cell[258369, 8345, 75, 3, 46, "Text"],
Cell[258447, 8350, 999, 32, 33, "Assumption",
  CellTags->"15"],
Cell[259449, 8384, 75, 3, 46, "Text"],
Cell[259527, 8389, 1090, 35, 33, "Conclusion",
  CellTags->"16"],
Cell[260620, 8426, 202, 10, 46, "Text"],
Cell[260825, 8438, 47, 0, 46, "Text"],
Cell[260875, 8440, 671, 26, 46, "Text"],
Cell[261549, 8468, 581, 18, 46, "Text"],
Cell[262133, 8488, 47, 0, 46, "Text"],
Cell[262183, 8490, 691, 26, 46, "Text"],
Cell[262877, 8518, 701, 26, 46, "Text"],
Cell[263581, 8546, 746, 27, 46, "Text"],
Cell[264330, 8575, 581, 18, 46, "Text"],
Cell[264914, 8595, 31, 0, 46, "Text"],
Cell[264948, 8597, 75, 3, 46, "Text"],
Cell[265026, 8602, 1643, 50, 46, "Assumption",
  CellTags->"2"],
Cell[266672, 8654, 75, 3, 46, "Text"],
Cell[266750, 8659, 1742, 53, 46, "Conclusion",
  CellTags->"3"],
Cell[268495, 8714, 347, 18, 46, "Text"],
Cell[268845, 8734, 32, 0, 46, "Text"],
Cell[268880, 8736, 1316, 41, 46, "Conclusion",
  CellTags->"17"],
Cell[270199, 8779, 212, 10, 46, "Text"],
Cell[270414, 8791, 979, 32, 33, "Conclusion",
  CellTags->"20"],
Cell[271396, 8825, 32, 0, 46, "Text"],
Cell[271431, 8827, 47, 0, 46, "Text"],
Cell[271481, 8829, 627, 25, 46, "Text"],
Cell[272111, 8856, 396, 14, 46, "Text"],
Cell[272510, 8872, 47, 0, 46, "Text"],
Cell[272560, 8874, 472, 16, 46, "Text"],
Cell[273035, 8892, 49, 0, 46, "Text"],
Cell[273087, 8894, 1224, 39, 46, "Conclusion",
  CellTags->"21"],
Cell[274314, 8935, 349, 18, 46, "Text"],
Cell[274666, 8955, 32, 0, 46, "Text"],
Cell[274701, 8957, 586, 21, 33, "Conclusion",
  CellTags->"22"],
Cell[275290, 8980, 202, 10, 46, "Text"],
Cell[275495, 8992, 47, 0, 46, "Text"],
Cell[275545, 8994, 282, 10, 46, "Text"],
Cell[275830, 9006, 47, 0, 46, "Text"],
Cell[275880, 9008, 441, 19, 46, "Text"],
Cell[276324, 9029, 282, 10, 46, "Text"],
Cell[276609, 9041, 31, 0, 46, "Text"],
Cell[276643, 9043, 75, 3, 46, "Text"],
Cell[276721, 9048, 895, 30, 33, "Assumption",
  CellTags->"23"],
Cell[277619, 9080, 75, 3, 46, "Text"],
Cell[277697, 9085, 986, 33, 33, "Conclusion",
  CellTags->"24"],
Cell[278686, 9120, 202, 10, 46, "Text"],
Cell[278891, 9132, 47, 0, 46, "Text"],
Cell[278941, 9134, 591, 24, 46, "Text"],
Cell[279535, 9160, 493, 16, 46, "Text"],
Cell[280031, 9178, 47, 0, 46, "Text"],
Cell[280081, 9180, 671, 26, 46, "Text"],
Cell[280755, 9208, 671, 26, 46, "Text"],
Cell[281429, 9236, 726, 27, 46, "Text"],
Cell[282158, 9265, 493, 16, 46, "Text"],
Cell[282654, 9283, 31, 0, 46, "Text"],
Cell[282688, 9285, 75, 3, 46, "Text"],
Cell[282766, 9290, 1617, 48, 46, "Assumption",
  CellTags->"18"],
Cell[284386, 9340, 75, 3, 46, "Text"],
Cell[284464, 9345, 1720, 51, 46, "Conclusion",
  CellTags->"19"],
Cell[286187, 9398, 212, 10, 46, "Text"],
Cell[286402, 9410, 1343, 42, 33, "Conclusion",
  CellTags->"25"],
Cell[287748, 9454, 32, 0, 46, "Text"],
Cell[287783, 9456, 47, 0, 46, "Text"],
Cell[287833, 9458, 805, 30, 46, "Text"],
Cell[288641, 9490, 658, 21, 46, "Text"],
Cell[289302, 9513, 47, 0, 46, "Text"],
Cell[289352, 9515, 644, 21, 46, "Text"],
Cell[289999, 9538, 49, 0, 46, "Text"],
Cell[290051, 9540, 1730, 51, 46, "Conclusion",
  CellTags->"26"],
Cell[291784, 9593, 349, 18, 46, "Text"],
Cell[292136, 9613, 32, 0, 46, "Text"],
Cell[292171, 9615, 1105, 36, 33, "Conclusion",
  CellTags->"27"],
Cell[293279, 9653, 202, 10, 46, "Text"],
Cell[293484, 9665, 47, 0, 46, "Text"],
Cell[293534, 9667, 695, 26, 46, "Text"],
Cell[294232, 9695, 493, 16, 46, "Text"],
Cell[294728, 9713, 47, 0, 46, "Text"],
Cell[294778, 9715, 665, 26, 46, "Text"],
Cell[295446, 9743, 591, 24, 46, "Text"],
Cell[296040, 9769, 493, 16, 46, "Text"],
Cell[296536, 9787, 31, 0, 46, "Text"],
Cell[296570, 9789, 75, 3, 46, "Text"],
Cell[296648, 9794, 1355, 42, 33, "Assumption",
  CellTags->"28"],
Cell[298006, 9838, 75, 3, 46, "Text"],
Cell[298084, 9843, 1446, 45, 33, "Conclusion",
  CellTags->"29"],
Cell[299533, 9890, 202, 10, 46, "Text"],
Cell[299738, 9902, 47, 0, 46, "Text"],
Cell[299788, 9904, 854, 31, 46, "Text"],
Cell[300645, 9937, 784, 23, 46, "Text"],
Cell[301432, 9962, 47, 0, 46, "Text"],
Cell[301482, 9964, 844, 31, 46, "Text"],
Cell[302329, 9997, 854, 31, 46, "Text"],
Cell[303186, 10030, 919, 32, 46, "Text"],
Cell[304108, 10064, 784, 23, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[304929, 10092, 59, 0, 63, "Subsection"],
Cell[304991, 10094, 22, 0, 46, "Text"],
Cell[305016, 10096, 1170, 39, 45, "Conclusion",
  CellTags->" + "],
Cell[306189, 10137, 38, 0, 46, "Text"],
Cell[306230, 10139, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[306966, 10167, 1330, 43, 45, "Assumption",
  CellTags->" +succ"],
Cell[308299, 10212, 129, 3, 46, "Text"],
Cell[308431, 10217, 43, 0, 46, "Text"],
Cell[308477, 10219, 250, 10, 46, "Text"],
Cell[308730, 10231, 43, 0, 46, "Text"],
Cell[308776, 10233, 358, 18, 46, "Text"],
Cell[309137, 10253, 32, 0, 46, "Text"],
Cell[309172, 10255, 770, 27, 43, "Conclusion",
  CellTags->"1"],
Cell[309945, 10284, 129, 3, 46, "Text"],
Cell[310077, 10289, 43, 0, 46, "Text"],
Cell[310123, 10291, 210, 10, 46, "Text"],
Cell[310336, 10303, 489, 18, 33, "Conclusion",
  CellTags->"4"],
Cell[310828, 10323, 32, 0, 46, "Text"],
Cell[310863, 10325, 47, 0, 46, "Text"],
Cell[310913, 10327, 244, 9, 46, "Text"],
Cell[311160, 10338, 47, 0, 46, "Text"],
Cell[311210, 10340, 395, 18, 46, "Text"],
Cell[311608, 10360, 209, 8, 46, "Text"],
Cell[311820, 10370, 49, 0, 46, "Text"],
Cell[311872, 10372, 729, 26, 43, "Conclusion",
  CellTags->"5"],
Cell[312604, 10400, 347, 18, 46, "Text"],
Cell[312954, 10420, 32, 0, 46, "Text"],
Cell[312989, 10422, 184, 9, 33, "Conclusion",
  CellTags->"6"],
Cell[313176, 10433, 200, 10, 46, "Text"],
Cell[313379, 10445, 47, 0, 46, "Text"],
Cell[313429, 10447, 267, 14, 46, "Text"],
Cell[313699, 10463, 112, 5, 46, "Text"],
Cell[313814, 10470, 47, 0, 46, "Text"],
Cell[313864, 10472, 112, 5, 46, "Text"],
Cell[313979, 10479, 31, 0, 46, "Text"],
Cell[314013, 10481, 75, 3, 46, "Text"],
Cell[314091, 10486, 452, 17, 33, "Assumption",
  CellTags->"7"],
Cell[314546, 10505, 75, 3, 46, "Text"],
Cell[314624, 10510, 537, 20, 33, "Conclusion",
  CellTags->"8"],
Cell[315164, 10532, 200, 10, 46, "Text"],
Cell[315367, 10544, 47, 0, 46, "Text"],
Cell[315417, 10546, 439, 19, 46, "Text"],
Cell[315859, 10567, 468, 20, 46, "Text"],
Cell[316330, 10589, 245, 9, 46, "Text"],
Cell[316578, 10600, 47, 0, 46, "Text"],
Cell[316628, 10602, 245, 9, 46, "Text"],
Cell[316876, 10613, 44, 0, 46, "Text"],
Cell[316923, 10615, 241, 11, 70, "Text"],
Cell[317167, 10628, 31, 0, 46, "Text"],
Cell[317201, 10630, 75, 3, 46, "Text"],
Cell[317279, 10635, 1039, 34, 43, "Assumption",
  CellTags->"2"],
Cell[318321, 10671, 75, 3, 46, "Text"],
Cell[318399, 10676, 1134, 37, 43, "Conclusion",
  CellTags->"3"],
Cell[319536, 10715, 129, 3, 46, "Text"],
Cell[319668, 10720, 43, 0, 46, "Text"],
Cell[319714, 10722, 210, 10, 46, "Text"],
Cell[319927, 10734, 813, 28, 33, "Conclusion",
  CellTags->"9"],
Cell[320743, 10764, 32, 0, 46, "Text"],
Cell[320778, 10766, 47, 0, 46, "Text"],
Cell[320828, 10768, 396, 14, 46, "Text"],
Cell[321227, 10784, 47, 0, 46, "Text"],
Cell[321277, 10786, 553, 23, 46, "Text"],
Cell[321833, 10811, 598, 24, 46, "Text"],
Cell[322434, 10837, 451, 15, 46, "Text"],
Cell[322888, 10854, 49, 0, 46, "Text"],
Cell[322940, 10856, 1202, 39, 43, "Conclusion",
  CellTags->"10"],
Cell[324145, 10897, 356, 18, 46, "Text"],
Cell[324504, 10917, 32, 0, 46, "Text"],
Cell[324539, 10919, 619, 22, 33, "Conclusion",
  CellTags->"11"],
Cell[325161, 10943, 179, 10, 46, "Text"],
Cell[325343, 10955, 47, 0, 46, "Text"],
Cell[325393, 10957, 433, 19, 46, "Text"],
Cell[325829, 10978, 245, 9, 46, "Text"],
Cell[326077, 10989, 47, 0, 46, "Text"],
Cell[326127, 10991, 467, 20, 46, "Text"],
Cell[326597, 11013, 321, 11, 46, "Text"],
Cell[326921, 11026, 49, 0, 46, "Text"],
Cell[326973, 11028, 580, 21, 33, "Conclusion",
  CellTags->"14"],
Cell[327556, 11051, 227, 10, 46, "Text"],
Cell[327786, 11063, 31, 0, 46, "Text"],
Cell[327820, 11065, 75, 3, 46, "Text"],
Cell[327898, 11070, 872, 29, 33, "Assumption",
  CellTags->"12"],
Cell[328773, 11101, 75, 3, 46, "Text"],
Cell[328851, 11106, 963, 32, 33, "Conclusion",
  CellTags->"13"],
Cell[329817, 11140, 243, 11, 70, "Text"],
Cell[330063, 11153, 43, 0, 46, "Text"],
Cell[330109, 11155, 354, 18, 46, "Text"],
Cell[330466, 11175, 32, 0, 46, "Text"],
Cell[330501, 11177, 578, 21, 33, "Conclusion",
  CellTags->"15"],
Cell[331082, 11200, 179, 10, 46, "Text"],
Cell[331264, 11212, 47, 0, 46, "Text"],
Cell[331314, 11214, 433, 19, 46, "Text"],
Cell[331750, 11235, 245, 9, 46, "Text"],
Cell[331998, 11246, 47, 0, 46, "Text"],
Cell[332048, 11248, 439, 19, 46, "Text"],
Cell[332490, 11269, 321, 11, 46, "Text"],
Cell[332814, 11282, 49, 0, 46, "Text"],
Cell[332866, 11284, 580, 21, 33, "Conclusion",
  CellTags->"18"],
Cell[333449, 11307, 232, 11, 46, "Text"],
Cell[333684, 11320, 31, 0, 46, "Text"],
Cell[333718, 11322, 75, 3, 46, "Text"],
Cell[333796, 11327, 815, 28, 33, "Assumption",
  CellTags->"16"],
Cell[334614, 11357, 75, 3, 46, "Text"],
Cell[334692, 11362, 902, 31, 33, "Conclusion",
  CellTags->"17"],
Cell[335597, 11395, 243, 11, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[335877, 11411, 54, 0, 63, "Subsection"],
Cell[335934, 11413, 22, 0, 46, "Text"],
Cell[335959, 11415, 733, 26, 43, "Conclusion",
  CellTags->"0+ "],
Cell[336695, 11443, 38, 0, 46, "Text"],
Cell[336736, 11445, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[337472, 11473, 1330, 43, 45, "Assumption",
  CellTags->" +succ"],
Cell[338805, 11518, 351, 18, 46, "Text"],
Cell[339159, 11538, 32, 0, 46, "Text"],
Cell[339194, 11540, 194, 9, 33, "Conclusion",
  CellTags->"0+ .IB"],
Cell[339391, 11551, 210, 10, 46, "Text"],
Cell[339604, 11563, 47, 0, 46, "Text"],
Cell[339654, 11565, 267, 14, 46, "Text"],
Cell[339924, 11581, 112, 5, 46, "Text"],
Cell[340039, 11588, 47, 0, 46, "Text"],
Cell[340089, 11590, 112, 5, 46, "Text"],
Cell[340204, 11597, 31, 0, 46, "Text"],
Cell[340238, 11599, 75, 3, 46, "Text"],
Cell[340316, 11604, 462, 17, 33, "Assumption",
  CellTags->"0+ .IH"],
Cell[340781, 11623, 75, 3, 46, "Text"],
Cell[340859, 11628, 547, 20, 33, "Conclusion",
  CellTags->"0+ .IS"],
Cell[341409, 11650, 210, 10, 46, "Text"],
Cell[341622, 11662, 47, 0, 46, "Text"],
Cell[341672, 11664, 439, 19, 46, "Text"],
Cell[342114, 11685, 478, 20, 46, "Text"],
Cell[342595, 11707, 245, 9, 46, "Text"],
Cell[342843, 11718, 47, 0, 46, "Text"],
Cell[342893, 11720, 245, 9, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[343175, 11734, 54, 0, 63, "Subsection"],
Cell[343232, 11736, 22, 0, 46, "Text"],
Cell[343257, 11738, 1326, 43, 45, "Conclusion",
  CellTags->"^++ "],
Cell[344586, 11783, 38, 0, 46, "Text"],
Cell[344627, 11785, 733, 26, 43, "Assumption",
  CellTags->"0+ "],
Cell[345363, 11813, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[346099, 11841, 1330, 43, 45, "Assumption",
  CellTags->" +succ"],
Cell[347432, 11886, 353, 18, 46, "Text"],
Cell[347788, 11906, 32, 0, 46, "Text"],
Cell[347823, 11908, 881, 30, 43, "Conclusion",
  CellTags->"^++ .IB"],
Cell[348707, 11940, 222, 10, 46, "Text"],
Cell[348932, 11952, 591, 20, 33, "Conclusion",
  CellTags->"^++ .IB.F"],
Cell[349526, 11974, 32, 0, 46, "Text"],
Cell[349561, 11976, 47, 0, 46, "Text"],
Cell[349611, 11978, 249, 9, 46, "Text"],
Cell[349863, 11989, 47, 0, 46, "Text"],
Cell[349913, 11991, 472, 20, 46, "Text"],
Cell[350388, 12013, 245, 9, 46, "Text"],
Cell[350636, 12024, 49, 0, 46, "Text"],
Cell[350688, 12026, 792, 27, 43, "Conclusion",
  CellTags->"^++ .IB.S"],
Cell[351483, 12055, 363, 18, 46, "Text"],
Cell[351849, 12075, 32, 0, 46, "Text"],
Cell[351884, 12077, 220, 9, 33, "Conclusion",
  CellTags->"^++ .IB.S.IB"],
Cell[352107, 12088, 222, 10, 46, "Text"],
Cell[352332, 12100, 47, 0, 46, "Text"],
Cell[352382, 12102, 274, 14, 46, "Text"],
Cell[352659, 12118, 119, 5, 46, "Text"],
Cell[352781, 12125, 47, 0, 46, "Text"],
Cell[352831, 12127, 119, 5, 46, "Text"],
Cell[352953, 12134, 31, 0, 46, "Text"],
Cell[352987, 12136, 75, 3, 46, "Text"],
Cell[353065, 12141, 517, 18, 33, "Assumption",
  CellTags->"^++ .IB.S.IH"],
Cell[353585, 12161, 75, 3, 46, "Text"],
Cell[353663, 12166, 645, 22, 33, "Conclusion",
  CellTags->"^++ .IB.S.IS"],
Cell[354311, 12190, 222, 10, 46, "Text"],
Cell[354536, 12202, 47, 0, 46, "Text"],
Cell[354586, 12204, 444, 19, 46, "Text"],
Cell[355033, 12225, 495, 20, 46, "Text"],
Cell[355531, 12247, 322, 11, 46, "Text"],
Cell[355856, 12260, 47, 0, 46, "Text"],
Cell[355906, 12262, 322, 11, 46, "Text"],
Cell[356231, 12275, 31, 0, 46, "Text"],
Cell[356265, 12277, 75, 3, 46, "Text"],
Cell[356343, 12282, 1205, 38, 43, "Assumption",
  CellTags->"^++ .IH"],
Cell[357551, 12322, 75, 3, 46, "Text"],
Cell[357629, 12327, 1353, 42, 43, "Conclusion",
  CellTags->"^++ .IS"],
Cell[358985, 12371, 222, 10, 46, "Text"],
Cell[359210, 12383, 1015, 32, 33, "Conclusion",
  CellTags->"^++ .IS.F"],
Cell[360228, 12417, 32, 0, 46, "Text"],
Cell[360263, 12419, 47, 0, 46, "Text"],
Cell[360313, 12421, 477, 16, 46, "Text"],
Cell[360793, 12439, 47, 0, 46, "Text"],
Cell[360843, 12441, 652, 25, 46, "Text"],
Cell[361498, 12468, 557, 18, 46, "Text"],
Cell[362058, 12488, 49, 0, 46, "Text"],
Cell[362110, 12490, 1428, 43, 43, "Conclusion",
  CellTags->"^++ .IS.S"],
Cell[363541, 12535, 363, 18, 46, "Text"],
Cell[363907, 12555, 32, 0, 46, "Text"],
Cell[363942, 12557, 824, 27, 33, "Conclusion",
  CellTags->"^++ .IS.S.IB"],
Cell[364769, 12586, 222, 10, 46, "Text"],
Cell[364994, 12598, 47, 0, 46, "Text"],
Cell[365044, 12600, 519, 22, 46, "Text"],
Cell[365566, 12624, 322, 11, 46, "Text"],
Cell[365891, 12637, 47, 0, 46, "Text"],
Cell[365941, 12639, 562, 23, 46, "Text"],
Cell[366506, 12664, 322, 11, 46, "Text"],
Cell[366831, 12677, 31, 0, 46, "Text"],
Cell[366865, 12679, 75, 3, 46, "Text"],
Cell[366943, 12684, 1087, 34, 33, "Assumption",
  CellTags->"^++ .IS.S.IH"],
Cell[368033, 12720, 75, 3, 46, "Text"],
Cell[368111, 12725, 1182, 37, 33, "Conclusion",
  CellTags->"^++ .IS.S.IS"],
Cell[369296, 12764, 222, 10, 46, "Text"],
Cell[369521, 12776, 47, 0, 46, "Text"],
Cell[369571, 12778, 672, 26, 46, "Text"],
Cell[370246, 12806, 751, 27, 46, "Text"],
Cell[371000, 12835, 670, 20, 46, "Text"],
Cell[371673, 12857, 47, 0, 46, "Text"],
Cell[371723, 12859, 760, 28, 46, "Text"],
Cell[372486, 12889, 670, 20, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[373193, 12914, 54, 0, 63, "Subsection"],
Cell[373250, 12916, 22, 0, 46, "Text"],
Cell[373275, 12918, 1170, 39, 45, "Conclusion",
  CellTags->" + "],
Cell[374448, 12959, 38, 0, 46, "Text"],
Cell[374489, 12961, 1326, 43, 45, "Assumption",
  CellTags->"^++ "],
Cell[375818, 13006, 733, 26, 43, "Assumption",
  CellTags->"0+ "],
Cell[376554, 13034, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[377290, 13062, 1330, 43, 45, "Assumption",
  CellTags->" +succ"],
Cell[378623, 13107, 351, 18, 46, "Text"],
Cell[378977, 13127, 32, 0, 46, "Text"],
Cell[379012, 13129, 780, 27, 43, "Conclusion",
  CellTags->" + .IB"],
Cell[379795, 13158, 230, 10, 46, "Text"],
Cell[380028, 13170, 510, 19, 33, "Conclusion",
  CellTags->" + .IB.F"],
Cell[380541, 13191, 214, 10, 46, "Text"],
Cell[380758, 13203, 47, 0, 46, "Text"],
Cell[380808, 13205, 395, 18, 46, "Text"],
Cell[381206, 13225, 209, 8, 46, "Text"],
Cell[381418, 13235, 47, 0, 46, "Text"],
Cell[381468, 13237, 395, 18, 46, "Text"],
Cell[381866, 13257, 209, 8, 46, "Text"],
Cell[382078, 13267, 31, 0, 46, "Text"],
Cell[382112, 13269, 75, 3, 46, "Text"],
Cell[382190, 13274, 1049, 34, 43, "Assumption",
  CellTags->" + .IH"],
Cell[383242, 13310, 75, 3, 46, "Text"],
Cell[383320, 13315, 1144, 37, 43, "Conclusion",
  CellTags->" + .IS"],
Cell[384467, 13354, 230, 10, 46, "Text"],
Cell[384700, 13366, 834, 29, 33, "Conclusion",
  CellTags->" + .IS.F"],
Cell[385537, 13397, 214, 10, 46, "Text"],
Cell[385754, 13409, 47, 0, 46, "Text"],
Cell[385804, 13411, 549, 23, 46, "Text"],
Cell[386356, 13436, 451, 15, 46, "Text"],
Cell[386810, 13453, 47, 0, 46, "Text"],
Cell[386860, 13455, 553, 23, 46, "Text"],
Cell[387416, 13480, 608, 24, 46, "Text"],
Cell[388027, 13506, 451, 15, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[388515, 13526, 54, 0, 63, "Subsection"],
Cell[388572, 13528, 22, 0, 46, "Text"],
Cell[388597, 13530, 1789, 55, 46, "Conclusion",
  CellTags->"( + ) + "],
Cell[390389, 13587, 38, 0, 46, "Text"],
Cell[390430, 13589, 1170, 39, 45, "Assumption",
  CellTags->" + "],
Cell[391603, 13630, 1326, 43, 45, "Assumption",
  CellTags->"^++ "],
Cell[392932, 13675, 733, 26, 43, "Assumption",
  CellTags->"0+ "],
Cell[393668, 13703, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[394404, 13731, 1330, 43, 45, "Assumption",
  CellTags->" +succ"],
Cell[395737, 13776, 224, 10, 46, "Text"],
Cell[395964, 13788, 1187, 38, 33, "Conclusion",
  CellTags->"( + ) + .F"],
Cell[397154, 13828, 32, 0, 46, "Text"],
Cell[397189, 13830, 47, 0, 46, "Text"],
Cell[397239, 13832, 715, 28, 46, "Text"],
Cell[397957, 13862, 564, 19, 46, "Text"],
Cell[398524, 13883, 47, 0, 46, "Text"],
Cell[398574, 13885, 564, 19, 46, "Text"],
Cell[399141, 13906, 49, 0, 46, "Text"],
Cell[399193, 13908, 1793, 55, 46, "Conclusion",
  CellTags->"( + ) + .S"],
Cell[400989, 13965, 365, 18, 46, "Text"],
Cell[401357, 13985, 32, 0, 46, "Text"],
Cell[401392, 13987, 1382, 43, 46, "Conclusion",
  CellTags->"( + ) + .S.IB"],
Cell[402777, 14032, 244, 10, 46, "Text"],
Cell[403024, 14044, 944, 31, 33, "Conclusion",
  CellTags->"( + ) + .S.IB.F"],
Cell[403971, 14077, 228, 10, 46, "Text"],
Cell[404202, 14089, 47, 0, 46, "Text"],
Cell[404252, 14091, 585, 24, 46, "Text"],
Cell[404840, 14117, 509, 22, 46, "Text"],
Cell[405352, 14141, 358, 13, 46, "Text"],
Cell[405713, 14156, 47, 0, 46, "Text"],
Cell[405763, 14158, 601, 24, 46, "Text"],
Cell[406367, 14184, 358, 13, 46, "Text"],
Cell[406728, 14199, 31, 0, 46, "Text"],
Cell[406762, 14201, 75, 3, 46, "Text"],
Cell[406840, 14206, 1667, 50, 46, "Assumption",
  CellTags->"( + ) + .S.IH"],
Cell[408510, 14258, 75, 3, 46, "Text"],
Cell[408588, 14263, 1766, 53, 46, "Conclusion",
  CellTags->"( + ) + .S.IS"],
Cell[410357, 14318, 244, 10, 46, "Text"],
Cell[410604, 14330, 1288, 41, 33, "Conclusion",
  CellTags->"( + ) + .S.IS.F"],
Cell[411895, 14373, 228, 10, 46, "Text"],
Cell[412126, 14385, 47, 0, 46, "Text"],
Cell[412176, 14387, 757, 29, 46, "Text"],
Cell[412936, 14418, 763, 29, 46, "Text"],
Cell[413702, 14449, 765, 29, 46, "Text"],
Cell[414470, 14480, 771, 29, 46, "Text"],
Cell[415244, 14511, 681, 21, 46, "Text"],
Cell[415928, 14534, 47, 0, 46, "Text"],
Cell[415978, 14536, 755, 29, 46, "Text"],
Cell[416736, 14567, 852, 30, 46, "Text"],
Cell[417591, 14599, 681, 21, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[418309, 14625, 44, 0, 63, "Subsection"],
Cell[418356, 14627, 22, 0, 46, "Text"],
Cell[418381, 14629, 4387, 122, 46, "Conclusion",
  CellTags->"l4+"],
Cell[422771, 14753, 38, 0, 46, "Text"],
Cell[422812, 14755, 3162, 87, 50, "Assumption",
  CellTags->"l4:"],
Cell[425977, 14844, 1959, 59, 46, "Assumption",
  CellTags->"\[CirclePlus]:"],
Cell[427939, 14905, 3795, 101, 46, "Assumption",
  CellTags->"\[LeftBracketingBar]++\[RightBracketingBar]"],
Cell[431737, 15008, 1975, 59, 45, "Assumption",
  CellTags->"max:"],
Cell[433715, 15069, 233, 10, 46, "Text"],
Cell[433951, 15081, 2960, 85, 33, "Conclusion",
  CellTags->"l4+'"],
Cell[436914, 15168, 202, 10, 46, "Text"],
Cell[437119, 15180, 25, 0, 46, "Text"],
Cell[437147, 15182, 1443, 45, 33, "Assumption",
  CellTags->"l4+'.A"],
Cell[438593, 15229, 24, 0, 46, "Text"],
Cell[438620, 15231, 1510, 47, 33, "Conclusion",
  CellTags->"l4+'.C"],
Cell[440133, 15280, 498, 26, 46, "Text"],
Cell[440634, 15308, 365, 18, 46, "Text"],
Cell[441002, 15328, 2603, 70, 43, "Conclusion",
  CellTags->"l4+'.C'"],
Cell[443608, 15400, 363, 18, 46, "Text"],
Cell[443974, 15420, 1587, 46, 43, "Assumption",
  CellTags->"l4+'.A.1'"],
Cell[445564, 15468, 363, 18, 46, "Text"],
Cell[445930, 15488, 1589, 46, 43, "Assumption",
  CellTags->"l4+'.A.2'"],
Cell[447522, 15536, 241, 10, 46, "Text"],
Cell[447766, 15548, 2157, 62, 33, "Conclusion",
  CellTags->"l4+'.C''"],
Cell[449926, 15612, 210, 10, 46, "Text"],
Cell[450139, 15624, 25, 0, 46, "Text"],
Cell[450167, 15626, 667, 23, 33, "Assumption",
  CellTags->"l4+'.C''.A"],
Cell[450837, 15651, 24, 0, 46, "Text"],
Cell[450864, 15653, 1537, 46, 33, "Conclusion",
  CellTags->"l4+'.C''.C"],
Cell[452404, 15701, 465, 21, 46, "Text"],
Cell[452872, 15724, 1739, 51, 33, "Conclusion",
  CellTags->"l4+'.C''.C'"],
Cell[454614, 15777, 671, 24, 46, "Text"],
Cell[455288, 15803, 1687, 49, 33, "Conclusion",
  CellTags->"l4+'.C''.C'.A"],
Cell[456978, 15854, 234, 10, 46, "Text"],
Cell[457215, 15866, 970, 33, 46, "Text"],
Cell[458188, 15901, 379, 18, 46, "Text"],
Cell[458570, 15921, 468, 17, 33, "Conclusion",
  CellTags->"l4+'.C''.C'.A.1.A"],
Cell[459041, 15940, 342, 18, 46, "Text"],
Cell[459386, 15960, 783, 27, 33, "Assumption",
  CellTags->"max:/1"],
Cell[460172, 15989, 498, 26, 46, "Text"],
Cell[460673, 16017, 387, 18, 46, "Text"],
Cell[461063, 16037, 972, 33, 46, "Text"],
Cell[462038, 16072, 379, 18, 46, "Text"],
Cell[462420, 16092, 468, 17, 33, "Conclusion",
  CellTags->"l4+'.C''.C'.A.2.A"],
Cell[462891, 16111, 342, 18, 46, "Text"],
Cell[463236, 16131, 785, 27, 33, "Assumption",
  CellTags->"max:/13"],
Cell[464024, 16160, 504, 26, 46, "Text"],
Cell[464531, 16188, 389, 18, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[464957, 16211, 44, 0, 63, "Subsection"],
Cell[465004, 16213, 22, 0, 46, "Text"],
Cell[465029, 16215, 3387, 95, 46, "Conclusion",
  CellTags->"l3+"],
Cell[468419, 16312, 38, 0, 46, "Text"],
Cell[468460, 16314, 2195, 64, 50, "Assumption",
  CellTags->"l3:"],
Cell[470658, 16380, 4387, 122, 46, "Assumption",
  CellTags->"l4+"],
Cell[475048, 16504, 233, 10, 46, "Text"],
Cell[475284, 16516, 2287, 67, 33, "Conclusion",
  CellTags->"l3+'"],
Cell[477574, 16585, 202, 10, 46, "Text"],
Cell[477779, 16597, 25, 0, 46, "Text"],
Cell[477807, 16599, 1163, 37, 33, "Assumption",
  CellTags->"l3+'.A"],
Cell[478973, 16638, 24, 0, 46, "Text"],
Cell[479000, 16640, 1153, 37, 33, "Conclusion",
  CellTags->"l3+'.C"],
Cell[480156, 16679, 498, 26, 46, "Text"],
Cell[480657, 16707, 365, 18, 46, "Text"],
Cell[481025, 16727, 1559, 48, 43, "Conclusion",
  CellTags->"l3+'.C'"],
Cell[482587, 16777, 363, 18, 46, "Text"],
Cell[482953, 16797, 1005, 33, 43, "Assumption",
  CellTags->"l3+'.A.1'"],
Cell[483961, 16832, 225, 10, 46, "Text"],
Cell[484189, 16844, 765, 26, 33, "Assumption",
  CellTags->"l3+'.A.1''"],
Cell[484957, 16872, 363, 18, 46, "Text"],
Cell[485323, 16892, 1007, 33, 43, "Assumption",
  CellTags->"l3+'.A.2'"],
Cell[486333, 16927, 225, 10, 46, "Text"],
Cell[486561, 16939, 767, 26, 33, "Assumption",
  CellTags->"l3+'.A.2''"],
Cell[487331, 16967, 385, 18, 46, "Text"],
Cell[487719, 16987, 3631, 98, 45, "Assumption",
  CellTags->"l3+'.C''"],
Cell[491353, 17087, 361, 18, 46, "Text"],
Cell[491717, 17107, 1957, 57, 45, "Conclusion",
  CellTags->"l3+'.C'.A"],
Cell[493677, 17166, 390, 18, 46, "Text"],
Cell[494070, 17186, 43, 0, 46, "Text"],
Cell[494116, 17188, 219, 10, 46, "Text"],
Cell[494338, 17200, 1836, 53, 43, "Conclusion",
  CellTags->"l3+'.C'.A/2"],
Cell[496177, 17255, 394, 18, 46, "Text"],
Cell[496574, 17275, 43, 0, 46, "Text"],
Cell[496620, 17277, 223, 10, 46, "Text"],
Cell[496846, 17289, 1457, 45, 33, "Conclusion",
  CellTags->"l3+'.C'.A/2/1"],
Cell[498306, 17336, 234, 10, 46, "Text"],
Cell[498543, 17348, 859, 31, 46, "Text"],
Cell[499405, 17381, 387, 18, 46, "Text"],
Cell[499795, 17401, 861, 31, 46, "Text"],
Cell[500659, 17434, 387, 18, 46, "Text"],
Cell[501049, 17454, 44, 0, 46, "Text"],
Cell[501096, 17456, 261, 11, 70, "Text"],
Cell[501360, 17469, 44, 0, 46, "Text"],
Cell[501407, 17471, 257, 11, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[501701, 17487, 44, 0, 63, "Subsection"],
Cell[501748, 17489, 22, 0, 46, "Text"],
Cell[501773, 17491, 2406, 70, 46, "Conclusion",
  CellTags->"l2+"],
Cell[504182, 17563, 38, 0, 46, "Text"],
Cell[504223, 17565, 1741, 52, 50, "Assumption",
  CellTags->"l2:"],
Cell[505967, 17619, 3136, 88, 50, "Assumption",
  CellTags->"l3+"],
Cell[509106, 17709, 233, 10, 46, "Text"],
Cell[509342, 17721, 1640, 50, 33, "Conclusion",
  CellTags->"l2+'"],
Cell[510985, 17773, 202, 10, 46, "Text"],
Cell[511190, 17785, 25, 0, 46, "Text"],
Cell[511218, 17787, 867, 29, 33, "Assumption",
  CellTags->"l2+'.A"],
Cell[512088, 17818, 24, 0, 46, "Text"],
Cell[512115, 17820, 836, 28, 33, "Conclusion",
  CellTags->"l2+'.C"],
Cell[512954, 17850, 498, 26, 46, "Text"],
Cell[513455, 17878, 365, 18, 46, "Text"],
Cell[513823, 17898, 1242, 39, 43, "Conclusion",
  CellTags->"l2+'.C'"],
Cell[515068, 17939, 363, 18, 46, "Text"],
Cell[515434, 17959, 876, 29, 43, "Assumption",
  CellTags->"l2+'.A.1'"],
Cell[516313, 17990, 363, 18, 46, "Text"],
Cell[516679, 18010, 876, 29, 43, "Assumption",
  CellTags->"l2+'.A.2'"],
Cell[517558, 18041, 241, 10, 46, "Text"],
Cell[517802, 18053, 981, 32, 33, "Conclusion",
  CellTags->"l2+'.C''"],
Cell[518786, 18087, 353, 18, 46, "Text"],
Cell[519142, 18107, 1251, 39, 44, "Conclusion",
  CellTags->"l2+'.C''.A"],
Cell[520396, 18148, 228, 10, 46, "Text"],
Cell[520627, 18160, 760, 28, 51, "Text"],
Cell[521390, 18190, 383, 18, 46, "Text"],
Cell[521776, 18210, 760, 28, 51, "Text"],
Cell[522539, 18240, 383, 18, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[522959, 18263, 68, 0, 63, "Subsection"],
Cell[523030, 18265, 22, 0, 46, "Text"],
Cell[523055, 18267, 1170, 39, 45, "Conclusion",
  CellTags->" \[RawStar] "],
Cell[524228, 18308, 38, 0, 46, "Text"],
Cell[524269, 18310, 613, 23, 43, "Assumption",
  CellTags->" \[RawStar]0"],
Cell[524885, 18335, 1402, 45, 45, "Assumption",
  CellTags->" \[RawStar] ^+"],
Cell[526290, 18382, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[527026, 18410, 1328, 43, 45, "Assumption",
  CellTags->" + ^+"],
Cell[528357, 18455, 733, 26, 43, "Assumption",
  CellTags->"0+ "],
Cell[529093, 18483, 1326, 43, 45, "Assumption",
  CellTags->"^++ "],
Cell[530422, 18528, 1789, 55, 46, "Assumption",
  CellTags->"( + ) + "],
Cell[532214, 18585, 129, 3, 46, "Text"],
Cell[532346, 18590, 43, 0, 46, "Text"],
Cell[532392, 18592, 249, 10, 46, "Text"],
Cell[532644, 18604, 43, 0, 46, "Text"],
Cell[532690, 18606, 358, 18, 46, "Text"],
Cell[533051, 18626, 32, 0, 46, "Text"],
Cell[533086, 18628, 780, 27, 43, "Conclusion",
  CellTags->" \[RawStar] .IB"],
Cell[533869, 18657, 129, 3, 46, "Text"],
Cell[534001, 18662, 43, 0, 46, "Text"],
Cell[534047, 18664, 220, 10, 46, "Text"],
Cell[534270, 18676, 503, 18, 33, "Conclusion",
  CellTags->" \[RawStar] .IB.F"],
Cell[534776, 18696, 32, 0, 46, "Text"],
Cell[534811, 18698, 47, 0, 46, "Text"],
Cell[534861, 18700, 244, 9, 46, "Text"],
Cell[535108, 18711, 47, 0, 46, "Text"],
Cell[535158, 18713, 395, 18, 46, "Text"],
Cell[535556, 18733, 112, 5, 46, "Text"],
Cell[535671, 18740, 49, 0, 46, "Text"],
Cell[535723, 18742, 618, 22, 43, "Conclusion",
  CellTags->" \[RawStar] .IB.S"],
Cell[536344, 18766, 361, 18, 46, "Text"],
Cell[536708, 18786, 32, 0, 46, "Text"],
Cell[536743, 18788, 202, 9, 33, "Conclusion",
  CellTags->" \[RawStar] .IB.S.IB"],
Cell[536948, 18799, 220, 10, 46, "Text"],
Cell[537171, 18811, 47, 0, 46, "Text"],
Cell[537221, 18813, 265, 14, 46, "Text"],
Cell[537489, 18829, 112, 5, 46, "Text"],
Cell[537604, 18836, 47, 0, 46, "Text"],
Cell[537654, 18838, 112, 5, 46, "Text"],
Cell[537769, 18845, 31, 0, 46, "Text"],
Cell[537803, 18847, 75, 3, 46, "Text"],
Cell[537881, 18852, 358, 13, 33, "Assumption",
  CellTags->" \[RawStar] .IB.S.IH"],
Cell[538242, 18867, 75, 3, 46, "Text"],
Cell[538320, 18872, 405, 15, 33, "Conclusion",
  CellTags->" \[RawStar] .IB.S.IS"],
Cell[538728, 18889, 220, 10, 46, "Text"],
Cell[538951, 18901, 47, 0, 46, "Text"],
Cell[539001, 18903, 437, 19, 46, "Text"],
Cell[539441, 18924, 448, 19, 46, "Text"],
Cell[539892, 18945, 267, 14, 46, "Text"],
Cell[540162, 18961, 112, 5, 46, "Text"],
Cell[540277, 18968, 47, 0, 46, "Text"],
Cell[540327, 18970, 112, 5, 46, "Text"],
Cell[540442, 18977, 44, 0, 46, "Text"],
Cell[540489, 18979, 251, 11, 70, "Text"],
Cell[540743, 18992, 31, 0, 46, "Text"],
Cell[540777, 18994, 75, 3, 46, "Text"],
Cell[540855, 18999, 1049, 34, 43, "Assumption",
  CellTags->" \[RawStar] .IH"],
Cell[541907, 19035, 75, 3, 46, "Text"],
Cell[541985, 19040, 1144, 37, 43, "Conclusion",
  CellTags->" \[RawStar] .IS"],
Cell[543132, 19079, 129, 3, 46, "Text"],
Cell[543264, 19084, 43, 0, 46, "Text"],
Cell[543310, 19086, 220, 10, 46, "Text"],
Cell[543533, 19098, 827, 28, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.F"],
Cell[544363, 19128, 32, 0, 46, "Text"],
Cell[544398, 19130, 47, 0, 46, "Text"],
Cell[544448, 19132, 396, 14, 46, "Text"],
Cell[544847, 19148, 47, 0, 46, "Text"],
Cell[544897, 19150, 551, 23, 46, "Text"],
Cell[545451, 19175, 674, 27, 46, "Text"],
Cell[546128, 19204, 517, 18, 46, "Text"],
Cell[546648, 19224, 49, 0, 46, "Text"],
Cell[546700, 19226, 1288, 41, 43, "Conclusion",
  CellTags->" \[RawStar] .IS.S"],
Cell[547991, 19269, 368, 18, 46, "Text"],
Cell[548362, 19289, 32, 0, 46, "Text"],
Cell[548397, 19291, 595, 21, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.S.IB"],
Cell[548995, 19314, 197, 10, 46, "Text"],
Cell[549195, 19326, 47, 0, 46, "Text"],
Cell[549245, 19328, 433, 19, 46, "Text"],
Cell[549681, 19349, 112, 5, 46, "Text"],
Cell[549796, 19356, 47, 0, 46, "Text"],
Cell[549846, 19358, 438, 19, 46, "Text"],
Cell[550287, 19379, 432, 19, 46, "Text"],
Cell[550722, 19400, 244, 9, 46, "Text"],
Cell[550969, 19411, 49, 0, 46, "Text"],
Cell[551021, 19413, 369, 14, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.S.IB.S"],
Cell[551393, 19429, 249, 10, 46, "Text"],
Cell[551645, 19441, 31, 0, 46, "Text"],
Cell[551679, 19443, 75, 3, 46, "Text"],
Cell[551757, 19448, 962, 32, 33, "Assumption",
  CellTags->" \[RawStar] .IS.S.IH"],
Cell[552722, 19482, 75, 3, 46, "Text"],
Cell[552800, 19487, 1091, 36, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.S.IS"],
Cell[553894, 19525, 261, 11, 70, "Text"],
Cell[554158, 19538, 43, 0, 46, "Text"],
Cell[554204, 19540, 364, 18, 46, "Text"],
Cell[554571, 19560, 32, 0, 46, "Text"],
Cell[554606, 19562, 592, 21, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.IB"],
Cell[555201, 19585, 193, 10, 46, "Text"],
Cell[555397, 19597, 47, 0, 46, "Text"],
Cell[555447, 19599, 433, 19, 46, "Text"],
Cell[555883, 19620, 112, 5, 46, "Text"],
Cell[555998, 19627, 47, 0, 46, "Text"],
Cell[556048, 19629, 437, 19, 46, "Text"],
Cell[556488, 19650, 432, 19, 46, "Text"],
Cell[556923, 19671, 244, 9, 46, "Text"],
Cell[557170, 19682, 49, 0, 46, "Text"],
Cell[557222, 19684, 365, 14, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.IB.S"],
Cell[557590, 19700, 245, 10, 46, "Text"],
Cell[557838, 19712, 31, 0, 46, "Text"],
Cell[557872, 19714, 75, 3, 46, "Text"],
Cell[557950, 19719, 829, 28, 33, "Assumption",
  CellTags->" \[RawStar] .IS.IH"],
Cell[558782, 19749, 75, 3, 46, "Text"],
Cell[558860, 19754, 916, 31, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.IS"],
Cell[559779, 19787, 257, 11, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[560073, 19803, 56, 0, 63, "Subsection"],
Cell[560132, 19805, 22, 0, 46, "Text"],
Cell[560157, 19807, 608, 22, 43, "Conclusion",
  CellTags->"0\[RawStar] "],
Cell[560768, 19831, 38, 0, 46, "Text"],
Cell[560809, 19833, 613, 23, 43, "Assumption",
  CellTags->" \[RawStar]0"],
Cell[561425, 19858, 1402, 45, 45, "Assumption",
  CellTags->" \[RawStar] ^+"],
Cell[562830, 19905, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[563566, 19933, 1328, 43, 45, "Assumption",
  CellTags->" + ^+"],
Cell[564897, 19978, 733, 26, 43, "Assumption",
  CellTags->"0+ "],
Cell[565633, 20006, 1326, 43, 45, "Assumption",
  CellTags->"^++ "],
Cell[566962, 20051, 1789, 55, 46, "Assumption",
  CellTags->"( + ) + "],
Cell[568754, 20108, 129, 3, 46, "Text"],
Cell[568886, 20113, 43, 0, 46, "Text"],
Cell[568932, 20115, 249, 10, 46, "Text"],
Cell[569184, 20127, 43, 0, 46, "Text"],
Cell[569230, 20129, 351, 18, 46, "Text"],
Cell[569584, 20149, 32, 0, 46, "Text"],
Cell[569619, 20151, 192, 9, 33, "Conclusion",
  CellTags->"0\[RawStar] .IB"],
Cell[569814, 20162, 210, 10, 46, "Text"],
Cell[570027, 20174, 47, 0, 46, "Text"],
Cell[570077, 20176, 265, 14, 46, "Text"],
Cell[570345, 20192, 112, 5, 46, "Text"],
Cell[570460, 20199, 47, 0, 46, "Text"],
Cell[570510, 20201, 112, 5, 46, "Text"],
Cell[570625, 20208, 31, 0, 46, "Text"],
Cell[570659, 20210, 75, 3, 46, "Text"],
Cell[570737, 20215, 348, 13, 33, "Assumption",
  CellTags->"0\[RawStar] .IH"],
Cell[571088, 20230, 75, 3, 46, "Text"],
Cell[571166, 20235, 395, 15, 33, "Conclusion",
  CellTags->"0\[RawStar] .IS"],
Cell[571564, 20252, 210, 10, 46, "Text"],
Cell[571777, 20264, 47, 0, 46, "Text"],
Cell[571827, 20266, 437, 19, 46, "Text"],
Cell[572267, 20287, 438, 19, 46, "Text"],
Cell[572708, 20308, 267, 14, 46, "Text"],
Cell[572978, 20324, 112, 5, 46, "Text"],
Cell[573093, 20331, 47, 0, 46, "Text"],
Cell[573143, 20333, 112, 5, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[573292, 20343, 68, 0, 63, "Subsection"],
Cell[573363, 20345, 22, 0, 46, "Text"],
Cell[573388, 20347, 1170, 39, 45, "Conclusion",
  CellTags->" \[RawStar] "],
Cell[574561, 20388, 38, 0, 46, "Text"],
Cell[574602, 20390, 613, 23, 43, "Assumption",
  CellTags->" \[RawStar]0"],
Cell[575218, 20415, 1402, 45, 45, "Assumption",
  CellTags->" \[RawStar] ^+"],
Cell[576623, 20462, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[577359, 20490, 1328, 43, 45, "Assumption",
  CellTags->" + ^+"],
Cell[578690, 20535, 733, 26, 43, "Assumption",
  CellTags->"0+ "],
Cell[579426, 20563, 1326, 43, 45, "Assumption",
  CellTags->"^++ "],
Cell[580755, 20608, 1789, 55, 46, "Assumption",
  CellTags->"( + ) + "],
Cell[582547, 20665, 608, 22, 43, "Assumption",
  CellTags->"0\[RawStar] "],
Cell[583158, 20689, 129, 3, 46, "Text"],
Cell[583290, 20694, 43, 0, 46, "Text"],
Cell[583336, 20696, 249, 10, 46, "Text"],
Cell[583588, 20708, 43, 0, 46, "Text"],
Cell[583634, 20710, 358, 18, 46, "Text"],
Cell[583995, 20730, 32, 0, 46, "Text"],
Cell[584030, 20732, 780, 27, 43, "Conclusion",
  CellTags->" \[RawStar] .IB"],
Cell[584813, 20761, 129, 3, 46, "Text"],
Cell[584945, 20766, 43, 0, 46, "Text"],
Cell[584991, 20768, 230, 10, 46, "Text"],
Cell[585224, 20780, 510, 19, 33, "Conclusion",
  CellTags->" \[RawStar] .IB.F"],
Cell[585737, 20801, 214, 10, 46, "Text"],
Cell[585954, 20813, 47, 0, 46, "Text"],
Cell[586004, 20815, 395, 18, 46, "Text"],
Cell[586402, 20835, 112, 5, 46, "Text"],
Cell[586517, 20842, 47, 0, 46, "Text"],
Cell[586567, 20844, 395, 18, 46, "Text"],
Cell[586965, 20864, 112, 5, 46, "Text"],
Cell[587080, 20871, 44, 0, 46, "Text"],
Cell[587127, 20873, 251, 11, 70, "Text"],
Cell[587381, 20886, 31, 0, 46, "Text"],
Cell[587415, 20888, 75, 3, 46, "Text"],
Cell[587493, 20893, 1049, 34, 43, "Assumption",
  CellTags->" \[RawStar] .IH"],
Cell[588545, 20929, 75, 3, 46, "Text"],
Cell[588623, 20934, 1144, 37, 43, "Conclusion",
  CellTags->" \[RawStar] .IS"],
Cell[589770, 20973, 129, 3, 46, "Text"],
Cell[589902, 20978, 43, 0, 46, "Text"],
Cell[589948, 20980, 220, 10, 46, "Text"],
Cell[590171, 20992, 827, 28, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.F"],
Cell[591001, 21022, 32, 0, 46, "Text"],
Cell[591036, 21024, 47, 0, 46, "Text"],
Cell[591086, 21026, 396, 14, 46, "Text"],
Cell[591485, 21042, 47, 0, 46, "Text"],
Cell[591535, 21044, 551, 23, 46, "Text"],
Cell[592089, 21069, 674, 27, 46, "Text"],
Cell[592766, 21098, 517, 18, 46, "Text"],
Cell[593286, 21118, 49, 0, 46, "Text"],
Cell[593338, 21120, 1288, 41, 43, "Conclusion",
  CellTags->" \[RawStar] .IS.S"],
Cell[594629, 21163, 368, 18, 46, "Text"],
Cell[595000, 21183, 32, 0, 46, "Text"],
Cell[595035, 21185, 595, 21, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.S.IB"],
Cell[595633, 21208, 220, 10, 46, "Text"],
Cell[595856, 21220, 47, 0, 46, "Text"],
Cell[595906, 21222, 433, 19, 46, "Text"],
Cell[596342, 21243, 112, 5, 46, "Text"],
Cell[596457, 21250, 47, 0, 46, "Text"],
Cell[596507, 21252, 438, 19, 46, "Text"],
Cell[596948, 21273, 432, 19, 46, "Text"],
Cell[597383, 21294, 395, 18, 46, "Text"],
Cell[597781, 21314, 112, 5, 46, "Text"],
Cell[597896, 21321, 31, 0, 46, "Text"],
Cell[597930, 21323, 75, 3, 46, "Text"],
Cell[598008, 21328, 962, 32, 33, "Assumption",
  CellTags->" \[RawStar] .IS.S.IH"],
Cell[598973, 21362, 75, 3, 46, "Text"],
Cell[599051, 21367, 1091, 36, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.S.IS"],
Cell[600145, 21405, 197, 10, 46, "Text"],
Cell[600345, 21417, 47, 0, 46, "Text"],
Cell[600395, 21419, 589, 24, 46, "Text"],
Cell[600987, 21445, 762, 29, 46, "Text"],
Cell[601752, 21476, 936, 34, 46, "Text"],
Cell[602691, 21512, 1041, 35, 46, "Text"],
Cell[603735, 21549, 860, 26, 46, "Text"],
Cell[604598, 21577, 47, 0, 46, "Text"],
Cell[604648, 21579, 750, 29, 46, "Text"],
Cell[605401, 21610, 936, 34, 46, "Text"],
Cell[606340, 21646, 1041, 35, 46, "Text"],
Cell[607384, 21683, 860, 26, 46, "Text"],
Cell[608247, 21711, 49, 0, 46, "Text"],
Cell[608299, 21713, 1825, 54, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.S.IS.S"],
Cell[610127, 21769, 249, 10, 46, "Text"],
Cell[610379, 21781, 43, 0, 46, "Text"],
Cell[610425, 21783, 364, 18, 46, "Text"],
Cell[610792, 21803, 32, 0, 46, "Text"],
Cell[610827, 21805, 592, 21, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.IB"],
Cell[611422, 21828, 216, 10, 46, "Text"],
Cell[611641, 21840, 47, 0, 46, "Text"],
Cell[611691, 21842, 433, 19, 46, "Text"],
Cell[612127, 21863, 112, 5, 46, "Text"],
Cell[612242, 21870, 47, 0, 46, "Text"],
Cell[612292, 21872, 437, 19, 46, "Text"],
Cell[612732, 21893, 432, 19, 46, "Text"],
Cell[613167, 21914, 395, 18, 46, "Text"],
Cell[613565, 21934, 112, 5, 46, "Text"],
Cell[613680, 21941, 31, 0, 46, "Text"],
Cell[613714, 21943, 75, 3, 46, "Text"],
Cell[613792, 21948, 829, 28, 33, "Assumption",
  CellTags->" \[RawStar] .IS.IH"],
Cell[614624, 21978, 75, 3, 46, "Text"],
Cell[614702, 21983, 916, 31, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.IS"],
Cell[615621, 22016, 193, 10, 46, "Text"],
Cell[615817, 22028, 47, 0, 46, "Text"],
Cell[615867, 22030, 589, 24, 46, "Text"],
Cell[616459, 22056, 758, 29, 46, "Text"],
Cell[617220, 22087, 750, 29, 46, "Text"],
Cell[617973, 22118, 938, 34, 46, "Text"],
Cell[618914, 22154, 936, 34, 46, "Text"],
Cell[619853, 22190, 1041, 35, 46, "Text"],
Cell[620897, 22227, 860, 26, 46, "Text"],
Cell[621760, 22255, 47, 0, 46, "Text"],
Cell[621810, 22257, 589, 24, 46, "Text"],
Cell[622402, 22283, 752, 29, 46, "Text"],
Cell[623157, 22314, 750, 29, 46, "Text"],
Cell[623910, 22345, 936, 34, 46, "Text"],
Cell[624849, 22381, 1041, 35, 46, "Text"],
Cell[625893, 22418, 860, 26, 46, "Text"],
Cell[626756, 22446, 49, 0, 46, "Text"],
Cell[626808, 22448, 1821, 54, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.IS.S"],
Cell[628632, 22504, 245, 10, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[628914, 22519, 57, 0, 63, "Subsection"],
Cell[628974, 22521, 22, 0, 46, "Text"],
Cell[628999, 22523, 1170, 39, 45, "Conclusion",
  CellTags->" \[RawStar] "],
Cell[630172, 22564, 38, 0, 46, "Text"],
Cell[630213, 22566, 613, 23, 43, "Assumption",
  CellTags->" \[RawStar]0"],
Cell[630829, 22591, 1402, 45, 45, "Assumption",
  CellTags->" \[RawStar] ^+"],
Cell[632234, 22638, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[632970, 22666, 1328, 43, 45, "Assumption",
  CellTags->" + ^+"],
Cell[634301, 22711, 733, 26, 43, "Assumption",
  CellTags->"0+ "],
Cell[635037, 22739, 1326, 43, 45, "Assumption",
  CellTags->"^++ "],
Cell[636366, 22784, 1789, 55, 46, "Assumption",
  CellTags->"( + ) + "],
Cell[638158, 22841, 1170, 39, 45, "Assumption",
  CellTags->" + "],
Cell[639331, 22882, 608, 22, 43, "Assumption",
  CellTags->"0\[RawStar] "],
Cell[639942, 22906, 129, 3, 46, "Text"],
Cell[640074, 22911, 43, 0, 46, "Text"],
Cell[640120, 22913, 249, 10, 46, "Text"],
Cell[640372, 22925, 43, 0, 46, "Text"],
Cell[640418, 22927, 351, 18, 46, "Text"],
Cell[640772, 22947, 32, 0, 46, "Text"],
Cell[640807, 22949, 780, 27, 43, "Conclusion",
  CellTags->" \[RawStar] .IB"],
Cell[641590, 22978, 129, 3, 46, "Text"],
Cell[641722, 22983, 43, 0, 46, "Text"],
Cell[641768, 22985, 230, 10, 46, "Text"],
Cell[642001, 22997, 510, 19, 33, "Conclusion",
  CellTags->" \[RawStar] .IB.F"],
Cell[642514, 23018, 214, 10, 46, "Text"],
Cell[642731, 23030, 47, 0, 46, "Text"],
Cell[642781, 23032, 395, 18, 46, "Text"],
Cell[643179, 23052, 112, 5, 46, "Text"],
Cell[643294, 23059, 47, 0, 46, "Text"],
Cell[643344, 23061, 395, 18, 46, "Text"],
Cell[643742, 23081, 112, 5, 46, "Text"],
Cell[643857, 23088, 44, 0, 46, "Text"],
Cell[643904, 23090, 251, 11, 70, "Text"],
Cell[644158, 23103, 31, 0, 46, "Text"],
Cell[644192, 23105, 75, 3, 46, "Text"],
Cell[644270, 23110, 1049, 34, 43, "Assumption",
  CellTags->" \[RawStar] .IH"],
Cell[645322, 23146, 75, 3, 46, "Text"],
Cell[645400, 23151, 1144, 37, 43, "Conclusion",
  CellTags->" \[RawStar] .IS"],
Cell[646547, 23190, 129, 3, 46, "Text"],
Cell[646679, 23195, 43, 0, 46, "Text"],
Cell[646725, 23197, 220, 10, 46, "Text"],
Cell[646948, 23209, 827, 28, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.F"],
Cell[647778, 23239, 32, 0, 46, "Text"],
Cell[647813, 23241, 47, 0, 46, "Text"],
Cell[647863, 23243, 396, 14, 46, "Text"],
Cell[648262, 23259, 47, 0, 46, "Text"],
Cell[648312, 23261, 551, 23, 46, "Text"],
Cell[648866, 23286, 674, 27, 46, "Text"],
Cell[649543, 23315, 668, 27, 46, "Text"],
Cell[650214, 23344, 517, 18, 46, "Text"],
Cell[650734, 23364, 49, 0, 46, "Text"],
Cell[650786, 23366, 1288, 41, 43, "Conclusion",
  CellTags->" \[RawStar] .IS.S"],
Cell[652077, 23409, 361, 18, 46, "Text"],
Cell[652441, 23429, 32, 0, 46, "Text"],
Cell[652476, 23431, 595, 21, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.S.IB"],
Cell[653074, 23454, 220, 10, 46, "Text"],
Cell[653297, 23466, 47, 0, 46, "Text"],
Cell[653347, 23468, 433, 19, 46, "Text"],
Cell[653783, 23489, 112, 5, 46, "Text"],
Cell[653898, 23496, 47, 0, 46, "Text"],
Cell[653948, 23498, 438, 19, 46, "Text"],
Cell[654389, 23519, 432, 19, 46, "Text"],
Cell[654824, 23540, 395, 18, 46, "Text"],
Cell[655222, 23560, 112, 5, 46, "Text"],
Cell[655337, 23567, 31, 0, 46, "Text"],
Cell[655371, 23569, 75, 3, 46, "Text"],
Cell[655449, 23574, 962, 32, 33, "Assumption",
  CellTags->" \[RawStar] .IS.S.IH"],
Cell[656414, 23608, 75, 3, 46, "Text"],
Cell[656492, 23613, 1091, 36, 33, "Conclusion",
  CellTags->" \[RawStar] .IS.S.IS"],
Cell[657586, 23651, 220, 10, 46, "Text"],
Cell[657809, 23663, 47, 0, 46, "Text"],
Cell[657859, 23665, 589, 24, 46, "Text"],
Cell[658451, 23691, 762, 29, 46, "Text"],
Cell[659216, 23722, 936, 34, 46, "Text"],
Cell[660155, 23758, 1041, 35, 46, "Text"],
Cell[661199, 23795, 880, 26, 46, "Text"],
Cell[662082, 23823, 47, 0, 46, "Text"],
Cell[662132, 23825, 750, 29, 46, "Text"],
Cell[662885, 23856, 934, 34, 46, "Text"],
Cell[663822, 23892, 880, 26, 46, "Text"],
Cell[664705, 23920, 44, 0, 46, "Text"],
Cell[664752, 23922, 251, 11, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[665040, 23938, 82, 1, 63, "Subsection"],
Cell[665125, 23941, 22, 0, 46, "Text"],
Cell[665150, 23943, 1789, 55, 46, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] "],
Cell[666942, 24000, 38, 0, 46, "Text"],
Cell[666983, 24002, 613, 23, 43, "Assumption",
  CellTags->" \[RawStar]0"],
Cell[667599, 24027, 1404, 45, 45, "Assumption",
  CellTags->" \[RawStar]  ^+"],
Cell[669006, 24074, 606, 22, 43, "Assumption",
  CellTags->"0\[RawStar]"],
Cell[669615, 24098, 1400, 45, 45, "Assumption",
  CellTags->" ^+\[RawStar]"],
Cell[671018, 24145, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[671754, 24173, 1328, 43, 45, "Assumption",
  CellTags->" + ^+"],
Cell[673085, 24218, 733, 26, 43, "Assumption",
  CellTags->"0+ "],
Cell[673821, 24246, 1326, 43, 45, "Assumption",
  CellTags->"^++ "],
Cell[675150, 24291, 1170, 39, 45, "Assumption",
  CellTags->" + "],
Cell[676323, 24332, 1789, 55, 46, "Assumption",
  CellTags->"( + ) + "],
Cell[678115, 24389, 129, 3, 46, "Text"],
Cell[678247, 24394, 43, 0, 46, "Text"],
Cell[678293, 24396, 259, 10, 46, "Text"],
Cell[678555, 24408, 43, 0, 46, "Text"],
Cell[678601, 24410, 361, 18, 46, "Text"],
Cell[678965, 24430, 32, 0, 46, "Text"],
Cell[679000, 24432, 1378, 43, 46, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IB"],
Cell[680381, 24477, 129, 3, 46, "Text"],
Cell[680513, 24482, 43, 0, 46, "Text"],
Cell[680559, 24484, 240, 10, 46, "Text"],
Cell[680802, 24496, 940, 31, 33, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IB.F"],
Cell[681745, 24529, 224, 10, 46, "Text"],
Cell[681972, 24541, 47, 0, 46, "Text"],
Cell[682022, 24543, 583, 24, 46, "Text"],
Cell[682608, 24569, 393, 18, 46, "Text"],
Cell[683004, 24589, 112, 5, 46, "Text"],
Cell[683119, 24596, 47, 0, 46, "Text"],
Cell[683169, 24598, 599, 24, 46, "Text"],
Cell[683771, 24624, 112, 5, 46, "Text"],
Cell[683886, 24631, 44, 0, 46, "Text"],
Cell[683933, 24633, 261, 11, 70, "Text"],
Cell[684197, 24646, 31, 0, 46, "Text"],
Cell[684231, 24648, 75, 3, 46, "Text"],
Cell[684309, 24653, 1663, 50, 46, "Assumption",
  CellTags->"( \[RawStar] ) \[RawStar] .IH"],
Cell[685975, 24705, 75, 3, 46, "Text"],
Cell[686053, 24710, 1762, 53, 46, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS"],
Cell[687818, 24765, 129, 3, 46, "Text"],
Cell[687950, 24770, 43, 0, 46, "Text"],
Cell[687996, 24772, 230, 10, 46, "Text"],
Cell[688229, 24784, 1277, 40, 33, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.F"],
Cell[689509, 24826, 32, 0, 46, "Text"],
Cell[689544, 24828, 47, 0, 46, "Text"],
Cell[689594, 24830, 759, 29, 46, "Text"],
Cell[690356, 24861, 894, 33, 46, "Text"],
Cell[691253, 24896, 743, 24, 46, "Text"],
Cell[691999, 24922, 47, 0, 46, "Text"],
Cell[692049, 24924, 755, 29, 46, "Text"],
Cell[692807, 24955, 1061, 38, 46, "Text"],
Cell[693871, 24995, 1045, 38, 46, "Text"],
Cell[694919, 25035, 894, 29, 46, "Text"],
Cell[695816, 25066, 49, 0, 46, "Text"],
Cell[695868, 25068, 2258, 66, 46, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S"],
Cell[698129, 25136, 371, 18, 46, "Text"],
Cell[698503, 25156, 32, 0, 46, "Text"],
Cell[698538, 25158, 1530, 46, 46, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IB"],
Cell[700071, 25206, 129, 3, 46, "Text"],
Cell[700203, 25211, 43, 0, 46, "Text"],
Cell[700249, 25213, 250, 10, 46, "Text"],
Cell[700502, 25225, 1189, 38, 33, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IB.F"],
Cell[701694, 25265, 234, 10, 46, "Text"],
Cell[701931, 25277, 47, 0, 46, "Text"],
Cell[701981, 25279, 626, 25, 46, "Text"],
Cell[702610, 25306, 403, 18, 46, "Text"],
Cell[703016, 25326, 393, 18, 46, "Text"],
Cell[703412, 25346, 112, 5, 46, "Text"],
Cell[703527, 25353, 47, 0, 46, "Text"],
Cell[703577, 25355, 785, 30, 46, "Text"],
Cell[704365, 25387, 581, 24, 46, "Text"],
Cell[704949, 25413, 430, 19, 46, "Text"],
Cell[705382, 25434, 267, 14, 46, "Text"],
Cell[705652, 25450, 112, 5, 46, "Text"],
Cell[705767, 25457, 44, 0, 46, "Text"],
Cell[705814, 25459, 271, 11, 70, "Text"],
Cell[706088, 25472, 31, 0, 46, "Text"],
Cell[706122, 25474, 75, 3, 46, "Text"],
Cell[706200, 25479, 2147, 61, 46, "Assumption",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IH"],
Cell[708350, 25542, 75, 3, 46, "Text"],
Cell[708428, 25547, 2348, 66, 46, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS"],
Cell[710779, 25615, 129, 3, 46, "Text"],
Cell[710911, 25620, 43, 0, 46, "Text"],
Cell[710957, 25622, 240, 10, 46, "Text"],
Cell[711200, 25634, 1920, 57, 33, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.F"],
Cell[713123, 25693, 32, 0, 46, "Text"],
Cell[713158, 25695, 47, 0, 46, "Text"],
Cell[713208, 25697, 986, 35, 46, "Text"],
Cell[714197, 25734, 1188, 40, 46, "Text"],
Cell[715388, 25776, 1218, 40, 46, "Text"],
Cell[716609, 25818, 1337, 44, 46, "Text"],
Cell[717949, 25864, 1337, 44, 46, "Text"],
Cell[719289, 25910, 1347, 44, 46, "Text"],
Cell[720639, 25956, 1317, 44, 46, "Text"],
Cell[721959, 26002, 1166, 35, 46, "Text"],
Cell[723128, 26039, 47, 0, 46, "Text"],
Cell[723178, 26041, 1135, 40, 46, "Text"],
Cell[724316, 26083, 1276, 44, 46, "Text"],
Cell[725595, 26129, 1460, 49, 46, "Text"],
Cell[727058, 26180, 1460, 49, 46, "Text"],
Cell[728521, 26231, 1309, 40, 46, "Text"],
Cell[729833, 26273, 49, 0, 46, "Text"],
Cell[729885, 26275, 3118, 84, 46, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S"],
Cell[733006, 26361, 388, 18, 46, "Text"],
Cell[733397, 26381, 32, 0, 46, "Text"],
Cell[733432, 26383, 1976, 57, 33, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IB"],
Cell[735411, 26442, 240, 10, 46, "Text"],
Cell[735654, 26454, 47, 0, 46, "Text"],
Cell[735704, 26456, 1081, 36, 46, "Text"],
Cell[736788, 26494, 116, 5, 46, "Text"],
Cell[736907, 26501, 47, 0, 46, "Text"],
Cell[736957, 26503, 1070, 37, 46, "Text"],
Cell[738030, 26542, 847, 30, 46, "Text"],
Cell[738880, 26574, 277, 14, 46, "Text"],
Cell[739160, 26590, 116, 5, 46, "Text"],
Cell[739279, 26597, 31, 0, 46, "Text"],
Cell[739313, 26599, 75, 3, 46, "Text"],
Cell[739391, 26604, 2630, 75, 33, "Assumption",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IH"],
Cell[742024, 26681, 75, 3, 46, "Text"],
Cell[742102, 26686, 2851, 81, 33, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IS"],
Cell[744956, 26769, 217, 10, 46, "Text"],
Cell[745176, 26781, 47, 0, 46, "Text"],
Cell[745226, 26783, 1401, 46, 46, "Text"],
Cell[746630, 26831, 2334, 68, 46, "Text"],
Cell[748967, 26901, 2572, 70, 46, "Text"],
Cell[751542, 26973, 2582, 70, 46, "Text"],
Cell[754127, 27045, 2489, 69, 46, "Text"],
Cell[756619, 27116, 2308, 60, 46, "Text"],
Cell[758930, 27178, 47, 0, 46, "Text"],
Cell[758980, 27180, 1592, 52, 46, "Text"],
Cell[760575, 27234, 1798, 57, 46, "Text"],
Cell[762376, 27293, 2453, 73, 46, "Text"],
Cell[764832, 27368, 2483, 73, 46, "Text"],
Cell[767318, 27443, 2707, 75, 46, "Text"],
Cell[770028, 27520, 2707, 75, 46, "Text"],
Cell[772738, 27597, 2717, 75, 46, "Text"],
Cell[775458, 27674, 2706, 74, 46, "Text"],
Cell[778167, 27750, 2729, 75, 46, "Text"],
Cell[780899, 27827, 2706, 74, 46, "Text"],
Cell[783608, 27903, 2716, 74, 46, "Text"],
Cell[786327, 27979, 2754, 74, 46, "Text"],
Cell[789084, 28055, 2783, 75, 46, "Text"],
Cell[791870, 28132, 2720, 74, 46, "Text"],
Cell[794593, 28208, 2714, 74, 46, "Text"],
Cell[797310, 28284, 2724, 74, 46, "Text"],
Cell[800037, 28360, 2714, 74, 46, "Text"],
Cell[802754, 28436, 2563, 65, 46, "Text"],
Cell[805320, 28503, 49, 0, 46, "Text"],
Cell[805372, 28505, 5137, 126, 54, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IS.S"],
Cell[810512, 28633, 269, 10, 46, "Text"],
Cell[810784, 28645, 43, 0, 46, "Text"],
Cell[810830, 28647, 377, 18, 46, "Text"],
Cell[811210, 28667, 32, 0, 46, "Text"],
Cell[811245, 28669, 1552, 47, 33, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.IB"],
Cell[812800, 28718, 236, 10, 46, "Text"],
Cell[813039, 28730, 47, 0, 46, "Text"],
Cell[813089, 28732, 871, 32, 46, "Text"],
Cell[813963, 28766, 112, 5, 46, "Text"],
Cell[814078, 28773, 47, 0, 46, "Text"],
Cell[814128, 28775, 906, 33, 46, "Text"],
Cell[815037, 28810, 874, 33, 46, "Text"],
Cell[815914, 28845, 683, 27, 46, "Text"],
Cell[816600, 28874, 432, 19, 46, "Text"],
Cell[817035, 28895, 267, 14, 46, "Text"],
Cell[817305, 28911, 112, 5, 46, "Text"],
Cell[817420, 28918, 31, 0, 46, "Text"],
Cell[817454, 28920, 75, 3, 46, "Text"],
Cell[817532, 28925, 1922, 57, 33, "Assumption",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.IH"],
Cell[819457, 28984, 75, 3, 46, "Text"],
Cell[819535, 28989, 2053, 61, 33, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.IS"],
Cell[821591, 29052, 236, 10, 46, "Text"],
Cell[821830, 29064, 47, 0, 46, "Text"],
Cell[821880, 29066, 1024, 36, 46, "Text"],
Cell[822907, 29104, 1668, 53, 46, "Text"],
Cell[824578, 29159, 1884, 59, 46, "Text"],
Cell[826465, 29220, 2045, 63, 46, "Text"],
Cell[828513, 29285, 2247, 68, 46, "Text"],
Cell[830763, 29355, 2453, 73, 46, "Text"],
Cell[833219, 29430, 2490, 74, 46, "Text"],
Cell[835712, 29506, 2707, 75, 46, "Text"],
Cell[838422, 29583, 2707, 75, 46, "Text"],
Cell[841132, 29660, 2707, 75, 46, "Text"],
Cell[843842, 29737, 2707, 75, 46, "Text"],
Cell[846552, 29814, 2717, 75, 46, "Text"],
Cell[849272, 29891, 2555, 65, 46, "Text"],
Cell[851830, 29958, 47, 0, 46, "Text"],
Cell[851880, 29960, 1215, 42, 46, "Text"],
Cell[853098, 30004, 1447, 48, 46, "Text"],
Cell[854548, 30054, 1884, 59, 46, "Text"],
Cell[856435, 30115, 2045, 63, 46, "Text"],
Cell[858483, 30180, 2247, 68, 46, "Text"],
Cell[860733, 30250, 2455, 73, 46, "Text"],
Cell[863191, 30325, 2483, 73, 46, "Text"],
Cell[865677, 30400, 2707, 75, 46, "Text"],
Cell[868387, 30477, 2707, 75, 46, "Text"],
Cell[871097, 30554, 2707, 75, 46, "Text"],
Cell[873807, 30631, 2707, 75, 46, "Text"],
Cell[876517, 30708, 2707, 75, 46, "Text"],
Cell[879227, 30785, 2717, 75, 46, "Text"],
Cell[881947, 30862, 2706, 74, 46, "Text"],
Cell[884656, 30938, 2729, 75, 46, "Text"],
Cell[887388, 31015, 2706, 74, 46, "Text"],
Cell[890097, 31091, 2555, 65, 46, "Text"],
Cell[892655, 31158, 44, 0, 46, "Text"],
Cell[892702, 31160, 261, 11, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[893000, 31176, 100, 2, 63, "Subsection"],
Cell[893103, 31180, 22, 0, 46, "Text"],
Cell[893128, 31182, 1789, 55, 46, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] "],
Cell[894920, 31239, 38, 0, 46, "Text"],
Cell[894961, 31241, 613, 23, 43, "Assumption",
  CellTags->" \[RawStar]0"],
Cell[895577, 31266, 1404, 45, 45, "Assumption",
  CellTags->" \[RawStar]  ^+"],
Cell[896984, 31313, 606, 22, 43, "Assumption",
  CellTags->"0\[RawStar]"],
Cell[897593, 31337, 1400, 45, 45, "Assumption",
  CellTags->" ^+\[RawStar]"],
Cell[898996, 31384, 733, 26, 43, "Assumption",
  CellTags->" +0"],
Cell[899732, 31412, 1328, 43, 45, "Assumption",
  CellTags->" + ^+"],
Cell[901063, 31457, 733, 26, 43, "Assumption",
  CellTags->"0+ "],
Cell[901799, 31485, 1326, 43, 45, "Assumption",
  CellTags->"^++ "],
Cell[903128, 31530, 361, 18, 46, "Text"],
Cell[903492, 31550, 32, 0, 46, "Text"],
Cell[903527, 31552, 1378, 43, 46, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IB"],
Cell[904908, 31597, 240, 10, 46, "Text"],
Cell[905151, 31609, 940, 31, 33, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IB.F"],
Cell[906094, 31642, 224, 10, 46, "Text"],
Cell[906321, 31654, 47, 0, 46, "Text"],
Cell[906371, 31656, 582, 24, 46, "Text"],
Cell[906956, 31682, 393, 18, 46, "Text"],
Cell[907352, 31702, 112, 5, 46, "Text"],
Cell[907467, 31709, 47, 0, 46, "Text"],
Cell[907517, 31711, 599, 24, 46, "Text"],
Cell[908119, 31737, 112, 5, 46, "Text"],
Cell[908234, 31744, 31, 0, 46, "Text"],
Cell[908268, 31746, 75, 3, 46, "Text"],
Cell[908346, 31751, 1663, 50, 46, "Assumption",
  CellTags->"( \[RawStar] ) \[RawStar] .IH"],
Cell[910012, 31803, 75, 3, 46, "Text"],
Cell[910090, 31808, 1762, 53, 46, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS"],
Cell[911855, 31863, 230, 10, 46, "Text"],
Cell[912088, 31875, 1277, 40, 33, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.F"],
Cell[913368, 31917, 32, 0, 46, "Text"],
Cell[913403, 31919, 47, 0, 46, "Text"],
Cell[913453, 31921, 759, 29, 46, "Text"],
Cell[914215, 31952, 916, 33, 46, "Text"],
Cell[915134, 31987, 743, 24, 46, "Text"],
Cell[915880, 32013, 47, 0, 46, "Text"],
Cell[915930, 32015, 755, 29, 46, "Text"],
Cell[916688, 32046, 1061, 38, 46, "Text"],
Cell[917752, 32086, 1067, 38, 46, "Text"],
Cell[918822, 32126, 894, 29, 46, "Text"],
Cell[919719, 32157, 49, 0, 46, "Text"],
Cell[919771, 32159, 2258, 66, 46, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S"],
Cell[922032, 32227, 371, 18, 46, "Text"],
Cell[922406, 32247, 32, 0, 46, "Text"],
Cell[922441, 32249, 1530, 46, 46, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IB"],
Cell[923974, 32297, 250, 10, 46, "Text"],
Cell[924227, 32309, 1189, 38, 33, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IB.F"],
Cell[925419, 32349, 234, 10, 46, "Text"],
Cell[925656, 32361, 47, 0, 46, "Text"],
Cell[925706, 32363, 626, 25, 46, "Text"],
Cell[926335, 32390, 403, 18, 46, "Text"],
Cell[926741, 32410, 393, 18, 46, "Text"],
Cell[927137, 32430, 112, 5, 46, "Text"],
Cell[927252, 32437, 47, 0, 46, "Text"],
Cell[927302, 32439, 785, 30, 46, "Text"],
Cell[928090, 32471, 581, 24, 46, "Text"],
Cell[928674, 32497, 430, 19, 46, "Text"],
Cell[929107, 32518, 267, 14, 46, "Text"],
Cell[929377, 32534, 112, 5, 46, "Text"],
Cell[929492, 32541, 31, 0, 46, "Text"],
Cell[929526, 32543, 75, 3, 46, "Text"],
Cell[929604, 32548, 2147, 61, 46, "Assumption",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IH"],
Cell[931754, 32611, 75, 3, 46, "Text"],
Cell[931832, 32616, 2348, 66, 46, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS"],
Cell[934183, 32684, 240, 10, 46, "Text"],
Cell[934426, 32696, 1920, 57, 33, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.F"],
Cell[936349, 32755, 32, 0, 46, "Text"],
Cell[936384, 32757, 47, 0, 46, "Text"],
Cell[936434, 32759, 1000, 35, 46, "Text"],
Cell[937437, 32796, 986, 35, 46, "Text"],
Cell[938426, 32833, 1206, 40, 46, "Text"],
Cell[939635, 32875, 1190, 40, 46, "Text"],
Cell[940828, 32917, 1236, 40, 46, "Text"],
Cell[942067, 32959, 1218, 40, 46, "Text"],
Cell[943288, 33001, 1359, 44, 46, "Text"],
Cell[944650, 33047, 1186, 35, 46, "Text"],
Cell[945839, 33084, 47, 0, 46, "Text"],
Cell[945889, 33086, 1149, 40, 46, "Text"],
Cell[947041, 33128, 1135, 40, 46, "Text"],
Cell[948179, 33170, 1294, 44, 46, "Text"],
Cell[949476, 33216, 1276, 44, 46, "Text"],
Cell[950755, 33262, 1482, 49, 46, "Text"],
Cell[952240, 33313, 1373, 40, 46, "Text"],
Cell[953616, 33355, 49, 0, 46, "Text"],
Cell[953668, 33357, 3207, 85, 46, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S"],
Cell[956878, 33444, 381, 18, 46, "Text"],
Cell[957262, 33464, 32, 0, 46, "Text"],
Cell[957297, 33466, 2077, 58, 33, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IB"],
Cell[959377, 33526, 240, 10, 46, "Text"],
Cell[959620, 33538, 47, 0, 46, "Text"],
Cell[959670, 33540, 1106, 37, 46, "Text"],
Cell[960779, 33579, 116, 5, 46, "Text"],
Cell[960898, 33586, 47, 0, 46, "Text"],
Cell[960948, 33588, 1139, 38, 46, "Text"],
Cell[962090, 33628, 968, 33, 46, "Text"],
Cell[963061, 33663, 297, 14, 46, "Text"],
Cell[963361, 33679, 277, 14, 46, "Text"],
Cell[963641, 33695, 116, 5, 46, "Text"],
Cell[963760, 33702, 31, 0, 46, "Text"],
Cell[963794, 33704, 75, 3, 46, "Text"],
Cell[963872, 33709, 2714, 75, 33, "Assumption",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IH"],
Cell[966589, 33786, 75, 3, 46, "Text"],
Cell[966667, 33791, 2935, 81, 33, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] .IS.S.IS.S.IS"],
Cell[969605, 33874, 240, 10, 46, "Text"],
Cell[969848, 33886, 47, 0, 46, "Text"],
Cell[969898, 33888, 1435, 46, 46, "Text"],
Cell[971336, 33936, 1421, 46, 46, "Text"],
Cell[972760, 33984, 2392, 68, 46, "Text"],
Cell[975155, 34054, 2575, 69, 46, "Text"],
Cell[977733, 34125, 2842, 71, 46, "Text"],
Cell[980578, 34198, 2834, 71, 46, "Text"],
Cell[983415, 34271, 3060, 75, 46, "Text"],
Cell[986478, 34348, 2917, 66, 46, "Text"],
Cell[989398, 34416, 47, 0, 46, "Text"],
Cell[989448, 34418, 1670, 52, 46, "Text"],
Cell[991121, 34472, 1636, 52, 46, "Text"],
Cell[992760, 34526, 1836, 57, 46, "Text"],
Cell[994599, 34585, 1870, 57, 46, "Text"],
Cell[996472, 34644, 2607, 73, 46, "Text"],
Cell[999082, 34719, 2810, 74, 46, "Text"],
Cell[1001895, 34795, 3090, 75, 46, "Text"],
Cell[1004988, 34872, 2917, 66, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1007942, 34943, 46, 0, 63, "Subsection"],
Cell[1007991, 34945, 22, 0, 46, "Text"],
Cell[1008016, 34947, 7260, 177, 134, "Conclusion",
  CellTags->"f=0"],
Cell[1015279, 35126, 36, 0, 46, "Text"],
Cell[1015318, 35128, 23, 0, 46, "Text"],
Cell[1015344, 35130, 382, 8, 146, "Text"],
Cell[1015729, 35140, 43, 0, 46, "Text"],
Cell[1015775, 35142, 6481, 158, 164, "Conclusion",
  CellTags->"f=0.1"],
Cell[1022259, 35302, 70, 0, 46, "Text"],
Cell[1022332, 35304, 182, 10, 46, "Text"],
Cell[1022517, 35316, 63, 0, 46, "Text"],
Cell[1022583, 35318, 348, 11, 46, "Conclusion",
  CellTags->"f=0.1.structure"],
Cell[1022934, 35331, 21, 0, 46, "Text"],
Cell[1022958, 35333, 5315, 144, 120, "Text"],
Cell[1028276, 35479, 203, 9, 46, "Text"],
Cell[1028482, 35490, 323, 10, 46, "Conclusion",
  CellTags->"f=0.1.implication"],
Cell[1028808, 35502, 207, 9, 46, "Text"],
Cell[1029018, 35513, 343, 11, 48, "Conclusion",
  CellTags->"f=0.1.not-exists"],
Cell[1029364, 35526, 52, 0, 46, "Text"],
Cell[1029419, 35528, 23, 0, 46, "Text"],
Cell[1029445, 35530, 231, 9, 46, "Text"],
Cell[1029679, 35541, 389, 12, 48, "Conclusion",
  CellTags->"f=0.1.not-exists-slack"],
Cell[1030071, 35555, 262, 5, 71, "Text"],
Cell[1030336, 35562, 91, 1, 40, "Text"],
Cell[1030430, 35565, 130, 4, 96, "Text"],
Cell[1030563, 35571, 456, 7, 90, "Text"],
Cell[1031022, 35580, 35, 0, 46, "Text"],
Cell[1031060, 35582, 51, 1, 40, "Text"],
Cell[1031114, 35585, 196, 11, 46, "Text"],
Cell[1031313, 35598, 109, 3, 46, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

